@@ -1,24 +1,29 @@
+import { AccessControlAction } from 'app/types/accessControl';
+
 export type ResourcePermission = {
   id: number;
-  resourceId: string;
+  resourceId?: string;
   isManaged: boolean;
   isInherited: boolean;
   isServiceAccount: boolean;
   userId?: number;
+  userUid?: string;
   userLogin?: string;
   userAvatarUrl?: string;
   team?: string;
   teamId?: number;
+  teamUid?: string;
   teamAvatarUrl?: string;
   builtInRole?: string;
-  actions: string[];
+  actions: AccessControlAction[];
   permission: string;
+  roleName?: string;
   warning?: string;
 };
 
 export type SetPermission = {
-  userId?: number;
-  teamId?: number;
+  userUid?: string;
+  teamUid?: string;
   builtInRole?: string;
   permission: string;
   target: PermissionTarget;
