@@ -5,13 +5,13 @@ import { useLocation } from 'react-router-dom-v5-compat';
 
 import { GrafanaTheme2, NavModelItem } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
+import { t } from '@grafana/i18n';
 import { config, reportInteraction } from '@grafana/runtime';
-import { CustomScrollbar, Icon, IconButton, useStyles2, Stack } from '@grafana/ui';
+import { ScrollContainer, useStyles2 } from '@grafana/ui';
 import { useGrafana } from 'app/core/context/GrafanaContext';
-import { t } from 'app/core/internationalization';
 import { setBookmark } from 'app/core/reducers/navBarTree';
 import { usePatchUserPreferencesMutation } from 'app/features/preferences/api/index';
-import { useDispatch, useSelector } from 'app/types';
+import { useDispatch, useSelector } from 'app/types/store';
 
 import { MegaMenuHeader } from './MegaMenuHeader';
 import { MegaMenuItem } from './MegaMenuItem';
@@ -41,7 +41,7 @@ export const MegaMenu = memo(
       .map((item) => enrichWithInteractionTracking(item, state.megaMenuDocked));
 
     if (config.featureToggles.pinNavItems) {
-      const bookmarksItem = findByUrl(navItems, '/bookmarks');
+      const bookmarksItem = navItems.find((item) => item.id === 'bookmarks');
       if (bookmarksItem) {
         // Add children to the bookmarks section
         bookmarksItem.children = pinnedItems.reduce((acc: NavModelItem[], url) => {
@@ -72,11 +72,6 @@ export const MegaMenu = memo(
       if (state.megaMenuDocked) {
         chrome.setMegaMenuOpen(false);
       }
-
-      // refocus on undock/menu open button when changing state
-      setTimeout(() => {
-        document.getElementById(state.megaMenuDocked ? 'mega-menu-toggle' : 'dock-menu-button')?.focus();
-      });
     };
 
     const isPinned = useCallback(
@@ -114,50 +109,22 @@ export const MegaMenu = memo(
 
     return (
       <div data-testid={selectors.components.NavMenu.Menu} ref={ref} {...restProps}>
-        {config.featureToggles.singleTopNav ? (
-          <MegaMenuHeader handleDockedMenu={handleDockedMenu} handleMegaMenu={handleMegaMenu} onClose={onClose} />
-        ) : (
-          <div className={styles.mobileHeader}>
-            <Icon name="bars" size="xl" />
-            <IconButton
-              tooltip={t('navigation.megamenu.close', 'Close menu')}
-              name="times"
-              onClick={onClose}
-              size="xl"
-              variant="secondary"
-            />
-          </div>
-        )}
+        <MegaMenuHeader handleDockedMenu={handleDockedMenu} handleMegaMenu={handleMegaMenu} onClose={onClose} />
         <nav className={styles.content}>
-          <CustomScrollbar showScrollIndicators hideHorizontalTrack>
+          <ScrollContainer height="100%" overflowX="hidden" showScrollIndicators>
             <ul className={styles.itemList} aria-label={t('navigation.megamenu.list-label', 'Navigation')}>
               {navItems.map((link, index) => (
-                <Stack key={link.text} direction={index === 0 ? 'row-reverse' : 'row'} alignItems="start">
-                  {index === 0 && !config.featureToggles.singleTopNav && (
-                    <IconButton
-                      id="dock-menu-button"
-                      className={styles.dockMenuButton}
-                      tooltip={
-                        state.megaMenuDocked
-                          ? t('navigation.megamenu.undock', 'Undock menu')
-                          : t('navigation.megamenu.dock', 'Dock menu')
-                      }
-                      name="web-section-alt"
-                      onClick={handleDockedMenu}
-                      variant="secondary"
-                    />
-                  )}
-                  <MegaMenuItem
-                    link={link}
-                    isPinned={isPinned}
-                    onClick={state.megaMenuDocked ? undefined : onClose}
-                    activeItem={activeItem}
-                    onPin={onPinItem}
-                  />
-                </Stack>
+                <MegaMenuItem
+                  key={link.text}
+                  link={link}
+                  isPinned={isPinned}
+                  onClick={state.megaMenuDocked ? undefined : onClose}
+                  activeItem={activeItem}
+                  onPin={onPinItem}
+                />
               ))}
             </ul>
-          </CustomScrollbar>
+          </ScrollContainer>
         </nav>
       </div>
     );
@@ -166,41 +133,43 @@ export const MegaMenu = memo(
 
 MegaMenu.displayName = 'MegaMenu';
 
-const getStyles = (theme: GrafanaTheme2) => ({
-  content: css({
-    display: 'flex',
-    flexDirection: 'column',
-    height: '100%',
-    minHeight: 0,
-    position: 'relative',
-  }),
-  mobileHeader: css({
-    display: 'flex',
-    justifyContent: 'space-between',
-    padding: theme.spacing(1, 1, 1, 2),
-    borderBottom: `1px solid ${theme.colors.border.weak}`,
+const getStyles = (theme: GrafanaTheme2) => {
+  return {
+    content: css({
+      display: 'flex',
+      flexDirection: 'column',
+      minHeight: 0,
+      flexGrow: 1,
+      position: 'relative',
+    }),
+    mobileHeader: css({
+      display: 'flex',
+      justifyContent: 'space-between',
+      padding: theme.spacing(1, 1, 1, 2),
+      borderBottom: `1px solid ${theme.colors.border.weak}`,
 
-    [theme.breakpoints.up('md')]: {
+      [theme.breakpoints.up('md')]: {
+        display: 'none',
+      },
+    }),
+    itemList: css({
+      boxSizing: 'border-box',
+      display: 'flex',
+      flexDirection: 'column',
+      listStyleType: 'none',
+      padding: theme.spacing(1, 1, 2, 1),
+      [theme.breakpoints.up('md')]: {
+        width: MENU_WIDTH,
+      },
+    }),
+    dockMenuButton: css({
       display: 'none',
-    },
-  }),
-  itemList: css({
-    boxSizing: 'border-box',
-    display: 'flex',
-    flexDirection: 'column',
-    listStyleType: 'none',
-    padding: theme.spacing(1, 1, 2, 1),
-    [theme.breakpoints.up('md')]: {
-      width: MENU_WIDTH,
-    },
-  }),
-  dockMenuButton: css({
-    display: 'none',
-    position: 'relative',
-    top: theme.spacing(1),
+      position: 'relative',
+      top: theme.spacing(1),
 
-    [theme.breakpoints.up('xl')]: {
-      display: 'inline-flex',
-    },
-  }),
-});
+      [theme.breakpoints.up('xl')]: {
+        display: 'inline-flex',
+      },
+    }),
+  };
+};
