@@ -1,10 +1,8 @@
-import React, { FC } from 'react';
-
 import { LoginLayout, InnerBox } from '../Login/LoginLayout';
 
 import { ForgottenPassword } from './ForgottenPassword';
 
-export const SendResetMailPage: FC = () => (
+export const SendResetMailPage = () => (
   <LoginLayout>
     <InnerBox>
       <ForgottenPassword />
