@@ -1,8 +1,8 @@
 import { css, cx } from '@emotion/css';
-import React from 'react';
-import { DragDropContext, Draggable, Droppable, DropResult } from 'react-beautiful-dnd';
+import { DragDropContext, Draggable, Droppable, DropResult } from '@hello-pangea/dnd';
 
 import { GrafanaTheme2 } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { Icon, IconButton, useStyles2 } from '@grafana/ui';
 
 import { LayerName } from './LayerName';
@@ -66,7 +66,13 @@ export const LayerDragDropList = <T extends LayerElement>({
                         ref={provided.innerRef}
                         {...provided.draggableProps}
                         {...provided.dragHandleProps}
-                        onMouseDown={() => onSelect(element)}
+                        onClick={() => onSelect(element)}
+                        onKeyDown={(e) => {
+                          if (e.key === 'Enter' || e.key === ' ') {
+                            e.preventDefault();
+                            onSelect(element);
+                          }
+                        }}
                         role="button"
                         tabIndex={0}
                       >
@@ -82,7 +88,7 @@ export const LayerDragDropList = <T extends LayerElement>({
                             {onDuplicate ? (
                               <IconButton
                                 name="copy"
-                                tooltip="Duplicate"
+                                tooltip={t('layers.layer-drag-drop-list.duplicate-tooltip', 'Duplicate')}
                                 className={style.actionIcon}
                                 onClick={() => onDuplicate(element)}
                               />
@@ -90,7 +96,7 @@ export const LayerDragDropList = <T extends LayerElement>({
 
                             <IconButton
                               name="trash-alt"
-                              tooltip="Remove"
+                              tooltip={t('layers.layer-drag-drop-list.remove-tooltip', 'Remove')}
                               className={cx(style.actionIcon, style.dragIcon)}
                               onClick={() => onDelete(element)}
                             />
@@ -98,8 +104,10 @@ export const LayerDragDropList = <T extends LayerElement>({
                         )}
                         {layers.length > shouldRenderDragIconLengthThreshold && (
                           <Icon
-                            aria-label="Drag and drop icon"
-                            title="Drag and drop to reorder"
+                            aria-label={t(
+                              'layers.layer-drag-drop-list.draggable-aria-label',
+                              'Drag and drop to reorder'
+                            )}
                             name="draggabledots"
                             size="lg"
                             className={style.dragIcon}
@@ -122,54 +130,50 @@ export const LayerDragDropList = <T extends LayerElement>({
   );
 };
 
-LayerDragDropList.defaultProps = {
-  isGroup: () => false,
-};
-
 const getStyles = (theme: GrafanaTheme2) => ({
-  wrapper: css`
-    margin-bottom: ${theme.spacing(2)};
-  `,
-  row: css`
-    padding: ${theme.spacing(0.5, 1)};
-    border-radius: ${theme.shape.borderRadius(1)};
-    background: ${theme.colors.background.secondary};
-    min-height: ${theme.spacing(4)};
-    display: flex;
-    align-items: center;
-    justify-content: space-between;
-    margin-bottom: 3px;
-    cursor: pointer;
+  wrapper: css({
+    marginBottom: theme.spacing(2),
+  }),
+  row: css({
+    padding: theme.spacing(0.5, 1),
+    borderRadius: theme.shape.radius.default,
+    background: theme.colors.background.secondary,
+    minHeight: theme.spacing(4),
+    display: 'flex',
+    alignItems: 'center',
+    justifyContent: 'space-between',
+    marginBottom: '3px',
+    cursor: 'pointer',
 
-    border: 1px solid ${theme.components.input.borderColor};
-    &:hover {
-      border: 1px solid ${theme.components.input.borderHover};
-    }
-  `,
-  sel: css`
-    border: 1px solid ${theme.colors.primary.border};
-    &:hover {
-      border: 1px solid ${theme.colors.primary.border};
-    }
-  `,
-  dragIcon: css`
-    cursor: drag;
-  `,
-  actionIcon: css`
-    color: ${theme.colors.text.secondary};
-    &:hover {
-      color: ${theme.colors.text};
-    }
-  `,
-  typeWrapper: css`
-    color: ${theme.colors.primary.text};
-    margin-right: 5px;
-  `,
-  textWrapper: css`
-    display: flex;
-    align-items: center;
-    flex-grow: 1;
-    overflow: hidden;
-    margin-right: ${theme.spacing(1)};
-  `,
+    border: `1px solid ${theme.components.input.borderColor}`,
+    '&:hover': {
+      border: `1px solid ${theme.components.input.borderHover}`,
+    },
+  }),
+  sel: css({
+    border: `1px solid ${theme.colors.primary.border}`,
+    '&:hover': {
+      border: `1px solid ${theme.colors.primary.border}`,
+    },
+  }),
+  dragIcon: css({
+    cursor: 'drag',
+  }),
+  actionIcon: css({
+    color: theme.colors.text.secondary,
+    '&:hover': {
+      color: theme.colors.text.primary,
+    },
+  }),
+  typeWrapper: css({
+    color: theme.colors.primary.text,
+    marginRight: '5px',
+  }),
+  textWrapper: css({
+    display: 'flex',
+    alignItems: 'center',
+    flexGrow: 1,
+    overflow: 'hidden',
+    marginRight: theme.spacing(1),
+  }),
 });
