@@ -2,7 +2,7 @@ import { useEffect } from 'react';
 
 import { NavModel, NavModelItem } from '@grafana/data';
 import { HOME_NAV_ID } from 'app/core/reducers/navModel';
-import { useSelector } from 'app/types';
+import { useSelector } from 'app/types/store';
 
 import { Branding } from '../Branding/Branding';
 import { buildBreadcrumbs } from '../Breadcrumbs/utils';
