@@ -1,5 +1,4 @@
 import { css } from '@emotion/css';
-import React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { useStyles2 } from '@grafana/ui';
@@ -19,7 +18,7 @@ export function GrafanaRouteLoading() {
 const getStyles = (theme: GrafanaTheme2) => ({
   loadingPage: css({
     backgroundColor: theme.colors.background.primary,
-    height: '100%',
+    flex: 1,
     flexDrection: 'column',
     display: 'flex',
     justifyContent: 'center',
