@@ -1,6 +1,5 @@
 import { UrlQueryMap } from '@grafana/data';
-
-import { KioskMode } from '../../types';
+import { KioskMode } from 'app/types/dashboard';
 
 // TODO Remove after topnav feature toggle is permanent and old NavBar is removed
 export function getKioskMode(queryParams: UrlQueryMap): KioskMode | null {
