@@ -1,7 +1,7 @@
 import { dateTime, DataQuery } from '@grafana/data';
 import store from 'app/core/store';
+import { RichHistoryQuery } from 'app/types/explore';
 
-import { RichHistoryQuery } from '../../types';
 import RichHistoryStorage, { RichHistoryStorageWarning } from '../history/RichHistoryStorage';
 
 import {
@@ -109,15 +109,13 @@ describe('richHistory', () => {
 
     it('should append query to query history', async () => {
       Date.now = jest.fn(() => 2);
-      const { limitExceeded, richHistoryStorageFull } = await addToRichHistory(
-        mock.testDatasourceUid,
-        mock.testDatasourceName,
-        mock.testQueries,
-        mock.testStarred,
-        mock.testComment,
-        true,
-        true
-      );
+      const { limitExceeded, richHistoryStorageFull } = await addToRichHistory({
+        localOverride: false,
+        datasource: { uid: mock.testDatasourceUid, name: mock.testDatasourceName },
+        queries: mock.testQueries,
+        starred: mock.testStarred,
+        comment: mock.testComment,
+      });
       expect(limitExceeded).toBeFalsy();
       expect(richHistoryStorageFull).toBeFalsy();
       expect(richHistoryStorageMock.addToRichHistory).toBeCalledWith({
@@ -142,15 +140,13 @@ describe('richHistory', () => {
         });
       });
 
-      const { richHistoryStorageFull, limitExceeded } = await addToRichHistory(
-        mock.testDatasourceUid,
-        mock.testDatasourceName,
-        mock.testQueries,
-        mock.testStarred,
-        mock.testComment,
-        true,
-        true
-      );
+      const { richHistoryStorageFull, limitExceeded } = await addToRichHistory({
+        localOverride: false,
+        datasource: { uid: mock.testDatasourceUid, name: mock.testDatasourceName },
+        queries: mock.testQueries,
+        starred: mock.testStarred,
+        comment: mock.testComment,
+      });
       expect(richHistoryStorageFull).toBeFalsy();
       expect(limitExceeded).toBeTruthy();
     });
