@@ -1,22 +1,18 @@
-import React, { useCallback, useEffect, useState } from 'react';
+import { useCallback, useEffect, useState } from 'react';
 import { useForm } from 'react-hook-form';
 import { connect, ConnectedProps } from 'react-redux';
 
 import { NavModelItem } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { featureEnabled } from '@grafana/runtime';
 import { Alert, Button, Field, Input, Stack } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { contextSrv } from 'app/core/core';
 import { GrafanaRouteComponentProps } from 'app/core/navigation/types';
-import {
-  AppNotificationSeverity,
-  LdapError,
-  LdapUser,
-  StoreState,
-  SyncInfo,
-  LdapConnectionInfo,
-  AccessControlAction,
-} from 'app/types';
+import { AccessControlAction } from 'app/types/accessControl';
+import { AppNotificationSeverity } from 'app/types/appNotifications';
+import { LdapConnectionInfo, LdapUser, SyncInfo, LdapError } from 'app/types/ldap';
+import { StoreState } from 'app/types/store';
 
 import {
   loadLdapState,
@@ -118,9 +114,11 @@ export const LdapPage = ({
 
           {canReadLDAPUser && (
             <section>
-              <h3>Test user mapping</h3>
+              <h3>
+                <Trans i18nKey="admin.ldap.test-mapping-heading">Test user mapping</Trans>
+              </h3>
               <form onSubmit={handleSubmit(search)}>
-                <Field label="Username">
+                <Field label={t('admin.ldap-page.label-username', 'Username')}>
                   <Input
                     {...register('username', { required: true })}
                     width={34}
@@ -129,7 +127,7 @@ export const LdapPage = ({
                     defaultValue={queryParams.username}
                     addonAfter={
                       <Button variant="primary" type="submit">
-                        Run
+                        <Trans i18nKey="admin.ldap.test-mapping-run-button">Run</Trans>
                       </Button>
                     }
                   />
