@@ -2,9 +2,9 @@ import { css } from '@emotion/css';
 import { FormProvider, useForm } from 'react-hook-form';
 
 import { GrafanaTheme2 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { locationService } from '@grafana/runtime';
 import { Alert, Button, Field, FieldSet, Input, LinkButton, LoadingPlaceholder, useStyles2 } from '@grafana/ui';
-import { Trans } from 'app/core/internationalization';
 import {
   MuteTiming,
   useCreateMuteTiming,
@@ -68,9 +68,10 @@ const MuteTimingForm = ({ muteTiming, showError, loading, provisioned, editMode
   const defaultValues = useDefaultValues(muteTiming);
 
   const formApi = useForm({ defaultValues, values: defaultValues });
+
   const updating = formApi.formState.isSubmitting;
 
-  const returnLink = makeAMLink('/alerting/routes/', selectedAlertmanager!, { tab: 'mute_timings' });
+  const returnLink = makeAMLink('/alerting/routes/', selectedAlertmanager!, { tab: 'time_intervals' });
 
   const onSubmit = async (values: MuteTimingFields) => {
     const interval = createMuteTiming(values);
@@ -88,11 +89,20 @@ const MuteTimingForm = ({ muteTiming, showError, loading, provisioned, editMode
   };
 
   if (loading) {
-    return <LoadingPlaceholder text="Loading mute timing" />;
+    return (
+      <LoadingPlaceholder text={t('alerting.time-interval-form.text-loading-time-interval', 'Loading time interval')} />
+    );
   }
 
   if (showError) {
-    return <Alert title="No matching mute timing found" />;
+    return (
+      <Alert
+        title={t(
+          'alerting.time-interval-form.title-no-matching-time-interval-found',
+          'No matching time interval found'
+        )}
+      />
+    );
   }
 
   return (
@@ -103,8 +113,11 @@ const MuteTimingForm = ({ muteTiming, showError, loading, provisioned, editMode
           <FieldSet disabled={provisioned || updating}>
             <Field
               required
-              label="Name"
-              description="A unique name for the mute timing"
+              label={t('alerting.mute-timing-form.label-name', 'Name')}
+              description={t(
+                'alerting.time-interval-form.description-unique-time-interval',
+                'A unique name for the time interval'
+              )}
               invalid={!!formApi.formState.errors?.name}
               error={formApi.formState.errors.name?.message}
             >
@@ -128,9 +141,9 @@ const MuteTimingForm = ({ muteTiming, showError, loading, provisioned, editMode
               icon={updating ? 'spinner' : undefined}
             >
               {updating ? (
-                <Trans i18nKey="alerting.mute-timings.saving">Saving mute timing</Trans>
+                <Trans i18nKey="alerting.time-interval.saving">Saving time interval</Trans>
               ) : (
-                <Trans i18nKey="alerting.mute-timings.save">Save mute timing</Trans>
+                <Trans i18nKey="alerting.time-interval.save">Save time interval</Trans>
               )}
             </Button>
             <LinkButton type="button" variant="secondary" fill="outline" href={returnLink} disabled={updating}>
