@@ -8,15 +8,15 @@ import {
   IoK8SApimachineryPkgApisMetaV1ObjectMeta,
 } from 'app/features/alerting/unified/openapi/timeIntervalsApi.gen';
 import { BaseAlertmanagerArgs, Skippable } from 'app/features/alerting/unified/types/hooks';
-import { GRAFANA_RULES_SOURCE_NAME } from 'app/features/alerting/unified/utils/datasource';
 import { PROVENANCE_NONE } from 'app/features/alerting/unified/utils/k8s/constants';
 import {
-  getK8sNamespace,
+  encodeFieldSelector,
   isK8sEntityProvisioned,
   shouldUseK8sApi,
 } from 'app/features/alerting/unified/utils/k8s/utils';
 import { MuteTimeInterval } from 'app/plugins/datasource/alertmanager/types';
 
+import { getAPINamespace } from '../../../../../api/utils';
 import { useAsync } from '../../hooks/useAsync';
 import { useProduceNewAlertmanagerConfiguration } from '../../hooks/useProduceNewAlertmanagerConfig';
 import {
@@ -25,7 +25,7 @@ import {
   updateMuteTimingAction,
 } from '../../reducers/alertmanager/muteTimings';
 
-const { useLazyGetAlertmanagerConfigurationQuery, useGetMuteTimingListQuery } = alertmanagerApi;
+const { useLazyGetAlertmanagerConfigurationQuery } = alertmanagerApi;
 const {
   useLazyListNamespacedTimeIntervalQuery,
   useCreateNamespacedTimeIntervalMutation,
@@ -114,7 +114,7 @@ export const useMuteTimings = ({ alertmanager, skip }: BaseAlertmanagerArgs & Sk
       return;
     }
     if (useK8sApi) {
-      const namespace = getK8sNamespace();
+      const namespace = getAPINamespace();
       getGrafanaTimeIntervals({ namespace });
     } else {
       getAlertmanagerTimeIntervals(alertmanager);
@@ -140,7 +140,7 @@ export const useCreateMuteTiming = ({ alertmanager }: BaseAlertmanagerArgs) => {
   const [updateConfiguration] = useProduceNewAlertmanagerConfiguration();
 
   const addToK8sAPI = useAsync(({ interval }: CreateUpdateMuteTimingArgs) => {
-    const namespace = getK8sNamespace();
+    const namespace = getAPINamespace();
 
     return createGrafanaTimeInterval({
       namespace,
@@ -202,8 +202,9 @@ export const useGetMuteTiming = ({ alertmanager, name: nameToFind }: BaseAlertma
 
   useEffect(() => {
     if (useK8sApi) {
-      const namespace = getK8sNamespace();
-      getGrafanaTimeInterval({ namespace, fieldSelector: `spec.name=${nameToFind}` }, true);
+      const namespace = getAPINamespace();
+      const entityName = encodeFieldSelector(nameToFind);
+      getGrafanaTimeInterval({ namespace, fieldSelector: `spec.name=${entityName}` }, true);
     } else {
       getAlertmanagerTimeInterval(alertmanager, true);
     }
@@ -228,7 +229,7 @@ export const useUpdateMuteTiming = ({ alertmanager }: BaseAlertmanagerArgs) => {
 
   const updateToK8sAPI = useAsync(
     async ({ interval, originalName }: CreateUpdateMuteTimingArgs & { originalName: string }) => {
-      const namespace = getK8sNamespace();
+      const namespace = getAPINamespace();
 
       return replaceGrafanaTimeInterval({
         name: originalName,
@@ -267,7 +268,7 @@ export const useDeleteMuteTiming = ({ alertmanager }: BaseAlertmanagerArgs) => {
   });
 
   const deleteFromK8sAPI = useAsync(async ({ name }: DeleteMuteTimingArgs) => {
-    const namespace = getK8sNamespace();
+    const namespace = getAPINamespace();
     await deleteGrafanaTimeInterval({
       name,
       namespace,
@@ -302,21 +303,3 @@ export const useValidateMuteTiming = ({ alertmanager }: BaseAlertmanagerArgs) =>
       });
   };
 };
-
-/**
- * @deprecated This will be deprecated by the K8S API.
- * Once that is enabled by default, this method should be removed and `useMuteTimings` should always be used instead
- */
-export const useSelectableMuteTimings = ({ alertmanager, skip }: BaseAlertmanagerArgs & Skippable) => {
-  const useK8sApi = shouldUseK8sApi(alertmanager);
-  const useDeprecatedEndpoint = alertmanager === GRAFANA_RULES_SOURCE_NAME && !useK8sApi;
-
-  /** Fetch from the (to be deprecated) specific endpoint for time-intervals */
-  const deprecatedMuteTimingsResponse = useGetMuteTimingListQuery(undefined, {
-    skip: skip || !useDeprecatedEndpoint,
-  });
-
-  const fetchMuteTimings = useMuteTimings({ alertmanager, skip: skip || useDeprecatedEndpoint });
-
-  return useDeprecatedEndpoint ? deprecatedMuteTimingsResponse : fetchMuteTimings;
-};
