@@ -7,6 +7,7 @@ import { useToggle } from 'react-use';
 import AutoSizer from 'react-virtualized-auto-sizer';
 
 import { GrafanaTheme2 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { isFetchError, locationService } from '@grafana/runtime';
 import {
   Alert,
@@ -25,10 +26,10 @@ import {
   useStyles2,
 } from '@grafana/ui';
 import { useAppNotification } from 'app/core/copy/appNotification';
-import { Trans, t } from 'app/core/internationalization';
 import { ActiveTab as ContactPointsActiveTabs } from 'app/features/alerting/unified/components/contact-points/ContactPoints';
 import { TestTemplateAlert } from 'app/plugins/datasource/alertmanager/types';
 
+import { AITemplateButtonComponent } from '../../enterprise-components/AI/AIGenTemplateButton/addAITemplateButton';
 import { GRAFANA_RULES_SOURCE_NAME } from '../../utils/datasource';
 import { makeAMLink, stringifyErrorLike } from '../../utils/misc';
 import { ProvisionedResource, ProvisioningAlert } from '../Provisioning';
@@ -106,6 +107,9 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
   const [payload, setPayload] = useState(defaultPayloadString);
   const [payloadFormatError, setPayloadFormatError] = useState<string | null>(null);
 
+  // AI feedback state
+  const [aiGeneratedTemplate, setAiGeneratedTemplate] = useState(false);
+
   const { isProvisioned } = useNotificationTemplateMetadata(originalTemplate);
   const originalTemplatePrefill: TemplateFormValues | undefined = originalTemplate
     ? { title: originalTemplate.title, content: originalTemplate.content }
@@ -164,13 +168,26 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
     setValue('content', newValue);
   };
 
+  const handleTemplateGenerated = (template: string) => {
+    setValue('content', template);
+    setAiGeneratedTemplate(true);
+  };
+
   return (
     <>
       <FormProvider {...formApi}>
-        <form onSubmit={handleSubmit(submit)} ref={formRef} className={styles.form} aria-label="Template form">
+        <form
+          onSubmit={handleSubmit(submit)}
+          ref={formRef}
+          className={styles.form}
+          aria-label={t('alerting.template-form.aria-label-template-form', 'Template form')}
+        >
           {/* error message */}
           {error && (
-            <Alert severity="error" title="Error saving template">
+            <Alert
+              severity="error"
+              title={t('alerting.template-form.title-error-saving-template', 'Error saving template')}
+            >
               {error.message || (isFetchError(error) && error.data?.message) || String(error)}
             </Alert>
           )}
@@ -187,17 +204,20 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
               {/* name and save buttons */}
               <Stack direction="row" alignItems="center">
                 <InlineField
-                  label="Template group name"
+                  label={t('alerting.template-form.label-template-group-name', 'Template group name')}
                   error={errors?.title?.message}
                   invalid={!!errors.title?.message}
                   required
                 >
                   <Input
                     {...register('title', {
-                      required: { value: true, message: 'Required.' },
+                      required: { value: true, message: t('alerting.template-form.message.required', 'Required.') },
                       validate: { titleIsUnique },
                     })}
-                    placeholder="Give your template group a name"
+                    placeholder={t(
+                      'alerting.template-form.new-template-name-placeholder-give-your-template-group-a-name',
+                      'Give your template group a name'
+                    )}
                     width={42}
                     autoFocus={true}
                     id="new-template-name"
@@ -231,7 +251,7 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
                       <div className={cx(styles.flexColumn, styles.containerWithBorderAndRadius, styles.minEditorSize)}>
                         <div>
                           <EditorColumnHeader
-                            label="Template group"
+                            label={t('alerting.template-form.label-template-group', 'Template group')}
                             actions={
                               <>
                                 {/* examples dropdown – only available for Grafana Alertmanager */}
@@ -248,7 +268,10 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
                                         ))}
                                         <Menu.Divider />
                                         <Menu.Item
-                                          label={'Examples documentation'}
+                                          label={t(
+                                            'alerting.template-form.label-examples-documentation',
+                                            'Examples documentation'
+                                          )}
                                           url="https://grafana.com/docs/grafana/latest/alerting/configure-notifications/template-notifications/examples/"
                                           target="_blank"
                                           icon="external-link-alt"
@@ -261,6 +284,13 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
                                     </Button>
                                   </Dropdown>
                                 )}
+                                {/* GenAI button – only available for Grafana Alertmanager and enterprise */}
+                                {isGrafanaAlertManager && (
+                                  <AITemplateButtonComponent
+                                    onTemplateGenerated={handleTemplateGenerated}
+                                    disabled={isProvisioned}
+                                  />
+                                )}
                                 <Button
                                   icon="question-circle"
                                   size="sm"
@@ -317,18 +347,19 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
                 </div>
                 {/* preview column – full height and half-width */}
                 {isGrafanaAlertManager && (
-                  <>
-                    <div {...rowSplitter.secondaryProps}>
-                      <div {...rowSplitter.splitterProps} />
-                      <TemplatePreview
-                        payload={payload}
-                        templateName={watch('title')}
-                        setPayloadFormatError={setPayloadFormatError}
-                        payloadFormatError={payloadFormatError}
-                        className={cx(styles.templatePreview, styles.minEditorSize)}
-                      />
-                    </div>
-                  </>
+                  <div {...rowSplitter.secondaryProps}>
+                    <div {...rowSplitter.splitterProps} />
+                    <TemplatePreview
+                      payload={payload}
+                      templateName={watch('title')}
+                      templateContent={watch('content')}
+                      setPayloadFormatError={setPayloadFormatError}
+                      payloadFormatError={payloadFormatError}
+                      className={cx(styles.templatePreview, styles.minEditorSize)}
+                      aiGeneratedTemplate={aiGeneratedTemplate}
+                      setAiGeneratedTemplate={setAiGeneratedTemplate}
+                    />
+                  </div>
                 )}
               </div>
             </Stack>
@@ -336,7 +367,11 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
         </form>
       </FormProvider>
       {cheatsheetOpened && (
-        <Drawer title="Templating cheat sheet" onClose={toggleCheatsheetOpened} size="lg">
+        <Drawer
+          title={t('alerting.template-form.title-templating-cheat-sheet', 'Templating cheat sheet')}
+          onClose={toggleCheatsheetOpened}
+          size="lg"
+        >
           <TemplatingCheatSheet />
         </Drawer>
       )}
