@@ -14,9 +14,9 @@ interface HistoryProps {
 
 const History = ({ rule }: HistoryProps) => {
   // can be "loki", "multiple" or "annotations"
-  const stateHistoryBackend = config.unifiedAlerting.alertStateHistoryBackend;
+  const stateHistoryBackend = config.unifiedAlerting.stateHistory?.backend;
   // can be "loki" or "annotations"
-  const stateHistoryPrimary = config.unifiedAlerting.alertStateHistoryPrimary;
+  const stateHistoryPrimary = config.unifiedAlerting.stateHistory?.primary;
 
   // if "loki" is either the backend or the primary, show the new state history implementation
   const usingNewAlertStateHistory = [stateHistoryBackend, stateHistoryPrimary].some(
@@ -26,13 +26,12 @@ const History = ({ rule }: HistoryProps) => {
     ? StateHistoryImplementation.Loki
     : StateHistoryImplementation.Annotations;
 
-  const ruleID = rule.grafana_alert.id ?? '';
   const ruleUID = rule.grafana_alert.uid;
 
   return (
     <Suspense fallback={'Loading...'}>
       {implementation === StateHistoryImplementation.Loki && <LokiStateHistory ruleUID={ruleUID} />}
-      {implementation === StateHistoryImplementation.Annotations && <AnnotationsStateHistory alertId={ruleID} />}
+      {implementation === StateHistoryImplementation.Annotations && <AnnotationsStateHistory ruleUID={ruleUID} />}
     </Suspense>
   );
 };
