@@ -6,7 +6,7 @@ import { InsightsMenuButton } from '../../InsightsMenuButton';
 
 export function getRulesPerGroupScene(datasource: DataSourceRef, panelTitle: string) {
   const expr = INSTANCE_ID
-    ? `sum(grafanacloud_instance_rule_group_rules{rule_group="$rule_group", id="${INSTANCE_ID}"})`
+    ? `sum(grafanacloud_instance_rule_group_rules{rule_group="$rule_group", stack_id="${INSTANCE_ID}"})`
     : `sum(grafanacloud_instance_rule_group_rules{rule_group="$rule_group"})`;
 
   const query = new SceneQueryRunner({
