@@ -1,25 +1,34 @@
-import React from 'react';
+import { Suspense, lazy } from 'react';
 
+import { t } from '@grafana/i18n';
 import { Drawer, LoadingPlaceholder, Stack, TextLink } from '@grafana/ui';
 
-import { t } from '../../../../core/internationalization';
-import { createUrl } from '../utils/url';
+import { createRelativeUrl } from '../utils/url';
 
-const AlertRulesDrawerContent = React.lazy(
+const AlertRulesDrawerContent = lazy(
   () => import(/* webpackChunkName: "alert-rules-drawer-content" */ './AlertRulesDrawerContent')
 );
 
 interface Props {
   dashboardUid: string;
-  onClose: () => void;
+  onDismiss: () => void;
 }
 
-export function AlertRulesDrawer({ dashboardUid, onClose }: Props) {
+export function AlertRulesDrawer({ dashboardUid, onDismiss }: Props) {
   return (
-    <Drawer title="Alert rules" subtitle={<DrawerSubtitle dashboardUid={dashboardUid} />} onClose={onClose} size="lg">
-      <React.Suspense fallback={<LoadingPlaceholder text="Loading alert rules" />}>
+    <Drawer
+      title={t('alerting.alert-rules-drawer.title-alert-rules', 'Alert rules')}
+      subtitle={<DrawerSubtitle dashboardUid={dashboardUid} />}
+      onClose={onDismiss}
+      size="lg"
+    >
+      <Suspense
+        fallback={
+          <LoadingPlaceholder text={t('alerting.alert-rules-drawer.text-loading-alert-rules', 'Loading alert rules')} />
+        }
+      >
         <AlertRulesDrawerContent dashboardUid={dashboardUid} />
-      </React.Suspense>
+      </Suspense>
     </Drawer>
   );
 }
@@ -30,7 +39,7 @@ function DrawerSubtitle({ dashboardUid }: { dashboardUid: string }) {
   return (
     <Stack gap={2}>
       <div>{t('dashboard.alert-rules-drawer.subtitle', 'Alert rules related to this dashboard')}</div>
-      <TextLink href={createUrl(`/alerting/list/?${searchParams.toString()}`)}>
+      <TextLink href={createRelativeUrl(`/alerting/list/?${searchParams.toString()}`)}>
         {t('dashboard.alert-rules-drawer.redirect-link', 'List in Grafana Alerting')}
       </TextLink>
     </Stack>
