@@ -6,11 +6,20 @@ import {
   findMatchingAlertGroups,
   findMatchingRoutes,
   normalizeRoute,
+  unquoteRouteMatchers,
 } from './utils/notification-policies';
 
+export interface MatchOptions {
+  unquoteMatchers?: boolean;
+}
+
 export const routeGroupsMatcher = {
-  getRouteGroupsMap(rootRoute: RouteWithID, groups: AlertmanagerGroup[]): Map<string, AlertmanagerGroup[]> {
-    const normalizedRootRoute = normalizeRoute(rootRoute);
+  getRouteGroupsMap(
+    rootRoute: RouteWithID,
+    groups: AlertmanagerGroup[],
+    options?: MatchOptions
+  ): Map<string, AlertmanagerGroup[]> {
+    const normalizedRootRoute = getNormalizedRoute(rootRoute, options);
 
     function addRouteGroups(route: RouteWithID, acc: Map<string, AlertmanagerGroup[]>) {
       const routeGroups = findMatchingAlertGroups(normalizedRootRoute, route, groups);
@@ -25,10 +34,14 @@ export const routeGroupsMatcher = {
     return routeGroupsMap;
   },
 
-  matchInstancesToRoute(routeTree: RouteWithID, instancesToMatch: Labels[]): Map<string, AlertInstanceMatch[]> {
+  matchInstancesToRoute(
+    routeTree: RouteWithID,
+    instancesToMatch: Labels[],
+    options?: MatchOptions
+  ): Map<string, AlertInstanceMatch[]> {
     const result = new Map<string, AlertInstanceMatch[]>();
 
-    const normalizedRootRoute = normalizeRoute(routeTree);
+    const normalizedRootRoute = getNormalizedRoute(routeTree, options);
 
     instancesToMatch.forEach((instance) => {
       const matchingRoutes = findMatchingRoutes(normalizedRootRoute, Object.entries(instance));
@@ -47,4 +60,8 @@ export const routeGroupsMatcher = {
   },
 };
 
+function getNormalizedRoute(route: RouteWithID, options?: MatchOptions): RouteWithID {
+  return options?.unquoteMatchers ? unquoteRouteMatchers(normalizeRoute(route)) : normalizeRoute(route);
+}
+
 export type RouteGroupsMatcher = typeof routeGroupsMatcher;
