@@ -1,16 +1,13 @@
 import { useCallback, useEffect, useMemo, useState } from 'react';
-import { useLocation } from 'react-router-dom-v5-compat';
 import { useAsyncFn, useInterval } from 'react-use';
 
-import { urlUtil } from '@grafana/data';
-import { logInfo } from '@grafana/runtime';
-import { Button, LinkButton, Stack } from '@grafana/ui';
+import { t } from '@grafana/i18n';
+import { Button, Stack } from '@grafana/ui';
 import { useQueryParams } from 'app/core/hooks/useQueryParams';
-import { Trans } from 'app/core/internationalization';
-import { useDispatch } from 'app/types';
+import { useDispatch } from 'app/types/store';
 import { CombinedRuleNamespace } from 'app/types/unified-alerting';
 
-import { LogMessages, trackRuleListNavigation } from '../Analytics';
+import { trackRuleListNavigation } from '../Analytics';
 import { AlertingPageWrapper } from '../components/AlertingPageWrapper';
 import RulesFilter from '../components/rules/Filter/RulesFilter.v1';
 import { NoRulesSplash } from '../components/rules/NoRulesCTA';
@@ -20,14 +17,15 @@ import { RuleListGroupView } from '../components/rules/RuleListGroupView';
 import { RuleListStateView } from '../components/rules/RuleListStateView';
 import { RuleStats } from '../components/rules/RuleStats';
 import { shouldUsePrometheusRulesPrimary } from '../featureToggles';
-import { AlertingAction, useAlertingAbility } from '../hooks/useAbilities';
 import { useCombinedRuleNamespaces } from '../hooks/useCombinedRuleNamespaces';
 import { useFilteredRules, useRulesFilter } from '../hooks/useFilteredRules';
 import { useUnifiedAlertingSelector } from '../hooks/useUnifiedAlertingSelector';
 import { fetchAllPromAndRulerRulesAction, fetchAllPromRulesAction, fetchRulerRulesAction } from '../state/actions';
 import { RULE_LIST_POLL_INTERVAL_MS } from '../utils/constants';
 import { GRAFANA_RULES_SOURCE_NAME, getAllRulesSourceNames } from '../utils/datasource';
-import { createRelativeUrl } from '../utils/url';
+
+import { RuleListPageTitle } from './RuleListPageTitle';
+import { RuleListActionButtons } from './components/RuleListActionButtons';
 
 const VIEWS = {
   groups: RuleListGroupView,
@@ -123,13 +121,8 @@ const RuleListV1 = () => {
     <AlertingPageWrapper
       navId="alert-list"
       isLoading={false}
-      actions={
-        hasAlertRulesCreated && (
-          <Stack gap={1}>
-            <CreateAlertButton /> <ExportNewRuleButton />
-          </Stack>
-        )
-      }
+      renderTitle={(title) => <RuleListPageTitle title={title} />}
+      actions={<RuleListActionButtons hasAlertRulesCreated={hasAlertRulesCreated} />}
     >
       <Stack direction="column">
         <RuleListErrors />
@@ -142,7 +135,9 @@ const RuleListV1 = () => {
                 variant="secondary"
                 onClick={() => setExpandAll(!expandAll)}
               >
-                {expandAll ? 'Collapse all' : 'Expand all'}
+                {expandAll
+                  ? t('alerting.rule-list-v1.collapse-all', 'Collapse all')
+                  : t('alerting.rule-list-v1.expand-all', 'Expand all')}
               </Button>
             )}
           </Stack>
@@ -156,45 +151,3 @@ const RuleListV1 = () => {
 };
 
 export default RuleListV1;
-
-export function CreateAlertButton() {
-  const [createRuleSupported, createRuleAllowed] = useAlertingAbility(AlertingAction.CreateAlertRule);
-  const [createCloudRuleSupported, createCloudRuleAllowed] = useAlertingAbility(AlertingAction.CreateExternalAlertRule);
-
-  const location = useLocation();
-
-  const canCreateCloudRules = createCloudRuleSupported && createCloudRuleAllowed;
-
-  const canCreateGrafanaRules = createRuleSupported && createRuleAllowed;
-
-  if (canCreateGrafanaRules || canCreateCloudRules) {
-    return (
-      <LinkButton
-        href={urlUtil.renderUrl('alerting/new/alerting', { returnTo: location.pathname + location.search })}
-        icon="plus"
-        onClick={() => logInfo(LogMessages.alertRuleFromScratch)}
-      >
-        <Trans i18nKey="alerting.rule-list.new-alert-rule">New alert rule</Trans>
-      </LinkButton>
-    );
-  }
-  return null;
-}
-
-function ExportNewRuleButton() {
-  const returnTo = location.pathname + location.search;
-  const url = createRelativeUrl(`/alerting/export-new-rule`, {
-    returnTo,
-  });
-  return (
-    <LinkButton
-      href={url}
-      icon="download-alt"
-      variant="secondary"
-      tooltip="Export new grafana rule"
-      onClick={() => logInfo(LogMessages.exportNewGrafanaRule)}
-    >
-      <Trans i18nKey="alerting.list-view.section.grafanaManaged.export-new-rule">Export rule definition</Trans>
-    </LinkButton>
-  );
-}
