@@ -10,9 +10,10 @@ import {
   AnnotationEventFieldSource,
   getValueFormat,
 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { Select, Tooltip, Icon } from '@grafana/ui';
 
-import { annotationEventNames, AnnotationFieldInfo } from '../standardAnnotationSupport';
+import { getAnnotationEventNames, AnnotationFieldInfo } from '../standardAnnotationSupport';
 import { AnnotationQueryResponse } from '../types';
 
 // const valueOptions: Array<SelectableValue<AnnotationEventFieldSource>> = [
@@ -170,7 +171,10 @@ export class AnnotationFieldMapper extends PureComponent<Props, State> {
             onChange={(v: SelectableValue<string>) => {
               this.onFieldNameChange(row.key, v);
             }}
-            noOptionsMessage="Unknown field names"
+            noOptionsMessage={t(
+              'annotations.annotation-field-mapper.noOptionsMessage-unknown-field-names',
+              'Unknown field names'
+            )}
             allowCustomValue={true}
             isClearable
           />
@@ -188,13 +192,19 @@ export class AnnotationFieldMapper extends PureComponent<Props, State> {
       <table className="filter-table">
         <thead>
           <tr>
-            <th>Annotation</th>
-            <th>From</th>
-            <th>First Value</th>
+            <th>
+              <Trans i18nKey="annotations.annotation-field-mapper.annotation">Annotation</Trans>
+            </th>
+            <th>
+              <Trans i18nKey="annotations.annotation-field-mapper.from">From</Trans>
+            </th>
+            <th>
+              <Trans i18nKey="annotations.annotation-field-mapper.first-value">First value</Trans>
+            </th>
           </tr>
         </thead>
         <tbody>
-          {annotationEventNames.map((row) => {
+          {getAnnotationEventNames().map((row) => {
             return this.renderRow(row, mappings[row.key] || {}, first);
           })}
         </tbody>
