@@ -11,6 +11,7 @@ import {
   LoadingState,
 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
+import { Trans, t } from '@grafana/i18n';
 import { Alert, AlertVariant, Button, Space, Spinner } from '@grafana/ui';
 import { getDashboardSrv } from 'app/features/dashboard/services/DashboardSrv';
 import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
@@ -99,9 +100,27 @@ export default class StandardAnnotationQueryEditor extends PureComponent<Props,
   };
 
   onQueryChange = (target: DataQuery) => {
+    // if dealing with v2 dashboards
+    if (this.props.annotation.query && this.props.annotation.query.spec) {
+      target = {
+        ...this.props.annotation.query.spec,
+        ...target,
+      };
+    }
+    //target property is what ds query editor are using, but for v2 we also need to keep query in sync
     this.props.onChange({
       ...this.props.annotation,
+      // the query editor uses target, but the annotation in v2 uses query
+      // therefore we need to keep the target and query in sync
       target,
+      ...(this.props.annotation.query && {
+        query: {
+          kind: this.props.annotation.query.kind,
+          spec: { ...target },
+        },
+      }),
+      // Keep legacyOptions from the original annotation if they exist
+      ...(this.props.annotation.legacyOptions ? { legacyOptions: this.props.annotation.legacyOptions } : {}),
     });
   };
 
@@ -147,13 +166,21 @@ export default class StandardAnnotationQueryEditor extends PureComponent<Props,
     }
 
     if (!events?.length) {
-      return <p>No events found</p>;
+      return (
+        <p>
+          <Trans i18nKey="annotations.standard-annotation-query-editor.no-events-found">No events found</Trans>
+        </p>
+      );
     }
 
     const frame = panelData?.series?.[0] ?? panelData?.annotations?.[0];
+    const numEvents = events.length;
+    const numFields = frame?.fields.length;
     return (
       <p>
-        {events.length} events (from {frame?.fields.length} fields)
+        <Trans i18nKey="annotations.standard-annotation-query-editor.events-found">
+          {{ numEvents }} events (from {{ numFields }} fields)
+        </Trans>
       </p>
     );
   }
@@ -178,7 +205,9 @@ export default class StandardAnnotationQueryEditor extends PureComponent<Props,
               size="xs"
               onClick={this.onRunQuery}
             >
-              Test annotation query
+              <Trans i18nKey="annotations.standard-annotation-query-editor.test-annotation-query">
+                Test annotation query
+              </Trans>
             </Button>
           )}
         </div>
@@ -186,7 +215,7 @@ export default class StandardAnnotationQueryEditor extends PureComponent<Props,
         <Alert
           data-testid={selectors.components.Annotations.editor.resultContainer}
           severity={this.getStatusSeverity(response)}
-          title="Query result"
+          title={t('annotations.standard-annotation-query-editor.title-query-result', 'Query result')}
         >
           {this.renderStatusText(response, running)}
         </Alert>
@@ -195,7 +224,12 @@ export default class StandardAnnotationQueryEditor extends PureComponent<Props,
   }
 
   onAnnotationChange = (annotation: AnnotationQuery) => {
-    this.props.onChange(annotation);
+    // Also preserve any legacyOptions field that might exist when migrating from V2 to V1
+    this.props.onChange({
+      ...annotation,
+      // Keep legacyOptions from the original annotation if they exist
+      ...(this.props.annotation.legacyOptions ? { legacyOptions: this.props.annotation.legacyOptions } : {}),
+    });
   };
 
   render() {
@@ -205,14 +239,38 @@ export default class StandardAnnotationQueryEditor extends PureComponent<Props,
     // Find the annotation runner
     let QueryEditor = datasource.annotations?.QueryEditor || datasource.components?.QueryEditor;
     if (!QueryEditor) {
-      return <div>Annotations are not supported. This datasource needs to export a QueryEditor</div>;
+      return (
+        <div>
+          <Trans i18nKey="annotations.standard-annotation-query-editor.no-query-editor">
+            Annotations are not supported. This datasource needs to export a QueryEditor
+          </Trans>
+        </div>
+      );
     }
 
-    const query = {
+    // For v2 dashboards, target is not available, only query
+    let target = annotation.target;
+
+    // For v2 dashboards, use query.spec
+    if (annotation.query && annotation.query.spec) {
+      target = {
+        ...annotation.query.spec,
+      };
+    }
+
+    let query = {
       ...datasource.annotations?.getDefaultQuery?.(),
-      ...(annotation.target ?? { refId: 'Anno' }),
+      ...(target ?? { refId: 'Anno' }),
     };
 
+    // Create annotation object that respects annotations API
+    let editorAnnotation = annotation;
+
+    // For v2 dashboards: propagate legacyOptions to root level for datasource compatibility
+    if (annotation.query && annotation.legacyOptions) {
+      editorAnnotation = { ...annotation.legacyOptions, ...annotation };
+    }
+
     return (
       <>
         <DataSourcePluginContextProvider instanceSettings={datasourceInstanceSettings}>
@@ -224,7 +282,7 @@ export default class StandardAnnotationQueryEditor extends PureComponent<Props,
             onRunQuery={this.onRunQuery}
             data={response?.panelData}
             range={getTimeSrv().timeRange()}
-            annotation={annotation}
+            annotation={editorAnnotation}
             onAnnotationChange={this.onAnnotationChange}
           />
         </DataSourcePluginContextProvider>
