@@ -1,9 +1,9 @@
 import { SelectableValue } from '@grafana/data';
 
-import { fieldMap, sectionFields } from '../fields';
+import { fieldMap, getSectionFields } from '../fields';
 import { FieldData, SSOProvider, SSOProviderDTO } from '../types';
 
-import { isSelectableValue } from './guards';
+import { isSelectableValueArray } from './guards';
 
 export const emptySettings: SSOProviderDTO = {
   allowAssignGrafanaAdmin: false,
@@ -20,10 +20,12 @@ export const emptySettings: SSOProviderDTO = {
   clientSecret: '',
   managedIdentityClientId: '',
   federatedCredentialAudience: '',
+  workloadIdentityTokenFile: '',
   emailAttributeName: '',
   emailAttributePath: '',
   emptyScopes: false,
   enabled: false,
+  loginPrompt: '',
   extra: {},
   groupsAttributePath: '',
   hostedDomain: '',
@@ -81,15 +83,12 @@ export function dataToDTO(data?: SSOProvider): SSOProviderDTO {
 }
 
 const valuesToString = (values: Array<SelectableValue<string>>) => {
-  if (values.length <= 1) {
-    return values.map(({ value }) => value).join(',');
-  }
-  // Store as JSON array if there are multiple values
+  // Store arrays as JSON array
   return JSON.stringify(values.map(({ value }) => value));
 };
 
 const getFieldsForProvider = (provider: string) => {
-  const sections = sectionFields[provider];
+  const sections = getSectionFields()[provider];
 
   // include the enabled field because it is not part of the fields defined for providers
   const fields = ['enabled'];
@@ -121,10 +120,10 @@ export function dtoToData(dto: SSOProviderDTO, provider: string) {
   for (const field of arrayFields) {
     const value = current[field];
     if (value) {
-      if (isSelectableValue(value)) {
+      if (isSelectableValueArray(value)) {
         //@ts-expect-error
         settings[field] = valuesToString(value);
-      } else if (isSelectableValue([value])) {
+      } else if (isSelectableValueArray([value])) {
         //@ts-expect-error
         settings[field] = value.value;
       }
@@ -136,5 +135,5 @@ export function dtoToData(dto: SSOProviderDTO, provider: string) {
 export function getArrayFields(obj: Record<string, FieldData>, providerFields: string[]): Array<keyof SSOProviderDTO> {
   return Object.entries(obj)
     .filter(([key, value]) => providerFields.includes(key) && value.type === 'select')
-    .map(([key]) => key as keyof SSOProviderDTO);
+    .map(([key]) => key as keyof SSOProviderDTO); // TODO: replace this with a type guard
 }
