@@ -1,12 +1,13 @@
-import { config, getBackendSrv } from '@grafana/runtime';
+import { getBackendSrv } from '@grafana/runtime';
 import { GENERAL_FOLDER_UID } from 'app/features/search/constants';
-import { getGrafanaSearcher, NestedFolderDTO } from 'app/features/search/service';
+import { getGrafanaSearcher } from 'app/features/search/service/searcher';
+import { NestedFolderDTO } from 'app/features/search/service/types';
 import { queryResultToViewItem } from 'app/features/search/service/utils';
 import { DashboardViewItem } from 'app/features/search/types';
+import { AccessControlAction } from 'app/types/accessControl';
 
 import { contextSrv } from '../../../core/core';
-import { AccessControlAction } from '../../../types';
-import { isSharedWithMe } from '../components/utils';
+import { getFolderURL, isSharedWithMe } from '../components/utils';
 
 export const PAGE_SIZE = 50;
 
@@ -16,12 +17,9 @@ export async function listFolders(
   page = 1,
   pageSize = PAGE_SIZE
 ): Promise<DashboardViewItem[]> {
-  if (parentUID && !config.featureToggles.nestedFolders) {
-    return [];
-  }
-
   const backendSrv = getBackendSrv();
 
+  // TODO: what to do here for unified search?
   let folders: NestedFolderDTO[] = [];
   if (contextSrv.hasPermission(AccessControlAction.FoldersRead)) {
     folders = await backendSrv.get<NestedFolderDTO[]>('/api/folders', {
@@ -37,7 +35,10 @@ export async function listFolders(
     title: item.title,
     parentTitle,
     parentUID,
-    url: isSharedWithMe(item.uid) ? undefined : `/dashboards/f/${item.uid}/`,
+    managedBy: item.managedBy,
+
+    // URLs from the backend come with subUrlPrefix already included, so match that behaviour here
+    url: isSharedWithMe(item.uid) ? undefined : getFolderURL(item.uid),
   }));
 }
 
@@ -50,6 +51,7 @@ export async function listDashboards(parentUID?: string, page = 1, pageSize = PA
     location: parentUID || 'general',
     from: (page - 1) * pageSize, // our pages are 1-indexed, so we need to -1 to convert that to correct value to skip
     limit: pageSize,
+    offset: (page - 1) * pageSize,
   });
 
   return dashboardsResults.view.map((item) => {
