@@ -1,14 +1,19 @@
-import React, { useState } from 'react';
+import { useState } from 'react';
 
-import { config, locationService, reportInteraction } from '@grafana/runtime';
+import { AppEvents } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
+import { locationService, reportInteraction } from '@grafana/runtime';
 import { Button, Drawer, Dropdown, Icon, Menu, MenuItem } from '@grafana/ui';
 import { Permissions } from 'app/core/components/AccessControl';
 import { appEvents } from 'app/core/core';
-import { t, Trans } from 'app/core/internationalization';
-import { FolderDTO } from 'app/types';
+import { RepoType } from 'app/features/provisioning/Wizard/types';
+import { DeleteProvisionedFolderForm } from 'app/features/provisioning/components/Folders/DeleteProvisionedFolderForm';
+import { getReadOnlyTooltipText } from 'app/features/provisioning/utils/repository';
 import { ShowModalReactEvent } from 'app/types/events';
+import { FolderDTO } from 'app/types/folders';
 
-import { useDeleteFolderMutation, useMoveFolderMutation } from '../api/browseDashboardsAPI';
+import { useDeleteFolderMutationFacade, useMoveFolderMutationFacade } from '../../../api/clients/folder/v1beta1/hooks';
+import { ManagerKind } from '../../apiserver/types';
 import { getFolderPermissions } from '../permissions';
 
 import { DeleteModal } from './BrowseActions/DeleteModal';
@@ -16,19 +21,25 @@ import { MoveModal } from './BrowseActions/MoveModal';
 
 interface Props {
   folder: FolderDTO;
+  isReadOnlyRepo?: boolean;
+  repoType?: RepoType;
 }
 
-export function FolderActionsButton({ folder }: Props) {
+export function FolderActionsButton({ folder, repoType, isReadOnlyRepo }: Props) {
   const [isOpen, setIsOpen] = useState(false);
   const [showPermissionsDrawer, setShowPermissionsDrawer] = useState(false);
-  const [moveFolder] = useMoveFolderMutation();
-  const [deleteFolder] = useDeleteFolderMutation();
+  const [showDeleteProvisionedFolderDrawer, setShowDeleteProvisionedFolderDrawer] = useState(false);
+  const [moveFolder] = useMoveFolderMutationFacade();
+
+  const deleteFolder = useDeleteFolderMutationFacade();
+
   const { canEditFolders, canDeleteFolders, canViewPermissions, canSetPermissions } = getFolderPermissions(folder);
-  // Can only move folders when nestedFolders is enabled
-  const canMoveFolder = config.featureToggles.nestedFolders && canEditFolders;
+  const isProvisionedFolder = folder.managedBy === ManagerKind.Repo;
+  // Can only move folders when the folder is not provisioned
+  const canMoveFolder = canEditFolders && !isProvisionedFolder;
 
   const onMove = async (destinationUID: string) => {
-    await moveFolder({ folder, destinationUID });
+    await moveFolder({ folderUID: folder.uid, destinationUID: destinationUID });
     reportInteraction('grafana_manage_dashboards_item_moved', {
       item_counts: {
         folder: 1,
@@ -39,7 +50,21 @@ export function FolderActionsButton({ folder }: Props) {
   };
 
   const onDelete = async () => {
-    await deleteFolder(folder);
+    const result = await deleteFolder(folder);
+
+    if (result.error) {
+      appEvents.publish({
+        type: AppEvents.alertError.name,
+        payload: [
+          t(
+            'browse-dashboards.folder-actions-button.delete-folder-error',
+            'Error deleting folder. Please try again later.'
+          ),
+        ],
+      });
+      return;
+    }
+
     reportInteraction('grafana_manage_dashboards_item_deleted', {
       item_counts: {
         folder: 1,
@@ -86,6 +111,10 @@ export function FolderActionsButton({ folder }: Props) {
     );
   };
 
+  const showDeleteProvisionedModal = () => {
+    setShowDeleteProvisionedFolderDrawer(true);
+  };
+
   const managePermissionsLabel = t('browse-dashboards.folder-actions-button.manage-permissions', 'Manage permissions');
   const moveLabel = t('browse-dashboards.folder-actions-button.move', 'Move');
   const deleteLabel = t('browse-dashboards.folder-actions-button.delete', 'Delete');
@@ -94,7 +123,13 @@ export function FolderActionsButton({ folder }: Props) {
     <Menu>
       {canViewPermissions && <MenuItem onClick={() => setShowPermissionsDrawer(true)} label={managePermissionsLabel} />}
       {canMoveFolder && <MenuItem onClick={showMoveModal} label={moveLabel} />}
-      {canDeleteFolders && <MenuItem destructive onClick={showDeleteModal} label={deleteLabel} />}
+      {canDeleteFolders && (
+        <MenuItem
+          destructive
+          onClick={isProvisionedFolder ? showDeleteProvisionedModal : showDeleteModal}
+          label={deleteLabel}
+        />
+      )}
     </Menu>
   );
 
@@ -105,7 +140,11 @@ export function FolderActionsButton({ folder }: Props) {
   return (
     <>
       <Dropdown overlay={menu} onVisibleChange={setIsOpen}>
-        <Button variant="secondary">
+        <Button
+          variant="secondary"
+          disabled={isReadOnlyRepo}
+          tooltip={isReadOnlyRepo ? getReadOnlyTooltipText({ isLocal: repoType === 'local' }) : undefined}
+        >
           <Trans i18nKey="browse-dashboards.folder-actions-button.folder-actions">Folder actions</Trans>
           <Icon name={isOpen ? 'angle-up' : 'angle-down'} />
         </Button>
@@ -120,6 +159,18 @@ export function FolderActionsButton({ folder }: Props) {
           <Permissions resource="folders" resourceId={folder.uid} canSetPermissions={canSetPermissions} />
         </Drawer>
       )}
+      {showDeleteProvisionedFolderDrawer && (
+        <Drawer
+          title={t('browse-dashboards.action.delete-provisioned-folder', 'Delete provisioned folder')}
+          subtitle={folder.title}
+          onClose={() => setShowDeleteProvisionedFolderDrawer(false)}
+        >
+          <DeleteProvisionedFolderForm
+            parentFolder={folder}
+            onDismiss={() => setShowDeleteProvisionedFolderDrawer(false)}
+          />
+        </Drawer>
+      )}
     </>
   );
 }
