@@ -32,7 +32,8 @@ const browseDashboardsSlice = createSlice({
 
 export const browseDashboardsReducer = browseDashboardsSlice.reducer;
 
-export const { setFolderOpenState, setItemSelectionState, setAllSelection } = browseDashboardsSlice.actions;
+export const { setFolderOpenState, setItemSelectionState, setAllSelection, clearFolders } =
+  browseDashboardsSlice.actions;
 
 export default {
   browseDashboards: browseDashboardsReducer,
