@@ -1,10 +1,11 @@
 import { css } from '@emotion/css';
 
-import { GrafanaTheme2, OneClickMode } from '@grafana/data';
+import { GrafanaTheme2 } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { ScalarDimensionConfig } from '@grafana/schema';
 import { useStyles2 } from '@grafana/ui';
-import { DimensionContext } from 'app/features/dimensions';
-import { ScalarDimensionEditor } from 'app/features/dimensions/editors';
+import { DimensionContext } from 'app/features/dimensions/context';
+import { ScalarDimensionEditor } from 'app/features/dimensions/editors/ScalarDimensionEditor';
 
 import { CanvasElementItem, CanvasElementOptions, CanvasElementProps, defaultBgColor } from '../element';
 
@@ -94,7 +95,6 @@ export const droneFrontItem: CanvasElementItem = {
       left: options?.placement?.left,
       rotation: options?.placement?.rotation ?? 0,
     },
-    oneClickMode: options?.oneClickMode ?? OneClickMode.Off,
     links: options?.links ?? [],
   }),
 
@@ -110,12 +110,12 @@ export const droneFrontItem: CanvasElementItem = {
   },
 
   registerOptionsUI: (builder) => {
-    const category = ['Drone Front'];
+    const category = [t('canvas.drone-front-item.category-drone-front', 'Drone Front')];
     builder.addCustomEditor({
       category,
       id: 'rollAngle',
       path: 'config.rollAngle',
-      name: 'Roll Angle',
+      name: t('canvas.drone-front-item.name-roll-angle', 'Roll Angle'),
       editor: ScalarDimensionEditor,
     });
   },
