@@ -3,7 +3,8 @@ import { negate } from 'lodash';
 import { memo, useCallback, useEffect, useMemo, useRef, useState } from 'react';
 
 import { DataSourceInstanceSettings, GrafanaTheme2 } from '@grafana/data';
-import { isFetchError, reportInteraction } from '@grafana/runtime';
+import { Trans, t } from '@grafana/i18n';
+import { CorrelationData, isFetchError, reportInteraction } from '@grafana/runtime';
 import {
   Badge,
   Button,
@@ -16,29 +17,28 @@ import {
   type CellProps,
   type SortByFn,
   Pagination,
-  Icon,
+  TextLink,
 } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { contextSrv } from 'app/core/core';
 import { useNavModel } from 'app/core/hooks/useNavModel';
-import { Trans, t } from 'app/core/internationalization';
-import { AccessControlAction } from 'app/types';
+import { AccessControlAction } from 'app/types/accessControl';
 
 import { AddCorrelationForm } from './Forms/AddCorrelationForm';
 import { EditCorrelationForm } from './Forms/EditCorrelationForm';
 import { EmptyCorrelationsCTA } from './components/EmptyCorrelationsCTA';
 import type { Correlation, RemoveCorrelationParams } from './types';
-import { CorrelationData, useCorrelations } from './useCorrelations';
+import { useCorrelations } from './useCorrelations';
 
 const sortDatasource: SortByFn<CorrelationData> = (a, b, column) =>
   a.values[column].name.localeCompare(b.values[column].name);
 
 const isCorrelationsReadOnly = (correlation: CorrelationData) => correlation.provisioned;
 
-const loaderWrapper = css`
-  display: flex;
-  justify-content: center;
-`;
+const loaderWrapper = css({
+  display: 'flex',
+  justifyContent: 'center',
+});
 
 export default function CorrelationsPage() {
   const navModel = useNavModel('correlations');
@@ -160,14 +160,9 @@ export default function CorrelationsPage() {
         <>
           <Trans i18nKey="correlations.sub-title">
             Define how data living in different data sources relates to each other. Read more in the{' '}
-            <a
-              href="https://grafana.com/docs/grafana/next/administration/correlations/"
-              target="_blank"
-              rel="noreferrer"
-            >
+            <TextLink href="https://grafana.com/docs/grafana/next/administration/correlations/" external>
               documentation
-              <Icon name="external-link-alt" />
-            </a>
+            </TextLink>
           </Trans>
         </>
       }
@@ -255,15 +250,15 @@ function ExpendedRow({ correlation: { source, ...correlation }, readOnly, onUpda
 }
 
 const getDatasourceCellStyles = (theme: GrafanaTheme2) => ({
-  root: css`
-    display: flex;
-    align-items: center;
-  `,
-  dsLogo: css`
-    margin-right: ${theme.spacing()};
-    height: 16px;
-    width: 16px;
-  `,
+  root: css({
+    display: 'flex',
+    alignItems: 'center',
+  }),
+  dsLogo: css({
+    marginRight: theme.spacing(),
+    height: '16px',
+    width: '16px',
+  }),
 });
 
 const DataSourceCell = memo(
@@ -286,9 +281,9 @@ const DataSourceCell = memo(
   }
 );
 
-const noWrap = css`
-  white-space: nowrap;
-`;
+const noWrap = css({
+  whiteSpace: 'nowrap',
+});
 
 const InfoCell = memo(
   function InfoCell({ ...props }: CellProps<CorrelationData, void>) {
