@@ -1,8 +1,6 @@
-import React from 'react';
-
-import { sanitizeUrl } from '@grafana/data/src/text/sanitize';
+import { sanitizeUrl } from '@grafana/data/internal';
 import { selectors } from '@grafana/e2e-selectors';
-import { SceneComponentProps, SceneObjectBase, SceneObjectState } from '@grafana/scenes';
+import { sceneGraph } from '@grafana/scenes';
 import { DashboardLink } from '@grafana/schema';
 import { Tooltip } from '@grafana/ui';
 import {
@@ -12,16 +10,17 @@ import {
 import { getLinkSrv } from 'app/features/panel/panellinks/link_srv';
 
 import { LINK_ICON_MAP } from '../settings/links/utils';
-import { getDashboardSceneFor } from '../utils/utils';
 
-interface DashboardLinksControlsState extends SceneObjectState {}
+import { DashboardScene } from './DashboardScene';
 
-export class DashboardLinksControls extends SceneObjectBase<DashboardLinksControlsState> {
-  static Component = DashboardLinksControlsRenderer;
+export interface Props {
+  links: DashboardLink[];
+  dashboard: DashboardScene;
 }
 
-function DashboardLinksControlsRenderer({ model }: SceneComponentProps<DashboardLinksControls>) {
-  const { links, uid } = getDashboardSceneFor(model).useState();
+export function DashboardLinksControls({ links, dashboard }: Props) {
+  sceneGraph.getTimeRange(dashboard).useState();
+  const uid = dashboard.state.uid;
 
   if (!links || !uid) {
     return null;
