@@ -34,7 +34,12 @@ class DashboardMacro implements FormatVariable {
 }
 
 export function registerDashboardMacro() {
-  const unregister = sceneUtils.registerVariableMacro('__dashboard', DashboardMacro);
+  try {
+    const unregister = sceneUtils.registerVariableMacro('__dashboard', DashboardMacro);
 
-  return () => unregister();
+    return () => unregister();
+  } catch (e) {
+    console.error('Error registering dashboard macro', e);
+    return () => {};
+  }
 }
