@@ -10,29 +10,25 @@ import {
   GroupByVariable,
   IntervalVariable,
   QueryVariable,
-  SceneDataLayerControls,
-  SceneDataProvider,
-  SceneDataQuery,
-  SceneDataTransformer,
-  SceneQueryRunner,
   SceneRefreshPicker,
   SceneTimePicker,
   SceneTimeRange,
   SceneVariable,
   SceneVariableSet,
+  ScopesVariable,
   TextBoxVariable,
-  VariableValueSelectors,
 } from '@grafana/scenes';
-import { DataSourceRef } from '@grafana/schema/dist/esm/index.gen';
 import {
   AdhocVariableKind,
+  AnnotationQueryKind,
   ConstantVariableKind,
   CustomVariableKind,
-  DashboardV2Spec,
+  Spec as DashboardV2Spec,
   DatasourceVariableKind,
   defaultAdhocVariableKind,
   defaultConstantVariableKind,
   defaultCustomVariableKind,
+  defaultDataQueryKind,
   defaultDatasourceVariableKind,
   defaultGroupByVariableKind,
   defaultIntervalVariableKind,
@@ -42,10 +38,10 @@ import {
   IntervalVariableKind,
   LibraryPanelKind,
   PanelKind,
-  PanelQueryKind,
   QueryVariableKind,
   TextVariableKind,
-} from '@grafana/schema/src/schema/dashboard/v2alpha0';
+} from '@grafana/schema/dist/esm/schema/dashboard/v2';
+import { DEFAULT_ANNOTATION_COLOR } from '@grafana/ui';
 import {
   AnnoKeyCreatedBy,
   AnnoKeyFolder,
@@ -53,26 +49,29 @@ import {
   AnnoKeyUpdatedTimestamp,
   AnnoKeyDashboardIsSnapshot,
   DeprecatedInternalId,
+  AnnoKeyEmbedded,
 } from 'app/features/apiserver/types';
 import { DashboardWithAccessInfo } from 'app/features/dashboard/api/types';
-import { MIXED_DATASOURCE_NAME } from 'app/plugins/datasource/mixed/MixedDataSource';
-import { DashboardMeta } from 'app/types';
+import {
+  getDashboardInteractionCallback,
+  getDashboardSceneProfiler,
+} from 'app/features/dashboard/services/DashboardProfiler';
+import { DashboardMeta } from 'app/types/dashboard';
 
 import { addPanelsOnLoadBehavior } from '../addToDashboard/addPanelsOnLoadBehavior';
 import { DashboardAnnotationsDataLayer } from '../scene/DashboardAnnotationsDataLayer';
 import { DashboardControls } from '../scene/DashboardControls';
 import { DashboardDataLayerSet } from '../scene/DashboardDataLayerSet';
-import { DashboardDatasourceBehaviour } from '../scene/DashboardDatasourceBehaviour';
 import { registerDashboardMacro } from '../scene/DashboardMacro';
 import { DashboardReloadBehavior } from '../scene/DashboardReloadBehavior';
 import { DashboardScene } from '../scene/DashboardScene';
-import { DashboardScopesFacade } from '../scene/DashboardScopesFacade';
 import { DashboardLayoutManager } from '../scene/types/DashboardLayoutManager';
-import { preserveDashboardSceneStateInLocalStorage } from '../utils/dashboardSessionState';
 import { getIntervalsFromQueryString } from '../utils/utils';
 
+import { transformV2ToV1AnnotationQuery } from './annotations';
 import { SnapshotVariable } from './custom-variables/SnapshotVariable';
-import { layoutSerializerRegistry } from './layoutSerializers/layoutSerializerRegistry';
+import { layoutDeserializerRegistry } from './layoutSerializers/layoutSerializerRegistry';
+import { getDataSourceForQuery, getRuntimeVariableDataSource } from './layoutSerializers/utils';
 import { registerPanelInteractionsReporter } from './transformSaveModelToScene';
 import {
   transformCursorSyncV2ToV1,
@@ -95,19 +94,26 @@ export type TypedVariableModelV2 =
   | AdhocVariableKind;
 
 export function transformSaveModelSchemaV2ToScene(dto: DashboardWithAccessInfo<DashboardV2Spec>): DashboardScene {
-  const { spec: dashboard, metadata } = dto;
+  const { spec: dashboard, metadata, apiVersion } = dto;
+
+  // annotations might not come with the builtIn Grafana annotation, we need to add it
+  const grafanaBuiltAnnotation = getGrafanaBuiltInAnnotationDataLayer(dashboard);
+  if (grafanaBuiltAnnotation) {
+    dashboard.annotations.unshift(grafanaBuiltAnnotation);
+  }
 
   const annotationLayers = dashboard.annotations.map((annotation) => {
-    return new DashboardAnnotationsDataLayer({
+    const annotationQuerySpec = transformV2ToV1AnnotationQuery(annotation);
+
+    const layerState = {
       key: uniqueId('annotations-'),
-      query: {
-        ...annotation.spec,
-        builtIn: annotation.spec.builtIn ? 1 : 0,
-      },
+      query: annotationQuerySpec,
       name: annotation.spec.name,
       isEnabled: Boolean(annotation.spec.enable),
       isHidden: Boolean(annotation.spec.hide),
-    });
+    };
+
+    return new DashboardAnnotationsDataLayer(layerState);
   });
 
   const isDashboardEditable = Boolean(dashboard.editable);
@@ -134,12 +140,13 @@ export function transformSaveModelSchemaV2ToScene(dto: DashboardWithAccessInfo<D
     updatedBy: metadata.annotations?.[AnnoKeyUpdatedBy],
     folderUid: metadata.annotations?.[AnnoKeyFolder],
     isSnapshot: Boolean(metadata.annotations?.[AnnoKeyDashboardIsSnapshot]),
+    isEmbedded: Boolean(metadata.annotations?.[AnnoKeyEmbedded]),
 
     // UI-only metadata, ref: DashboardModel.initMeta
     showSettings: Boolean(dto.access.canEdit),
     canMakeEditable: canSave && !isDashboardEditable,
     hasUnsavedFolderChange: false,
-    version: parseInt(metadata.resourceVersion, 10),
+    version: metadata.generation,
     k8s: metadata,
   };
 
@@ -150,155 +157,89 @@ export function transformSaveModelSchemaV2ToScene(dto: DashboardWithAccessInfo<D
     meta.canSave = false;
   }
 
-  const layoutManager: DashboardLayoutManager = layoutSerializerRegistry
+  const layoutManager: DashboardLayoutManager = layoutDeserializerRegistry
     .get(dashboard.layout.kind)
-    .serializer.deserialize(dashboard.layout, dashboard.elements, dashboard.preload);
+    .deserialize(dashboard.layout, dashboard.elements, dashboard.preload);
 
   //createLayoutManager(dashboard);
 
-  const dashboardScene = new DashboardScene({
-    description: dashboard.description,
-    editable: dashboard.editable,
-    preload: dashboard.preload,
-    id: dashboardId,
-    isDirty: false,
-    links: dashboard.links,
-    meta,
-    tags: dashboard.tags,
-    title: dashboard.title,
-    uid: metadata.name,
-    version: parseInt(metadata.resourceVersion, 10),
-    body: layoutManager,
-    $timeRange: new SceneTimeRange({
-      from: dashboard.timeSettings.from,
-      to: dashboard.timeSettings.to,
-      fiscalYearStartMonth: dashboard.timeSettings.fiscalYearStartMonth,
-      timeZone: dashboard.timeSettings.timezone,
-      weekStart: dashboard.timeSettings.weekStart,
-      UNSAFE_nowDelay: dashboard.timeSettings.nowDelay,
-    }),
-    $variables: getVariables(dashboard, meta.isSnapshot ?? false),
-    $behaviors: [
-      new behaviors.CursorSync({
-        sync: transformCursorSyncV2ToV1(dashboard.cursorSync),
-      }),
-      new behaviors.SceneQueryController(),
-      registerDashboardMacro,
-      registerPanelInteractionsReporter,
-      new behaviors.LiveNowTimer({ enabled: dashboard.liveNow }),
-      preserveDashboardSceneStateInLocalStorage,
-      addPanelsOnLoadBehavior,
-      new DashboardScopesFacade({
-        reloadOnParamsChange: config.featureToggles.reloadDashboardsOnParamsChange,
-        uid: dashboardId?.toString(),
-      }),
-      new DashboardReloadBehavior({
-        reloadOnParamsChange: config.featureToggles.reloadDashboardsOnParamsChange,
-        uid: dashboardId?.toString(),
-        version: 1,
-      }),
-    ],
-    $data: new DashboardDataLayerSet({
-      annotationLayers,
-    }),
-    controls: new DashboardControls({
-      variableControls: [new VariableValueSelectors({}), new SceneDataLayerControls()],
-      timePicker: new SceneTimePicker({
-        quickRanges: dashboard.timeSettings.quickRanges,
-      }),
-      refreshPicker: new SceneRefreshPicker({
-        refresh: dashboard.timeSettings.autoRefresh,
-        intervals: dashboard.timeSettings.autoRefreshIntervals,
-        withText: true,
-      }),
-      hideTimeControls: dashboard.timeSettings.hideTimepicker,
-    }),
-  });
+  const queryController = new behaviors.SceneQueryController(
+    {
+      enableProfiling:
+        config.dashboardPerformanceMetrics.findIndex((uid) => uid === '*' || uid === metadata.name) !== -1,
+      onProfileComplete: getDashboardInteractionCallback(metadata.name, dashboard.title),
+    },
+    getDashboardSceneProfiler()
+  );
 
-  dashboardScene.setInitialSaveModel(dto.spec, dto.metadata);
+  const dashboardScene = new DashboardScene(
+    {
+      description: dashboard.description,
+      editable: dashboard.editable,
+      preload: dashboard.preload,
+      id: dashboardId,
+      isDirty: false,
+      links: dashboard.links,
+      meta,
+      tags: dashboard.tags,
+      title: dashboard.title,
+      uid: metadata.name,
+      version: metadata.generation,
+      body: layoutManager,
+      $timeRange: new SceneTimeRange({
+        from: dashboard.timeSettings.from,
+        to: dashboard.timeSettings.to,
+        fiscalYearStartMonth: dashboard.timeSettings.fiscalYearStartMonth,
+        timeZone: dashboard.timeSettings.timezone,
+        weekStart: dashboard.timeSettings.weekStart,
+        UNSAFE_nowDelay: dashboard.timeSettings.nowDelay,
+      }),
+      $variables: getVariables(dashboard, meta.isSnapshot ?? false),
+      $behaviors: [
+        new behaviors.CursorSync({
+          sync: transformCursorSyncV2ToV1(dashboard.cursorSync),
+        }),
+        queryController,
+        registerDashboardMacro,
+        registerPanelInteractionsReporter,
+        new behaviors.LiveNowTimer({ enabled: dashboard.liveNow }),
+        addPanelsOnLoadBehavior,
+        new DashboardReloadBehavior({
+          reloadOnParamsChange: config.featureToggles.reloadDashboardsOnParamsChange && false,
+          uid: dashboardId?.toString(),
+        }),
+      ],
+      $data: new DashboardDataLayerSet({
+        annotationLayers,
+      }),
+      controls: new DashboardControls({
+        timePicker: new SceneTimePicker({
+          quickRanges: dashboard.timeSettings.quickRanges,
+          defaultQuickRanges: config.quickRanges,
+        }),
+        refreshPicker: new SceneRefreshPicker({
+          refresh: dashboard.timeSettings.autoRefresh,
+          intervals: dashboard.timeSettings.autoRefreshIntervals,
+          withText: true,
+        }),
+        hideTimeControls: dashboard.timeSettings.hideTimepicker,
+      }),
+    },
+    'v2'
+  );
+
+  dashboardScene.setInitialSaveModel(dto.spec, dto.metadata, apiVersion);
 
   return dashboardScene;
 }
 
-function getPanelDataSource(panel: PanelKind): DataSourceRef | undefined {
-  if (!panel.spec.data?.spec.queries?.length) {
-    return undefined;
-  }
-
-  let datasource: DataSourceRef | undefined = undefined;
-  let isMixedDatasource = false;
-
-  panel.spec.data.spec.queries.forEach((query) => {
-    if (!datasource) {
-      datasource = query.spec.datasource;
-    } else if (datasource.uid !== query.spec.datasource?.uid || datasource.type !== query.spec.datasource?.type) {
-      isMixedDatasource = true;
-    }
-  });
-
-  return isMixedDatasource ? { type: 'mixed', uid: MIXED_DATASOURCE_NAME } : datasource;
-}
-
-function panelQueryKindToSceneQuery(query: PanelQueryKind): SceneDataQuery {
-  return {
-    refId: query.spec.refId,
-    datasource: query.spec.datasource,
-    hide: query.spec.hidden,
-    ...query.spec.query.spec,
-  };
-}
-
-export function createPanelDataProvider(panelKind: PanelKind): SceneDataProvider | undefined {
-  const panel = panelKind.spec;
-  const targets = panel.data?.spec.queries ?? [];
-  // Skip setting query runner for panels without queries
-  if (!targets?.length) {
-    return undefined;
-  }
-
-  // Skip setting query runner for panel plugins with skipDataQuery
-  if (config.panels[panel.vizConfig.kind]?.skipDataQuery) {
-    return undefined;
-  }
-
-  let dataProvider: SceneDataProvider | undefined = undefined;
-  const datasource = getPanelDataSource(panelKind);
-
-  dataProvider = new SceneQueryRunner({
-    datasource,
-    queries: targets.map(panelQueryKindToSceneQuery),
-    maxDataPoints: panel.data.spec.queryOptions.maxDataPoints ?? undefined,
-    maxDataPointsFromWidth: true,
-    cacheTimeout: panel.data.spec.queryOptions.cacheTimeout,
-    queryCachingTTL: panel.data.spec.queryOptions.queryCachingTTL,
-    minInterval: panel.data.spec.queryOptions.interval ?? undefined,
-    dataLayerFilter: {
-      panelId: panel.id,
-    },
-    $behaviors: [new DashboardDatasourceBehaviour({})],
-  });
-
-  // Wrap inner data provider in a data transformer
-  return new SceneDataTransformer({
-    $data: dataProvider,
-    transformations: panel.data.spec.transformations.map((transformation) => transformation.spec),
-  });
-}
-
 function getVariables(dashboard: DashboardV2Spec, isSnapshot: boolean): SceneVariableSet | undefined {
   let variables: SceneVariableSet | undefined;
 
-  if (dashboard.variables.length) {
-    if (isSnapshot) {
-      variables = createVariablesForSnapshot(dashboard);
-    } else {
-      variables = createVariablesForDashboard(dashboard);
-    }
+  if (isSnapshot) {
+    variables = createVariablesForSnapshot(dashboard);
   } else {
-    // Create empty variable set
-    variables = new SceneVariableSet({
-      variables: [],
-    });
+    variables = createVariablesForDashboard(dashboard);
   }
 
   return variables;
@@ -318,6 +259,10 @@ function createVariablesForDashboard(dashboard: DashboardV2Spec) {
     // Added temporarily to allow skipping non-compatible variables
     .filter((v): v is SceneVariable => Boolean(v));
 
+  if (config.featureToggles.scopeFilters) {
+    variableObjects.push(new ScopesVariable({ enable: true }));
+  }
+
   return new SceneVariableSet({
     variables: variableObjects,
   });
@@ -328,23 +273,29 @@ function createSceneVariableFromVariableModel(variable: TypedVariableModelV2): S
     name: variable.spec.name,
     label: variable.spec.label,
     description: variable.spec.description,
+    showInControlsMenu: variable.spec.showInControlsMenu,
   };
   if (variable.kind === defaultAdhocVariableKind().kind) {
+    const ds = getDataSourceForQuery(
+      {
+        type: variable.group,
+        uid: variable.datasource?.name,
+      },
+      variable.group
+    );
     return new AdHocFiltersVariable({
       ...commonProperties,
       description: variable.spec.description,
       skipUrlSync: variable.spec.skipUrlSync,
       hide: transformVariableHideToEnumV1(variable.spec.hide),
-      datasource: variable.spec.datasource,
+      datasource: ds,
       applyMode: 'auto',
       filters: variable.spec.filters ?? [],
       baseFilters: variable.spec.baseFilters ?? [],
       defaultKeys: variable.spec.defaultKeys,
       useQueriesAsFilterForOptions: true,
       layout: config.featureToggles.newFiltersUI ? 'combobox' : undefined,
-      supportsMultiValueOperators: Boolean(
-        getDataSourceSrv().getInstanceSettings(variable.spec.datasource)?.meta.multiValueFilterOperators
-      ),
+      supportsMultiValueOperators: Boolean(getDataSourceSrv().getInstanceSettings(ds)?.meta.multiValueFilterOperators),
     });
   }
   if (variable.kind === defaultCustomVariableKind().kind) {
@@ -367,7 +318,7 @@ function createSceneVariableFromVariableModel(variable: TypedVariableModelV2): S
       value: variable.spec.current?.value ?? '',
       text: variable.spec.current?.text ?? '',
       query: getDataQueryForVariable(variable),
-      datasource: variable.spec.datasource,
+      datasource: getRuntimeVariableDataSource(variable),
       sort: transformSortVariableToEnumV1(variable.spec.sort),
       refresh: transformVariableRefreshToEnumV1(variable.spec.refresh),
       regex: variable.spec.regex,
@@ -435,9 +386,17 @@ function createSceneVariableFromVariableModel(variable: TypedVariableModelV2): S
       hide: transformVariableHideToEnumV1(variable.spec.hide),
     });
   } else if (config.featureToggles.groupByVariable && variable.kind === defaultGroupByVariableKind().kind) {
+    const ds = getDataSourceForQuery(
+      {
+        type: variable.group,
+        uid: variable.datasource?.name,
+      },
+      variable.group
+    );
+
     return new GroupByVariable({
       ...commonProperties,
-      datasource: variable.spec.datasource,
+      datasource: ds,
       value: variable.spec.current?.value || [],
       text: variable.spec.current?.text || [],
       skipUrlSync: variable.spec.skipUrlSync,
@@ -485,6 +444,14 @@ export function createVariablesForSnapshot(dashboard: DashboardV2Spec): SceneVar
       try {
         // for adhoc we are using the AdHocFiltersVariable from scenes becuase of its complexity
         if (v.kind === 'AdhocVariable') {
+          const ds = getDataSourceForQuery(
+            {
+              type: v.group,
+              uid: v.datasource?.name,
+            },
+            v.group
+          );
+
           return new AdHocFiltersVariable({
             name: v.spec.name,
             label: v.spec.label,
@@ -492,7 +459,7 @@ export function createVariablesForSnapshot(dashboard: DashboardV2Spec): SceneVar
             description: v.spec.description,
             skipUrlSync: v.spec.skipUrlSync,
             hide: transformVariableHideToEnumV1(v.spec.hide),
-            datasource: v.spec.datasource,
+            datasource: ds,
             applyMode: 'auto',
             filters: v.spec.filters ?? [],
             baseFilters: v.spec.baseFilters ?? [],
@@ -500,7 +467,7 @@ export function createVariablesForSnapshot(dashboard: DashboardV2Spec): SceneVar
             useQueriesAsFilterForOptions: true,
             layout: config.featureToggles.newFiltersUI ? 'combobox' : undefined,
             supportsMultiValueOperators: Boolean(
-              getDataSourceSrv().getInstanceSettings(v.spec.datasource)?.meta.multiValueFilterOperators
+              getDataSourceSrv().getInstanceSettings(ds)?.meta.multiValueFilterOperators
             ),
           });
         }
@@ -568,3 +535,31 @@ export function getPanelElement(dashboard: DashboardV2Spec, elementName: string)
 export function getLibraryPanelElement(dashboard: DashboardV2Spec, elementName: string): LibraryPanelKind | undefined {
   return dashboard.elements[elementName].kind === 'LibraryPanel' ? dashboard.elements[elementName] : undefined;
 }
+function getGrafanaBuiltInAnnotationDataLayer(dashboard: DashboardV2Spec) {
+  const found = dashboard.annotations.some((item) => item.spec.builtIn);
+  if (found) {
+    return;
+  }
+
+  const grafanaBuiltAnnotation: AnnotationQueryKind = {
+    kind: 'AnnotationQuery',
+    spec: {
+      query: {
+        kind: 'DataQuery',
+        version: defaultDataQueryKind().version,
+        group: 'grafana',
+        datasource: {
+          name: '-- Grafana --',
+        },
+        spec: {},
+      },
+      name: 'Annotations & Alerts',
+      iconColor: DEFAULT_ANNOTATION_COLOR,
+      enable: true,
+      hide: true,
+      builtIn: true,
+    },
+  };
+
+  return grafanaBuiltAnnotation;
+}
