@@ -1,7 +1,7 @@
-import React from 'react';
-
+import { Trans, t } from '@grafana/i18n';
 import { ConfirmModal } from '@grafana/ui';
 import { useAppNotification } from 'app/core/copy/appNotification';
+import { DashboardInteractions } from 'app/features/dashboard-scene/utils/interactions';
 
 import { DecoratedRevisionModel } from '../VersionsEditView';
 
@@ -19,6 +19,7 @@ export const RevertDashboardModal = ({ hideModal, onRestore, version }: RevertDa
 
     if (success) {
       notifyApp.success('Dashboard restored', `Restored from version ${version.version}`);
+      DashboardInteractions.versionRestoreClicked({ version: version.version, confirm: true });
     } else {
       notifyApp.error('Dashboard restore failed', `Failed to restore from version ${version.version}`);
     }
@@ -29,16 +30,25 @@ export const RevertDashboardModal = ({ hideModal, onRestore, version }: RevertDa
   return (
     <ConfirmModal
       isOpen={true}
-      title="Restore Version"
+      title={t('dashboard-scene.revert-dashboard-modal.title-restore-version', 'Restore version')}
       icon="history"
       onDismiss={hideModal}
       onConfirm={onRestoreDashboard}
       body={
         <p>
-          Are you sure you want to restore the dashboard to version {version.version}? All unsaved changes will be lost.
+          <Trans
+            i18nKey="dashboard-scene.revert-dashboard-modal.body-restore-version"
+            values={{ version: version.version }}
+          >
+            Are you sure you want to restore the dashboard to version {'{{version}}'}? All unsaved changes will be lost.
+          </Trans>
         </p>
       }
-      confirmText={`Yes, restore to version ${version.version}`}
+      confirmText={t(
+        'dashboard-scene.revert-dashboard-modal.confirmText-restore-version',
+        'Yes, restore to version {{version}}',
+        { version: version.version }
+      )}
     />
   );
 };
