@@ -1,15 +1,16 @@
-import React, { ComponentProps } from 'react';
+import { ComponentProps } from 'react';
 
-import { config } from '@grafana/runtime';
-import { SceneComponentProps, SceneObjectBase, SceneObjectState, VizPanel, SceneObjectRef } from '@grafana/scenes';
+import { t } from '@grafana/i18n';
+import { config, locationService } from '@grafana/runtime';
+import { SceneComponentProps, SceneObjectBase, SceneObjectRef, SceneObjectState, VizPanel } from '@grafana/scenes';
 import { Modal, ModalTabsHeader, TabContent } from '@grafana/ui';
 import { contextSrv } from 'app/core/core';
-import { t } from 'app/core/internationalization';
 import { isPublicDashboardsEnabled } from 'app/features/dashboard/components/ShareModal/SharePublicDashboard/SharePublicDashboardUtils';
+import { AccessControlAction } from 'app/types/accessControl';
 
-import { DashboardScene } from '../scene/DashboardScene';
+import { getTrackingSource } from '../../dashboard/components/ShareModal/utils';
 import { DashboardInteractions } from '../utils/interactions';
-import { getDashboardSceneFor } from '../utils/utils';
+import { getDashboardSceneFor, isLibraryPanel } from '../utils/utils';
 
 import { ShareExportTab } from './ShareExportTab';
 import { ShareLibraryPanelTab } from './ShareLibraryPanelTab';
@@ -17,15 +18,21 @@ import { ShareLinkTab } from './ShareLinkTab';
 import { SharePanelEmbedTab } from './SharePanelEmbedTab';
 import { ShareSnapshotTab } from './ShareSnapshotTab';
 import { SharePublicDashboardTab } from './public-dashboards/SharePublicDashboardTab';
-import { ModalSceneObjectLike, SceneShareTab } from './types';
+import { ModalSceneObjectLike, SceneShareTab, SceneShareTabState } from './types';
 
 interface ShareModalState extends SceneObjectState {
-  dashboardRef: SceneObjectRef<DashboardScene>;
   panelRef?: SceneObjectRef<VizPanel>;
   tabs?: SceneShareTab[];
   activeTab: string;
 }
 
+type customDashboardTabType = new (...args: SceneShareTabState[]) => SceneShareTab;
+const customDashboardTabs: customDashboardTabType[] = [];
+
+export function addDashboardShareTab(tab: customDashboardTabType) {
+  customDashboardTabs.push(tab);
+}
+
 /**
  * Used for full dashboard share modal and the panel level share modal
  */
@@ -38,44 +45,65 @@ export class ShareModal extends SceneObjectBase<ShareModalState> implements Moda
       ...state,
     });
 
-    this.addActivationHandler(() => this.buildTabs());
+    this.addActivationHandler(() => this.buildTabs(state.activeTab));
   }
 
-  private buildTabs() {
-    const { dashboardRef, panelRef } = this.state;
+  private buildTabs(activeTab?: string) {
+    const { panelRef } = this.state;
+    const modalRef = this.getRef();
 
-    const tabs: SceneShareTab[] = [new ShareLinkTab({ dashboardRef, panelRef, modalRef: this.getRef() })];
+    const tabs: SceneShareTab[] = [new ShareLinkTab({ panelRef, modalRef })];
+    const dashboard = getDashboardSceneFor(this);
 
     if (!panelRef) {
-      tabs.push(new ShareExportTab({ dashboardRef, modalRef: this.getRef() }));
+      tabs.push(new ShareExportTab({ modalRef }));
     }
 
-    if (contextSrv.isSignedIn && config.snapshotEnabled) {
-      tabs.push(new ShareSnapshotTab({ panelRef, dashboardRef, modalRef: this.getRef() }));
+    if (
+      contextSrv.isSignedIn &&
+      config.snapshotEnabled &&
+      contextSrv.hasPermission(AccessControlAction.SnapshotsCreate)
+    ) {
+      tabs.push(new ShareSnapshotTab({ panelRef, dashboardRef: dashboard.getRef(), modalRef }));
     }
 
     if (panelRef) {
-      tabs.push(new SharePanelEmbedTab({ panelRef, dashboardRef }));
-
-      if (panelRef.resolve() instanceof VizPanel) {
-        tabs.push(new ShareLibraryPanelTab({ panelRef, dashboardRef, modalRef: this.getRef() }));
+      tabs.push(new SharePanelEmbedTab({ panelRef }));
+      const panel = panelRef.resolve();
+      if (panel instanceof VizPanel) {
+        if (!isLibraryPanel(panel)) {
+          tabs.push(new ShareLibraryPanelTab({ panelRef, modalRef }));
+        }
       }
     }
 
-    if (isPublicDashboardsEnabled()) {
-      tabs.push(new SharePublicDashboardTab({ dashboardRef, modalRef: this.getRef() }));
+    if (!panelRef) {
+      tabs.push(...customDashboardTabs.map((Tab) => new Tab({ modalRef })));
+
+      if (isPublicDashboardsEnabled()) {
+        tabs.push(new SharePublicDashboardTab({ modalRef }));
+      }
     }
 
-    this.setState({ tabs });
+    const at = tabs.find((t) => t.tabId === activeTab);
+
+    this.setState({ activeTab: at?.tabId ?? tabs[0].tabId, tabs });
   }
 
   onDismiss = () => {
-    const dashboard = getDashboardSceneFor(this);
-    dashboard.closeModal();
+    if (this.state.panelRef) {
+      const dashboard = getDashboardSceneFor(this);
+      dashboard.closeModal();
+    } else {
+      locationService.partial({ shareView: null });
+    }
   };
 
   onChangeTab: ComponentProps<typeof ModalTabsHeader>['onChangeTab'] = (tab) => {
-    DashboardInteractions.sharingTabChanged({ item: tab.value });
+    DashboardInteractions.sharingCategoryClicked({
+      item: tab.value,
+      shareResource: getTrackingSource(this.state.panelRef),
+    });
     this.setState({ activeTab: tab.value });
   };
 }
