@@ -1,14 +1,14 @@
 import { TimeRange } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { config } from '@grafana/runtime';
 import { SceneComponentProps, sceneGraph, SceneObjectBase, SceneObjectRef, VizPanel } from '@grafana/scenes';
-import { t } from 'app/core/internationalization';
 import { ShareEmbed } from 'app/features/dashboard/components/ShareModal/ShareEmbed';
 import { buildParams, shareDashboardType } from 'app/features/dashboard/components/ShareModal/utils';
 
 import { DashboardScene } from '../scene/DashboardScene';
 import { PanelTimeRange } from '../scene/PanelTimeRange';
 import { getDashboardUrl } from '../utils/getDashboardUrl';
-import { getDashboardSceneFor, getPanelIdForVizPanel } from '../utils/utils';
+import { getDashboardSceneFor } from '../utils/utils';
 
 import { SceneShareTabState } from './types';
 
@@ -37,17 +37,14 @@ function SharePanelEmbedTabRenderer({ model }: SceneComponentProps<SharePanelEmb
 
   const dash = getDashboardSceneFor(model);
   const { uid: dashUid } = dash.useState();
-  const id = getPanelIdForVizPanel(p);
   const timeRangeState = sceneGraph.getTimeRange(p);
 
   const timeFrom = timeRangeState instanceof PanelTimeRange ? timeRangeState.state.timeFrom : undefined;
 
   return (
     <ShareEmbed
-      panel={{
-        id,
-        timeFrom,
-      }}
+      panelId={p.getPathId()}
+      timeFrom={timeFrom}
       range={timeRangeState.state.value}
       dashboard={{ uid: dashUid ?? '', time: timeRangeState.state.value }}
       buildIframe={getIframeBuilder(dash)}
@@ -62,12 +59,13 @@ const getIframeBuilder =
     useCurrentTimeRange: boolean,
     _dashboardUid: string,
     selectedTheme?: string,
-    panel?: { timeFrom?: string; id: number },
+    panelId?: string,
+    timeFrom?: string,
     range?: TimeRange
   ) => {
-    const params = buildParams({ useCurrentTimeRange, selectedTheme, panel, range });
-    const panelId = params.get('editPanel') ?? params.get('viewPanel') ?? '';
-    params.set('panelId', panelId);
+    const params = buildParams({ useCurrentTimeRange, selectedTheme, panelId, timeFrom, range });
+    const editOrViewPanel = params.get('editPanel') ?? params.get('viewPanel') ?? '';
+    params.set('panelId', editOrViewPanel);
     params.delete('editPanel');
     params.delete('viewPanel');
     params.set('__feature.dashboardSceneSolo', 'true');
