@@ -3,7 +3,7 @@ import { ComponentType } from 'react';
 import { NavModel } from '@grafana/data';
 import { IconName } from '@grafana/ui';
 
-import { DashboardModel } from '../../state';
+import { DashboardModel } from '../../state/DashboardModel';
 
 export interface SettingsPage {
   id: string;
