@@ -1,13 +1,15 @@
 import { css } from '@emotion/css';
-import React, { useCallback, useEffect, useState } from 'react';
+import { useCallback, useState } from 'react';
+import * as React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { Button, Spinner, useStyles2, Tooltip, Toggletip, Text } from '@grafana/ui';
+import { llm } from '@grafana/llm';
+import { Button, Spinner, useStyles2, Tooltip, Toggletip, Text, Stack } from '@grafana/ui';
 
 import { GenAIHistory } from './GenAIHistory';
-import { StreamStatus, useOpenAIStream } from './hooks';
+import { StreamStatus, TIMEOUT, useLLMStream } from './hooks';
 import { AutoGenerateItem, EventTrackingSrc, reportAutoGenerateInteraction } from './tracking';
-import { OAI_MODEL, DEFAULT_OAI_MODEL, Message, sanitizeReply } from './utils';
+import { DEFAULT_LLM_MODEL, Message, sanitizeReply } from './utils';
 
 export interface GenAIButtonProps {
   // Button label text
@@ -22,11 +24,22 @@ export interface GenAIButtonProps {
   // Temperature for the LLM plugin. Default is 1.
   // Closer to 0 means more conservative, closer to 1 means more creative.
   temperature?: number;
-  model?: OAI_MODEL;
+  model?: llm.Model;
   // Event tracking source. Send as `src` to Rudderstack event
   eventTrackingSrc: EventTrackingSrc;
   // Whether the button should be disabled
   disabled?: boolean;
+  /*
+    Tooltip to show when hovering over the button
+    Tooltip will be shown only before the improvement stage.
+    i.e once the button title changes to "Improve", the tooltip will not be shown because
+    toggletip will be enabled.
+  */
+  tooltip?: string;
+  // Optional callback to receive history updates
+  onHistoryChange?: (history: string[]) => void;
+  // Optional timeout for the LLM stream. Default is 10 seconds
+  timeout?: number;
 }
 export const STOP_GENERATION_TEXT = 'Stop generating';
 
@@ -34,79 +47,84 @@ export const GenAIButton = ({
   text = 'Auto-generate',
   toggleTipTitle = '',
   onClick: onClickProp,
-  model = DEFAULT_OAI_MODEL,
+  model = DEFAULT_LLM_MODEL,
   messages,
   onGenerate,
   temperature = 1,
   eventTrackingSrc,
   disabled,
+  tooltip,
+  onHistoryChange,
+  timeout = TIMEOUT,
 }: GenAIButtonProps) => {
   const styles = useStyles2(getStyles);
 
-  const {
-    messages: streamMessages,
-    setMessages,
-    setStopGeneration,
-    reply,
-    value,
-    error,
-    streamStatus,
-  } = useOpenAIStream(model, temperature);
-
   const [history, setHistory] = useState<string[]>([]);
-  const [showHistory, setShowHistory] = useState(true);
+  const unshiftHistoryEntry = useCallback(
+    (historyEntry: string) => {
+      setHistory((h) => {
+        const newHistory = [historyEntry, ...h];
+        return newHistory;
+      });
+      onHistoryChange?.([historyEntry, ...history]);
+    },
+    [onHistoryChange, history]
+  );
 
+  const onResponse = useCallback(
+    (reply: string) => {
+      const sanitizedReply = sanitizeReply(reply);
+      onGenerate(sanitizedReply);
+      unshiftHistoryEntry(sanitizedReply);
+    },
+    [onGenerate, unshiftHistoryEntry]
+  );
+
+  const { setMessages, stopGeneration, value, error, streamStatus } = useLLMStream({
+    model,
+    temperature,
+    onResponse,
+    timeout,
+  });
+
+  const [showHistory, setShowHistory] = useState(false);
   const hasHistory = history.length > 0;
-  const isFirstHistoryEntry = streamStatus === StreamStatus.GENERATING && !hasHistory;
+  const isFirstHistoryEntry = !hasHistory;
+
+  const isGenerating = streamStatus === StreamStatus.GENERATING;
   const isButtonDisabled = disabled || (value && !value.enabled && !error);
-  const reportInteraction = (item: AutoGenerateItem) => reportAutoGenerateInteraction(eventTrackingSrc, item);
+  const reportInteraction = useCallback(
+    (item: AutoGenerateItem) => reportAutoGenerateInteraction(eventTrackingSrc, item),
+    [eventTrackingSrc]
+  );
+
+  const showTooltip = error || tooltip ? undefined : false;
+  const tooltipContent = error
+    ? 'Failed to generate content using LLM. Please try again or if the problem persists, contact your organization admin.'
+    : tooltip || '';
 
   const onClick = (e: React.MouseEvent<HTMLButtonElement>) => {
     if (streamStatus === StreamStatus.GENERATING) {
-      setStopGeneration(true);
+      stopGeneration();
     } else {
       if (!hasHistory) {
         onClickProp?.(e);
-        setMessages(typeof messages === 'function' ? messages() : messages);
+        setMessages(getMessages());
       } else {
-        if (setShowHistory) {
-          setShowHistory(true);
-        }
+        setShowHistory(true);
       }
     }
 
     const buttonItem = error
       ? AutoGenerateItem.erroredRetryButton
-      : isFirstHistoryEntry
+      : isGenerating
         ? AutoGenerateItem.stopGenerationButton
-        : hasHistory
-          ? AutoGenerateItem.improveButton
-          : AutoGenerateItem.autoGenerateButton;
+        : isFirstHistoryEntry
+          ? AutoGenerateItem.autoGenerateButton
+          : AutoGenerateItem.improveButton;
     reportInteraction(buttonItem);
   };
 
-  const pushHistoryEntry = useCallback(
-    (historyEntry: string) => {
-      if (history.indexOf(historyEntry) === -1) {
-        setHistory([historyEntry, ...history]);
-      }
-    },
-    [history]
-  );
-
-  useEffect(() => {
-    // Todo: Consider other options for `"` sanitation
-    if (isFirstHistoryEntry && reply) {
-      onGenerate(sanitizeReply(reply));
-    }
-  }, [streamStatus, reply, onGenerate, isFirstHistoryEntry]);
-
-  useEffect(() => {
-    if (streamStatus === StreamStatus.COMPLETED) {
-      pushHistoryEntry(sanitizeReply(reply));
-    }
-  }, [history, streamStatus, reply, pushHistoryEntry]);
-
   // The button is disabled if the plugin is not installed or enabled
   if (!value?.enabled) {
     return null;
@@ -119,12 +137,14 @@ export const GenAIButton = ({
   };
 
   const getIcon = () => {
-    if (isFirstHistoryEntry) {
+    if (isGenerating) {
       return undefined;
     }
-    if (error || (value && !value?.enabled)) {
+
+    if (error || (value && !value.enabled)) {
       return 'exclamation-circle';
     }
+
     return 'ai';
   };
 
@@ -135,7 +155,7 @@ export const GenAIButton = ({
       buttonText = 'Retry';
     }
 
-    if (isFirstHistoryEntry) {
+    if (isGenerating) {
       buttonText = STOP_GENERATION_TEXT;
     }
 
@@ -159,6 +179,8 @@ export const GenAIButton = ({
     </Button>
   );
 
+  const getMessages = () => (typeof messages === 'function' ? messages() : messages);
+
   const renderButtonWithToggletip = () => {
     if (hasHistory) {
       const title = <Text element="p">{toggleTipTitle}</Text>;
@@ -169,15 +191,18 @@ export const GenAIButton = ({
           content={
             <GenAIHistory
               history={history}
-              messages={streamMessages}
+              messages={getMessages()}
               onApplySuggestion={onApplySuggestion}
-              updateHistory={pushHistoryEntry}
+              updateHistory={unshiftHistoryEntry}
               eventTrackingSrc={eventTrackingSrc}
+              timeout={timeout}
             />
           }
-          placement="bottom-start"
+          placement="left-start"
           fitContent={true}
-          show={showHistory ? undefined : false}
+          show={showHistory}
+          onClose={() => setShowHistory(false)}
+          onOpen={() => setShowHistory(true)}
         >
           {button}
         </Toggletip>
@@ -188,28 +213,20 @@ export const GenAIButton = ({
   };
 
   return (
-    <div className={styles.wrapper}>
-      {isFirstHistoryEntry && <Spinner size="sm" className={styles.spinner} />}
-      {!hasHistory && (
-        <Tooltip
-          show={error ? undefined : false}
-          interactive
-          content={
-            'Failed to generate content using OpenAI. Please try again or if the problem persist, contact your organization admin.'
-          }
-        >
+    <Stack direction="row" gap={0.5} alignItems="center">
+      {isGenerating && <Spinner size="sm" className={styles.spinner} />}
+      {isFirstHistoryEntry ? (
+        <Tooltip show={showTooltip} interactive content={tooltipContent}>
           {button}
         </Tooltip>
+      ) : (
+        renderButtonWithToggletip()
       )}
-      {hasHistory && renderButtonWithToggletip()}
-    </div>
+    </Stack>
   );
 };
 
 const getStyles = (theme: GrafanaTheme2) => ({
-  wrapper: css({
-    display: 'flex',
-  }),
   spinner: css({
     color: theme.colors.text.link,
   }),
