@@ -1,16 +1,16 @@
 import { css } from '@emotion/css';
-import { useState, useCallback } from 'react';
+import { useState, useCallback, useRef } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { Alert, Button, Icon, Input, Stack, Text, TextLink, useStyles2 } from '@grafana/ui';
-import { Trans } from 'app/core/internationalization';
 
 import { STOP_GENERATION_TEXT } from './GenAIButton';
 import { GenerationHistoryCarousel } from './GenerationHistoryCarousel';
 import { QuickFeedback } from './QuickFeedback';
-import { StreamStatus, useOpenAIStream } from './hooks';
+import { StreamStatus, useLLMStream } from './hooks';
 import { AutoGenerateItem, EventTrackingSrc, reportAutoGenerateInteraction } from './tracking';
-import { getFeedbackMessage, Message, DEFAULT_OAI_MODEL, QuickFeedbackType, sanitizeReply } from './utils';
+import { getFeedbackMessage, Message, DEFAULT_LLM_MODEL, QuickFeedbackType, sanitizeReply } from './utils';
 
 export interface GenAIHistoryProps {
   history: string[];
@@ -18,6 +18,7 @@ export interface GenAIHistoryProps {
   onApplySuggestion: (suggestion: string) => void;
   updateHistory: (historyEntry: string) => void;
   eventTrackingSrc: EventTrackingSrc;
+  timeout?: number;
 }
 
 const temperature = 0.5;
@@ -28,12 +29,17 @@ export const GenAIHistory = ({
   messages,
   onApplySuggestion,
   updateHistory,
+  timeout,
 }: GenAIHistoryProps) => {
   const styles = useStyles2(getStyles);
 
   const [currentIndex, setCurrentIndex] = useState(1);
   const [customFeedback, setCustomPrompt] = useState('');
 
+  // Keep ref in sync with messages prop to avoid stale closure issues
+  const messagesRef = useRef(messages);
+  messagesRef.current = messages;
+
   const onResponse = useCallback(
     (response: string) => {
       updateHistory(sanitizeReply(response));
@@ -41,10 +47,11 @@ export const GenAIHistory = ({
     [updateHistory]
   );
 
-  const { setMessages, stopGeneration, reply, streamStatus, error } = useOpenAIStream({
-    model: DEFAULT_OAI_MODEL,
+  const { setMessages, stopGeneration, reply, streamStatus, error } = useLLMStream({
+    model: DEFAULT_LLM_MODEL,
     temperature,
     onResponse,
+    timeout,
   });
 
   const reportInteraction = (item: AutoGenerateItem, otherMetadata?: object) =>
@@ -70,7 +77,7 @@ export const GenAIHistory = ({
   };
 
   const onGenerateWithFeedback = (suggestion: string) => {
-    setMessages((messages) => [...messages, ...getFeedbackMessage(history[currentIndex - 1], suggestion)]);
+    setMessages(() => [...messagesRef.current, ...getFeedbackMessage(history[currentIndex - 1], suggestion)]);
 
     if (suggestion in QuickFeedbackType) {
       reportInteraction(AutoGenerateItem.quickFeedback, { quickFeedbackItem: suggestion });
@@ -104,19 +111,18 @@ export const GenAIHistory = ({
       )}
 
       <GenerationHistoryCarousel history={history} index={currentIndex} onNavigate={onNavigate} />
-
       <div className={styles.actionButtons}>
         <QuickFeedback onSuggestionClick={onGenerateWithFeedback} isGenerating={isStreamGenerating} />
       </div>
 
       <Input
-        placeholder="Tell AI what to do next..."
+        placeholder={t('dashboard.gen-aihistory.placeholder-tell-ai-what-to-do-next', 'Tell AI what to do next...')}
         suffix={
           <Button
             icon="enter"
             variant="secondary"
             fill="text"
-            aria-label="Send custom feedback"
+            aria-label={t('dashboard.gen-aihistory.aria-label-send-custom-feedback', 'Send custom feedback')}
             onClick={onClickSubmitCustomFeedback}
             disabled={!customFeedback}
           >
@@ -143,18 +149,20 @@ export const GenAIHistory = ({
       </div>
 
       <div className={styles.footer}>
-        <Icon name="exclamation-circle" aria-label="exclamation-circle" className={styles.infoColor} />
+        <Icon name="exclamation-circle" className={styles.infoColor} />
         <Text variant="bodySmall" color="secondary">
-          This content is AI-generated using the{' '}
-          <TextLink
-            variant="bodySmall"
-            inline={true}
-            href="https://grafana.com/docs/grafana-cloud/alerting-and-irm/machine-learning/llm-plugin/"
-            external
-            onClick={onClickDocs}
-          >
-            Grafana LLM plugin
-          </TextLink>
+          <Trans i18nKey="dashboard.gen-aihistory.footer-text">
+            This content is AI-generated using the{' '}
+            <TextLink
+              variant="bodySmall"
+              inline={true}
+              href="https://grafana.com/docs/grafana-cloud/alerting-and-irm/machine-learning/llm-plugin/"
+              external
+              onClick={onClickDocs}
+            >
+              Grafana LLM plugin
+            </TextLink>
+          </Trans>
         </Text>
       </div>
     </div>
