@@ -1,9 +1,9 @@
 import { css } from '@emotion/css';
-import React from 'react';
 
+import { Trans, t } from '@grafana/i18n';
 import { Button, Modal } from '@grafana/ui';
 
-import { DashboardModel } from '../../state';
+import { DashboardModel } from '../../state/DashboardModel';
 
 import { SaveDashboardButton } from './SaveDashboardButton';
 
@@ -18,20 +18,22 @@ export const UnsavedChangesModal = ({ dashboard, onSaveSuccess, onDiscard, onDis
   return (
     <Modal
       isOpen={true}
-      title="Unsaved changes"
+      title={t('dashboard.unsaved-changes-modal.title-unsaved-changes', 'Unsaved changes')}
       onDismiss={onDismiss}
       icon="exclamation-triangle"
-      className={css`
-        width: 500px;
-      `}
+      className={css({
+        width: '500px',
+      })}
     >
-      <h5>Do you want to save your changes?</h5>
+      <h5>
+        <Trans i18nKey="dashboard.unsaved-changes-modal.changes">Do you want to save your changes?</Trans>
+      </h5>
       <Modal.ButtonRow>
         <Button variant="secondary" onClick={onDismiss} fill="outline">
-          Cancel
+          <Trans i18nKey="dashboard.unsaved-changes-modal.cancel">Cancel</Trans>
         </Button>
         <Button variant="destructive" onClick={onDiscard}>
-          Discard
+          <Trans i18nKey="dashboard.unsaved-changes-modal.discard">Discard</Trans>
         </Button>
         <SaveDashboardButton dashboard={dashboard} onSaveSuccess={onSaveSuccess} />
       </Modal.ButtonRow>
