@@ -1,7 +1,7 @@
 import { css, cx } from '@emotion/css';
-import React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { Button, ModalsController, CollapsableSection, useStyles2, Stack, Icon, Box } from '@grafana/ui';
 import { DiffGroup } from 'app/features/dashboard-scene/settings/version-history/DiffGroup';
 import { DiffViewer } from 'app/features/dashboard-scene/settings/version-history/DiffViewer';
@@ -27,12 +27,22 @@ export const VersionHistoryComparison = ({ baseInfo, newInfo, diffData, isNewLat
       <Stack justifyContent="space-between" alignItems="center">
         <Stack alignItems="center">
           <span className={cx(styles.versionInfo, styles.noMarginBottom)}>
-            <strong>Version {baseInfo.version}</strong> updated by {baseInfo.createdBy} {baseInfo.ageString}
+            <Trans
+              i18nKey="dashboard.version-history-comparison.old-updated-by"
+              values={{ version: baseInfo.version, editor: baseInfo.createdBy, timeAgo: baseInfo.ageString }}
+            >
+              <strong>Version {'{{version}}'}</strong> updated by {'{{editor}}'} {'{{timeAgo}}'}
+            </Trans>
             {baseInfo.message}
           </span>
           <Icon name="arrow-right" size="sm" />
           <span className={styles.versionInfo}>
-            <strong>Version {newInfo.version}</strong> updated by {newInfo.createdBy} {newInfo.ageString}
+            <Trans
+              i18nKey="dashboard.version-history-comparison.new-updated-by"
+              values={{ version: newInfo.version, editor: newInfo.createdBy, timeAgo: newInfo.ageString }}
+            >
+              <strong>Version {'{{version}}'}</strong> updated by {'{{editor}}'} {'{{timeAgo}}'}
+            </Trans>
             {newInfo.message}
           </span>
         </Stack>
@@ -44,12 +54,18 @@ export const VersionHistoryComparison = ({ baseInfo, newInfo, diffData, isNewLat
                 icon="history"
                 onClick={() => {
                   showModal(RevertDashboardModal, {
+                    id: baseInfo.id,
                     version: baseInfo.version,
                     hideModal,
                   });
                 }}
               >
-                Restore to version {baseInfo.version}
+                <Trans
+                  i18nKey="dashboard.version-history-comparison.button-restore"
+                  values={{ version: baseInfo.version }}
+                >
+                  Restore to version {'{{version}}'}
+                </Trans>
               </Button>
             )}
           </ModalsController>
@@ -61,7 +77,10 @@ export const VersionHistoryComparison = ({ baseInfo, newInfo, diffData, isNewLat
       ))}
 
       <Box paddingTop={2}>
-        <CollapsableSection isOpen={false} label="View JSON Diff">
+        <CollapsableSection
+          isOpen={false}
+          label={t('dashboard.version-history-comparison.label-view-json-diff', 'View JSON diff')}
+        >
           <DiffViewer
             oldValue={JSON.stringify(diffData.lhs, null, 2)}
             newValue={JSON.stringify(diffData.rhs, null, 2)}
