@@ -1,9 +1,10 @@
 import { useEffect, useState } from 'react';
 import { useParams } from 'react-router-dom-v5-compat';
 
+import { Trans } from '@grafana/i18n';
 import { getDataSourceSrv, locationService } from '@grafana/runtime';
 import { Page } from 'app/core/components/Page/Page';
-import { useDispatch } from 'app/types';
+import { useDispatch } from 'app/types/store';
 
 import { setInitialDatasource } from '../state/reducers';
 
@@ -28,7 +29,11 @@ export default function NewDashboardWithDS() {
     return (
       <Page navId="dashboards">
         <Page.Contents>
-          <div>Data source with UID &quot;{datasourceUid}&quot; not found.</div>
+          <div>
+            <Trans i18nKey="dashboard.new-dashboard-with-ds.not-found">
+              Data source with UID &quot;{{ datasourceUid }}&quot; not found.
+            </Trans>
+          </div>
         </Page.Contents>
       </Page>
     );
