@@ -1,7 +1,8 @@
+import { DashboardRoutes } from 'app/types/dashboard';
+
 import { SafeDynamicImport } from '../../core/components/DynamicImports/SafeDynamicImport';
 import { config } from '../../core/config';
 import { RouteDescriptor } from '../../core/navigation/types';
-import { DashboardRoutes } from '../../types';
 
 export const getPublicDashboardRoutes = (): RouteDescriptor[] => {
   if (!config.publicDashboardsEnabled) {
