@@ -1,19 +1,18 @@
 import { each, map } from 'lodash';
 
-import { DataLinkBuiltInVars, MappingType } from '@grafana/data';
-import { getPanelPlugin } from '@grafana/data/test/__mocks__/pluginMocks';
-import { setDataSourceSrv } from '@grafana/runtime';
+import { DataLinkBuiltInVars, MappingType, VariableHide } from '@grafana/data';
+import { getPanelPlugin } from '@grafana/data/test';
 import { FieldConfigSource } from '@grafana/schema';
 import { config } from 'app/core/config';
 import { GRID_CELL_HEIGHT, GRID_CELL_VMARGIN } from 'app/core/constants';
-import { mockDataSource, MockDataSourceSrv } from 'app/features/alerting/unified/mocks';
+import { mockDataSource } from 'app/features/alerting/unified/mocks';
+import { setupDataSources } from 'app/features/alerting/unified/testSetup/datasources';
 import { MIXED_DATASOURCE_NAME } from 'app/plugins/datasource/mixed/MixedDataSource';
 
-import { VariableHide } from '../../variables/types';
 import { DashboardModel } from '../state/DashboardModel';
 import { PanelModel } from '../state/PanelModel';
 
-jest.mock('app/core/services/context_srv', () => ({}));
+import { DASHBOARD_SCHEMA_VERSION } from './DashboardMigrator';
 
 const dataSources = {
   prom: mockDataSource({
@@ -40,15 +39,14 @@ const dataSources = {
   }),
 };
 
-setDataSourceSrv(new MockDataSourceSrv(dataSources));
+setupDataSources(...Object.values(dataSources));
 
 describe('DashboardModel', () => {
   describe('when creating dashboard with old schema', () => {
-    let model: any;
+    let model: DashboardModel;
     let graph: any;
-    let singlestat: any;
     let table: any;
-    let singlestatGauge: any;
+    const panelIdWithRepeatId = 500;
 
     config.panels = {
       stat: getPanelPlugin({ id: 'stat' }).meta,
@@ -58,17 +56,18 @@ describe('DashboardModel', () => {
     beforeEach(() => {
       model = new DashboardModel({
         services: {
-          filter: { time: { from: 'now-1d', to: 'now' }, list: [{}] },
+          filter: { time: { from: 'now-1d', to: 'now' }, list: [{ name: 'server' }] },
         },
         pulldowns: [
           { type: 'filtering', enable: true },
           { type: 'annotations', enable: true, annotations: [{ name: 'old' }] },
         ],
+        style: 'dark',
         panels: [
           {
             type: 'graph',
-            legend: { show: true },
             // @ts-expect-error
+            legend: { show: true },
             aliasYAxis: { test: 2 },
             y_formats: ['kbyte', 'ms'],
             grid: {
@@ -115,12 +114,34 @@ describe('DashboardModel', () => {
             styles: [{ thresholds: ['10', '20', '30'] }, { thresholds: ['100', '200', '300'] }],
             targets: [{ refId: 'A' }, {}],
           },
+          // Old left-over repeated panel
+          {
+            type: 'table',
+            id: panelIdWithRepeatId,
+            // @ts-expect-error
+            repeatPanelId: 1,
+          },
+          // Collapsed row with left-over repeated panels
+          {
+            type: 'row',
+            panels: [
+              {
+                id: 501,
+                type: 'table',
+                repeat: 'server',
+              },
+              // Old left-over repeated panel
+              {
+                id: 502,
+                // @ts-expect-error
+                repeatedPanelId: 501,
+              },
+            ],
+          },
         ],
       });
 
       graph = model.panels[0];
-      singlestat = model.panels[1];
-      singlestatGauge = model.panels[2];
       table = model.panels[3];
     });
 
@@ -129,28 +150,16 @@ describe('DashboardModel', () => {
     });
 
     it('should have panel id', () => {
-      expect(graph.id).toBe(1);
+      expect(graph.id).toBe(503);
+    });
+
+    it('should not have style', () => {
+      expect(model.style).toBe(undefined);
     });
 
     it('should move time and filtering list', () => {
       expect(model.time.from).toBe('now-1d');
-      expect(model.templating.list[0].allFormat).toBe('glob');
-    });
-
-    it('graphite panel should change name too graph', () => {
-      expect(graph.type).toBe('graph');
-    });
-
-    it('singlestat panel should be mapped to stat panel', () => {
-      expect(singlestat.type).toBe('stat');
-      expect(singlestat.fieldConfig.defaults.thresholds.steps[2].value).toBe(30);
-      expect(singlestat.fieldConfig.defaults.thresholds.steps[0].color).toBe('#FF0000');
-    });
-
-    it('singlestat panel should be mapped to gauge panel', () => {
-      expect(singlestatGauge.type).toBe('gauge');
-      expect(singlestatGauge.options.showThresholdMarkers).toBe(true);
-      expect(singlestatGauge.options.showThresholdLabels).toBe(false);
+      expect(model.templating.list[0].name).toBe('server');
     });
 
     it('queries without refId should get it', () => {
@@ -161,11 +170,6 @@ describe('DashboardModel', () => {
       expect(graph.legend.show).toBe(true);
     });
 
-    it('move aliasYAxis to series override', () => {
-      expect(graph.seriesOverrides[0].alias).toBe('test');
-      expect(graph.seriesOverrides[0].yaxis).toBe(2);
-    });
-
     it('should move pulldowns to new schema', () => {
       expect(model.annotations.list[1].name).toBe('old');
     });
@@ -178,58 +182,15 @@ describe('DashboardModel', () => {
     });
 
     it('table type should be deprecated', () => {
-      expect(table.type).toBe('table-old');
-    });
-
-    it('graph grid to yaxes options', () => {
-      expect(graph.yaxes[0].min).toBe(1);
-      expect(graph.yaxes[0].max).toBe(10);
-      expect(graph.yaxes[0].format).toBe('kbyte');
-      expect(graph.yaxes[0].label).toBe('left label');
-      expect(graph.yaxes[0].logBase).toBe(1);
-      expect(graph.yaxes[1].min).toBe(5);
-      expect(graph.yaxes[1].max).toBe(15);
-      expect(graph.yaxes[1].format).toBe('ms');
-      expect(graph.yaxes[1].logBase).toBe(2);
-
-      expect(graph.grid.rightMax).toBe(undefined);
-      expect(graph.grid.rightLogBase).toBe(undefined);
-      expect(graph.y_formats).toBe(undefined);
+      expect(table.type).toBe('table');
     });
 
     it('dashboard schema version should be set to latest', () => {
-      expect(model.schemaVersion).toBe(38);
+      expect(model.schemaVersion).toBe(DASHBOARD_SCHEMA_VERSION);
     });
 
-    it('graph thresholds should be migrated', () => {
-      expect(graph.thresholds.length).toBe(2);
-      expect(graph.thresholds[0].op).toBe('gt');
-      expect(graph.thresholds[0].value).toBe(200);
-      expect(graph.thresholds[0].fillColor).toBe('yellow');
-      expect(graph.thresholds[1].value).toBe(400);
-      expect(graph.thresholds[1].fillColor).toBe('red');
-    });
-
-    it('graph thresholds should be migrated onto specified thresholds', () => {
-      model = new DashboardModel({
-        panels: [
-          {
-            type: 'graph',
-            // @ts-expect-error
-            y_formats: ['kbyte', 'ms'],
-            grid: {
-              threshold1: 200,
-              threshold2: 400,
-            },
-            thresholds: [{ value: 100 }],
-          },
-        ],
-      });
-      graph = model.panels[0];
-      expect(graph.thresholds.length).toBe(3);
-      expect(graph.thresholds[0].value).toBe(100);
-      expect(graph.thresholds[1].value).toBe(200);
-      expect(graph.thresholds[2].value).toBe(400);
+    it('Shoud ignore repeated panels', () => {
+      expect(model.getPanelById(panelIdWithRepeatId)).toBe(null);
     });
   });
 
@@ -481,7 +442,7 @@ describe('DashboardModel', () => {
   });
 
   describe('when migrating panel links', () => {
-    let model: any;
+    let model: DashboardModel;
 
     beforeEach(() => {
       model = new DashboardModel({
@@ -528,24 +489,26 @@ describe('DashboardModel', () => {
     });
 
     it('should add keepTime as variable', () => {
-      expect(model.panels[0].links[0].url).toBe(`http://mylink.com?$${DataLinkBuiltInVars.keepTime}`);
+      expect(model.panels[0].links?.[0].url).toBe(`http://mylink.com?$${DataLinkBuiltInVars.keepTime}`);
     });
 
     it('should add params to url', () => {
-      expect(model.panels[0].links[1].url).toBe('http://mylink.com?existingParam&customParam');
+      expect(model.panels[0].links?.[1].url).toBe('http://mylink.com?existingParam&customParam');
     });
 
     it('should add includeVars to url', () => {
-      expect(model.panels[0].links[2].url).toBe(`http://mylink.com?existingParam&$${DataLinkBuiltInVars.includeVars}`);
+      expect(model.panels[0].links?.[2].url).toBe(
+        `http://mylink.com?existingParam&$${DataLinkBuiltInVars.includeVars}`
+      );
     });
 
     it('should slugify dashboard name', () => {
-      expect(model.panels[0].links[3].url).toBe(`dashboard/db/my-other-dashboard`);
+      expect(model.panels[0].links?.[3].url).toBe(`dashboard/db/my-other-dashboard`);
     });
   });
 
   describe('when migrating variables', () => {
-    let model: any;
+    let model: DashboardModel;
     beforeEach(() => {
       model = new DashboardModel({
         panels: [
@@ -612,7 +575,7 @@ describe('DashboardModel', () => {
   });
 
   describe('when migrating labels from DataFrame to Field', () => {
-    let model: any;
+    let model: DashboardModel;
     beforeEach(() => {
       model = new DashboardModel({
         panels: [
@@ -810,7 +773,6 @@ describe('DashboardModel', () => {
               '# Angular Text Panel\n# $constant\n\nFor markdown syntax help: [commonmark.org/help](https://commonmark.org/help/)\n\n## $text\n\n',
             mode: 'markdown',
           },
-          // @ts-expect-error
           {
             id: 3,
             type: 'text2',
@@ -821,7 +783,6 @@ describe('DashboardModel', () => {
                 '# React Text Panel from scratch\n# $constant\n\nFor markdown syntax help: [commonmark.org/help](https://commonmark.org/help/)\n\n## $text',
             },
           },
-          // @ts-expect-error
           {
             id: 4,
             type: 'text2',
@@ -858,7 +819,7 @@ describe('DashboardModel', () => {
     });
 
     it('should migrate panels with new Text Panel id', () => {
-      const reactPanel: any = model.panels[1];
+      const reactPanel = model.panels[1];
       expect(reactPanel.id).toEqual(3);
       expect(reactPanel.type).toEqual('text');
       expect(reactPanel.title).toEqual('React Text Panel from scratch');
@@ -869,7 +830,7 @@ describe('DashboardModel', () => {
     });
 
     it('should clean up old angular options for panels with new Text Panel id', () => {
-      const reactPanel: any = model.panels[2];
+      const reactPanel = model.panels[2];
       expect(reactPanel.id).toEqual(4);
       expect(reactPanel.type).toEqual('text');
       expect(reactPanel.title).toEqual('React Text Panel from Angular Panel');
@@ -886,58 +847,55 @@ describe('DashboardModel', () => {
 
     beforeEach(() => {
       model = new DashboardModel({
+        editable: true,
+        graphTooltip: 0,
+        schemaVersion: 10,
         templating: {
           list: [
-            // @ts-expect-error
             {
+              name: 'server1',
               type: 'query',
               hide: VariableHide.dontHide,
               datasource: null,
-              allFormat: '',
             },
-            // @ts-expect-error
             {
+              name: 'server2',
               type: 'query',
               hide: VariableHide.hideLabel,
               datasource: null,
-              allFormat: '',
             },
-            // @ts-expect-error
             {
+              name: 'server3',
               type: 'query',
               hide: VariableHide.hideVariable,
               datasource: null,
-              allFormat: '',
             },
-            // @ts-expect-error
             {
+              name: 'server4',
               type: 'constant',
               hide: VariableHide.dontHide,
               query: 'default value',
               current: { selected: true, text: 'A', value: 'B' },
               options: [{ selected: true, text: 'A', value: 'B' }],
               datasource: null,
-              allFormat: '',
             },
-            // @ts-expect-error
             {
+              name: 'server5',
               type: 'constant',
               hide: VariableHide.hideLabel,
               query: 'default value',
               current: { selected: true, text: 'A', value: 'B' },
               options: [{ selected: true, text: 'A', value: 'B' }],
               datasource: null,
-              allFormat: '',
             },
-            // @ts-expect-error
             {
+              name: 'server6',
               type: 'constant',
               hide: VariableHide.hideVariable,
               query: 'default value',
               current: { selected: true, text: 'A', value: 'B' },
               options: [{ selected: true, text: 'A', value: 'B' }],
               datasource: null,
-              allFormat: '',
             },
           ],
         },
@@ -956,34 +914,34 @@ describe('DashboardModel', () => {
 
     it('should migrate visible constant variables to textbox variables', () => {
       expect(model.templating.list[3]).toEqual({
+        name: 'server4',
         type: 'textbox',
         hide: VariableHide.dontHide,
         query: 'default value',
         current: { selected: true, text: 'default value', value: 'default value' },
         options: [{ selected: true, text: 'default value', value: 'default value' }],
         datasource: null,
-        allFormat: '',
       });
       expect(model.templating.list[4]).toEqual({
+        name: 'server5',
         type: 'textbox',
         hide: VariableHide.hideLabel,
         query: 'default value',
         current: { selected: true, text: 'default value', value: 'default value' },
         options: [{ selected: true, text: 'default value', value: 'default value' }],
         datasource: null,
-        allFormat: '',
       });
     });
 
     it('should change current and options for hidden constant variables', () => {
       expect(model.templating.list[5]).toEqual({
+        name: 'server6',
         type: 'constant',
         hide: VariableHide.hideVariable,
         query: 'default value',
         current: { selected: true, text: 'default value', value: 'default value' },
         options: [{ selected: true, text: 'default value', value: 'default value' }],
         datasource: null,
-        allFormat: '',
       });
     });
   });
@@ -993,95 +951,86 @@ describe('DashboardModel', () => {
 
     beforeEach(() => {
       model = new DashboardModel({
+        editable: true,
+        graphTooltip: 0,
+        schemaVersion: 20,
         templating: {
           list: [
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_never_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
               refresh: 0,
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_never_refresh_without_options',
               options: [],
               refresh: 0,
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_dashboard_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
               refresh: 1,
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_dashboard_refresh_without_options',
               options: [],
               refresh: 1,
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_timerange_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
               refresh: 2,
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_timerange_refresh_without_options',
               options: [],
               refresh: 2,
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_no_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_no_refresh_without_options',
               options: [],
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_unknown_refresh_with_options',
               options: [{ text: 'A', value: 'A' }],
+              // @ts-expect-error
               refresh: 2001,
             },
-            // @ts-expect-error
             {
               type: 'query',
               name: 'variable_with_unknown_refresh_without_options',
               options: [],
+              // @ts-expect-error
               refresh: 2001,
             },
-            // @ts-expect-error
             {
               type: 'custom',
               name: 'custom',
               options: [{ text: 'custom', value: 'custom' }],
             },
-            // @ts-expect-error
             {
               type: 'textbox',
               name: 'textbox',
               options: [{ text: 'Hello', value: 'World' }],
             },
-            // @ts-expect-error
             {
               type: 'datasource',
               name: 'datasource',
               options: [{ text: 'ds', value: 'ds' }], // fake example doesn't exist
             },
-            // @ts-expect-error
             {
               type: 'interval',
               name: 'interval',
@@ -1092,7 +1041,7 @@ describe('DashboardModel', () => {
       });
     });
 
-    it('should have 11 variables after migration', () => {
+    it('should have 14 variables after migration', () => {
       expect(model.templating.list.length).toBe(14);
     });
 
@@ -1328,7 +1277,7 @@ describe('DashboardModel', () => {
   });
 
   describe('when migrating singlestat value mappings', () => {
-    it('should migrate value mapping', () => {
+    it.skip('should migrate value mapping', () => {
       const model = new DashboardModel({
         panels: [
           {
@@ -1390,7 +1339,7 @@ describe('DashboardModel', () => {
       `);
     });
 
-    it('should migrate range mapping', () => {
+    it.skip('should migrate range mapping', () => {
       const model = new DashboardModel({
         panels: [
           {
@@ -1542,7 +1491,7 @@ describe('DashboardModel', () => {
   });
 
   describe('migrating legacy CloudWatch queries', () => {
-    let model: any;
+    let model: DashboardModel;
     let panelTargets: any;
 
     beforeEach(() => {
@@ -1573,7 +1522,6 @@ describe('DashboardModel', () => {
           ],
         },
         panels: [
-          // @ts-expect-error
           {
             gridPos: {
               h: 8,
@@ -1696,7 +1644,6 @@ describe('DashboardModel', () => {
               title: 'DynamoDB',
               type: 'row',
               panels: [
-                // @ts-expect-error
                 {
                   gridPos: {
                     h: 8,
@@ -1751,7 +1698,6 @@ describe('DashboardModel', () => {
                   title: 'Panel Title',
                   type: 'timeseries',
                 },
-                // @ts-expect-error
                 {
                   gridPos: {
                     h: 8,
@@ -1898,6 +1844,16 @@ describe('DashboardModel', () => {
               },
             ],
           },
+          // @ts-expect-error
+          {
+            id: 7,
+            datasource: { type: 'prometheus', uid: 'prom-uid' },
+          },
+          // @ts-expect-error
+          {
+            id: 8,
+            datasource: { type: 'prometheus' },
+          },
         ],
       });
     });
@@ -1927,6 +1883,14 @@ describe('DashboardModel', () => {
     it('should update datasources in panels collapsed rows', () => {
       expect(model.panels[3].panels?.[0].datasource).toEqual({ type: 'prometheus', uid: 'prom-uid' });
     });
+
+    it("should not migrate datasource if it's already a ref", () => {
+      expect(model.panels[4].datasource).toEqual({ type: 'prometheus', uid: 'prom-uid' });
+    });
+
+    it("should not migrate datasource if it's already a ref with only a type", () => {
+      expect(model.panels[5].datasource).toEqual({ type: 'prometheus' });
+    });
   });
 
   describe('when fixing query and panel data source refs out of sync due to default data source change', () => {
@@ -1961,8 +1925,8 @@ describe('DashboardModel', () => {
   describe('when migrating time series axis visibility', () => {
     test('preserves x axis visibility', () => {
       const model = new DashboardModel({
+        schemaVersion: 25,
         panels: [
-          // @ts-expect-error
           {
             type: 'timeseries',
             fieldConfig: {
@@ -2003,7 +1967,6 @@ describe('DashboardModel', () => {
       model = new DashboardModel({
         templating: {
           list: [
-            // @ts-expect-error
             {
               type: 'query',
               name: 'var',
@@ -2184,7 +2147,6 @@ describe('when migrating table cell display mode to cell options', () => {
   beforeEach(() => {
     model = new DashboardModel({
       panels: [
-        // @ts-expect-error
         {
           id: 1,
           type: 'table',
@@ -2196,9 +2158,8 @@ describe('when migrating table cell display mode to cell options', () => {
                 inspect: false,
               },
             },
-          } as unknown as FieldConfigSource, // missing overrides
+          } as unknown as FieldConfigSource, // missing overrides on purpose
         },
-        // @ts-expect-error
         {
           id: 2,
           type: 'table',
@@ -2213,7 +2174,6 @@ describe('when migrating table cell display mode to cell options', () => {
             overrides: [],
           },
         },
-        // @ts-expect-error
         {
           id: 3,
           type: 'table',
@@ -2228,7 +2188,6 @@ describe('when migrating table cell display mode to cell options', () => {
             overrides: [],
           },
         },
-        // @ts-expect-error
         {
           id: 4,
           type: 'table',
@@ -2243,7 +2202,6 @@ describe('when migrating table cell display mode to cell options', () => {
             overrides: [],
           },
         },
-        // @ts-expect-error
         {
           id: 5,
           type: 'table',
@@ -2258,7 +2216,6 @@ describe('when migrating table cell display mode to cell options', () => {
             overrides: [],
           },
         },
-        // @ts-expect-error
         {
           id: 6,
           type: 'table',
@@ -2326,7 +2283,6 @@ describe('when migrating table cell display mode to cell options', () => {
             ],
           },
         },
-        // @ts-expect-error
         {
           id: 7,
           type: 'table',
@@ -2401,6 +2357,110 @@ describe('when migrating table cell display mode to cell options', () => {
   });
 });
 
+describe('when migrating variable refresh to on dashboard load', () => {
+  let model: DashboardModel;
+
+  beforeEach(() => {
+    model = new DashboardModel({
+      //@ts-ignore
+      refresh: false,
+    });
+  });
+
+  it('should migrate to empty string', () => {
+    expect(model.refresh).toBe('');
+  });
+});
+
+describe('when migrating time_options in timepicker', () => {
+  let model: DashboardModel;
+
+  it('should remove the property', () => {
+    model = new DashboardModel({
+      timepicker: {
+        //@ts-expect-error
+        time_options: ['5m', '15m', '1h', '6h', '12h', '24h', '2d', '7d', '30d'],
+      },
+    });
+
+    expect(model.timepicker).not.toHaveProperty('time_options');
+  });
+
+  it('should not throw with empty timepicker', () => {
+    //@ts-expect-error
+    model = new DashboardModel({});
+
+    expect(model.timepicker).not.toHaveProperty('time_options');
+  });
+});
+
+describe('when migrating table panels at schema version 24', () => {
+  let model: DashboardModel;
+
+  afterEach(() => {
+    model = new DashboardModel({
+      panels: [],
+      schemaVersion: 23,
+    });
+  });
+
+  it('should migrate Angular table to table and set autoMigrateFrom', () => {
+    model = new DashboardModel({
+      panels: [
+        {
+          id: 1,
+          type: 'table',
+          // @ts-expect-error
+          legend: true,
+          styles: [{ thresholds: ['10', '20', '30'] }, { thresholds: ['100', '200', '300'] }],
+          targets: [{ refId: 'A' }, {}],
+        },
+      ],
+      schemaVersion: 23,
+    });
+
+    // Verify the panel was migrated to table, yes this is intentional
+    // when autoMigrateOldPanels is enabled, we should migrate to table
+    // and add the autoMigrateFrom property
+    expect(model.panels[0].type).toBe('table');
+    // Verify autoMigrateFrom was set
+    expect(model.panels[0].autoMigrateFrom).toBe('table-old');
+  });
+
+  it('should not migrate Angular table without styles', () => {
+    model = new DashboardModel({
+      panels: [
+        {
+          id: 1,
+          type: 'table',
+          // No styles property
+        },
+      ],
+      schemaVersion: 23,
+    });
+
+    // Verify the panel was not migrated
+    expect(model.panels[0].type).toBe('table');
+    expect(model.panels[0].autoMigrateFrom).toBeUndefined();
+  });
+
+  it('should not migrate React table (table2)', () => {
+    model = new DashboardModel({
+      panels: [
+        {
+          id: 1,
+          type: 'table2',
+        },
+      ],
+      schemaVersion: 23,
+    });
+
+    // Verify the panel was not migrated
+    expect(model.panels[0].type).toBe('table2');
+    expect(model.panels[0].autoMigrateFrom).toBeUndefined();
+  });
+});
+
 function createRow(options: any, panelDescriptions: any[]) {
   const PANEL_HEIGHT_STEP = GRID_CELL_HEIGHT + GRID_CELL_VMARGIN;
   const { collapse, showTitle, title, repeat, repeatIteration } = options;
