@@ -9,9 +9,9 @@ import {
   dateTime,
   TimeRange,
   PanelMigrationHandler,
+  PanelTypeChangedHandler,
 } from '@grafana/data';
-import { getPanelPlugin } from '@grafana/data/test/__mocks__/pluginMocks';
-import { mockStandardFieldConfigOptions } from '@grafana/data/test/helpers/fieldConfig';
+import { getPanelPlugin, mockStandardFieldConfigOptions } from '@grafana/data/test';
 import { setTemplateSrv } from '@grafana/runtime';
 import { queryBuilder } from 'app/features/variables/shared/testing/builders';
 
@@ -43,15 +43,14 @@ variableAdapters.setInit(() => [createQueryVariableAdapter()]);
 describe('PanelModel', () => {
   describe('when creating new panel model', () => {
     let model: any;
-    let modelJson: any;
+    let modelJson: Record<string, unknown>;
     let persistedOptionsMock;
 
     const tablePlugin = getPanelPlugin(
       {
         id: 'table',
       },
-      null as unknown as ComponentClass<PanelProps>, // react
-      {} // angular
+      getPanelPlugin({ id: 'react-base' }) as unknown as ComponentClass<PanelProps> // react
     );
 
     tablePlugin.setPanelOptions((builder) => {
@@ -147,12 +146,16 @@ describe('PanelModel', () => {
 
     describe('migrations', () => {
       let initialMigrator: PanelMigrationHandler<(typeof model)['options']> | undefined = undefined;
+      // eslint-disable-next-line @typescript-eslint/no-explicit-any
+      let initialShouldMigrate: ((panel: any) => boolean) | undefined = undefined;
 
       beforeEach(() => {
         initialMigrator = tablePlugin.onPanelMigration;
+        initialShouldMigrate = tablePlugin.shouldMigrate;
       });
       afterEach(() => {
         tablePlugin.onPanelMigration = initialMigrator;
+        tablePlugin.shouldMigrate = initialShouldMigrate;
       });
 
       it('should run sync migrations', async () => {
@@ -180,6 +183,58 @@ describe('PanelModel', () => {
         await model.pluginLoaded(tablePlugin);
         expect(model.options).toMatchObject({ valueToMigrate: 'new-version' });
       });
+
+      it('should run migration when shouldMigrate=true and same version', async () => {
+        model.options.valueToMigrate = 'old-legacy';
+        model.pluginVersion = '1.0.0';
+
+        tablePlugin.meta.info.version = '1.0.0';
+        tablePlugin.onPanelMigration = (p) => ({ ...p.options, valueToMigrate: 'migrated-by-shouldMigrate' });
+        tablePlugin.shouldMigrate = () => true;
+
+        await model.pluginLoaded(tablePlugin);
+
+        expect(model.options).toMatchObject({ valueToMigrate: 'migrated-by-shouldMigrate' });
+      });
+
+      it('should run migration when shouldMigrate=false and versions are different', async () => {
+        model.options.valueToMigrate = 'old-legacy';
+        model.pluginVersion = '1.0.0';
+
+        tablePlugin.meta.info.version = '2.0.0';
+        tablePlugin.onPanelMigration = (p) => ({ ...p.options, valueToMigrate: 'migrated-by-version' });
+        tablePlugin.shouldMigrate = () => false;
+
+        await model.pluginLoaded(tablePlugin);
+
+        expect(model.options).toMatchObject({ valueToMigrate: 'migrated-by-version' });
+      });
+
+      it('should fallback to version comparison when shouldMigrate is false', async () => {
+        model.options.valueToMigrate = 'old-legacy';
+        model.pluginVersion = '1.0.0';
+
+        tablePlugin.meta.info.version = '1.0.0';
+        tablePlugin.onPanelMigration = (p) => ({ ...p.options, valueToMigrate: 'should-not-migrate' });
+        tablePlugin.shouldMigrate = () => false;
+
+        await model.pluginLoaded(tablePlugin);
+
+        expect(model.options).toMatchObject({ valueToMigrate: 'old-legacy' });
+      });
+
+      it('should fallback to version comparison when shouldMigrate is not defined', async () => {
+        model.options.valueToMigrate = 'old-legacy';
+        model.pluginVersion = '1.0.0';
+
+        tablePlugin.meta.info.version = '2.0.0';
+        tablePlugin.onPanelMigration = (p) => ({ ...p.options, valueToMigrate: 'migrated-by-version' });
+        tablePlugin.shouldMigrate = undefined;
+
+        await model.pluginLoaded(tablePlugin);
+
+        expect(model.options).toMatchObject({ valueToMigrate: 'migrated-by-version' });
+      });
     });
 
     it('should apply defaults', () => {
@@ -388,12 +443,20 @@ describe('PanelModel', () => {
     });
 
     describe('when changing to react panel from angular panel', () => {
-      let panelQueryRunner: any;
+      let panelQueryRunner: PanelQueryRunner;
 
       const onPanelTypeChanged = jest.fn();
-      const reactPlugin = getPanelPlugin({ id: 'react' }).setPanelChangeHandler(onPanelTypeChanged as any);
+      const reactPlugin = getPanelPlugin({ id: 'react' }).setPanelChangeHandler(
+        onPanelTypeChanged as PanelTypeChangedHandler
+      );
 
       beforeEach(() => {
+        model = new PanelModel({
+          id: 'table-old',
+          type: 'table',
+          name: 'table-old',
+          plugin: { angularPanelCtrl: {} },
+        });
         model.changePlugin(reactPlugin);
         panelQueryRunner = model.getQueryRunner();
       });
@@ -412,13 +475,13 @@ describe('PanelModel', () => {
     });
 
     describe('when autoMigrateFrom angular to react', () => {
-      const onPanelTypeChanged = (panel: PanelModel, prevPluginId: string, prevOptions: Record<string, any>) => {
+      const onPanelTypeChanged: PanelTypeChangedHandler = (panel, prevPluginId, prevOptions) => {
         panel.fieldConfig = { defaults: { unit: 'bytes' }, overrides: [] };
         return { name: prevOptions.angular.oldName };
       };
 
       const reactPlugin = getPanelPlugin({ id: 'timeseries' })
-        .setPanelChangeHandler(onPanelTypeChanged as any)
+        .setPanelChangeHandler(onPanelTypeChanged)
         .useFieldConfig({
           disableStandardOptions: [FieldConfigProperty.Thresholds],
         })
@@ -450,10 +513,12 @@ describe('PanelModel', () => {
     });
 
     describe('variables interpolation', () => {
-      let panelQueryRunner: any;
+      let panelQueryRunner: PanelQueryRunner;
 
       const onPanelTypeChanged = jest.fn();
-      const reactPlugin = getPanelPlugin({ id: 'react' }).setPanelChangeHandler(onPanelTypeChanged as any);
+      const reactPlugin = getPanelPlugin({ id: 'react' }).setPanelChangeHandler(
+        onPanelTypeChanged as PanelTypeChangedHandler
+      );
 
       beforeEach(() => {
         model.changePlugin(reactPlugin);
@@ -463,7 +528,6 @@ describe('PanelModel', () => {
       it('should call react onPanelTypeChanged', () => {
         expect(onPanelTypeChanged.mock.calls.length).toBe(1);
         expect(onPanelTypeChanged.mock.calls[0][1]).toBe('table');
-        expect(onPanelTypeChanged.mock.calls[0][2].angular).toBeDefined();
       });
 
       it('getQueryRunner() should return same instance after changing to another react panel', () => {
