@@ -3,13 +3,12 @@ import {
   Dashboard,
   defaultDashboardCursorSync,
   defaultVariableModel,
-  GraphPanel,
   Panel,
   RowPanel,
   VariableModel,
 } from '@grafana/schema';
 import { GetVariables } from 'app/features/variables/state/selectors';
-import { DashboardMeta } from 'app/types';
+import { DashboardMeta } from 'app/types/dashboard';
 
 import { DashboardModel } from '../DashboardModel';
 
@@ -22,7 +21,7 @@ export function createDashboardModelFixture(
     editable: true,
     graphTooltip: defaultDashboardCursorSync,
     schemaVersion: 1,
-    style: 'dark',
+    version: 1,
     timezone: '',
     ...dashboardInput,
   };
@@ -30,16 +29,8 @@ export function createDashboardModelFixture(
   return new DashboardModel(dashboardJson, meta, { getVariablesFromState });
 }
 
-export function createPanelJSONFixture(panelInput: Partial<Panel | GraphPanel | RowPanel> = {}): Panel {
+export function createPanelSaveModel(panelInput: Partial<Panel | RowPanel> = {}): Panel {
   return {
-    fieldConfig: {
-      defaults: {},
-      overrides: [],
-    },
-    options: {},
-    repeatDirection: 'h',
-    transformations: [],
-    transparent: false,
     type: 'timeseries',
     ...panelInput,
   };
