@@ -1,5 +1,5 @@
 import { VariableModel } from '@grafana/schema/dist/esm/index';
-import { VariableKind } from '@grafana/schema/dist/esm/schema/dashboard/v2alpha0';
+import { VariableKind } from '@grafana/schema/dist/esm/schema/dashboard/v2';
 import { DashboardScene } from 'app/features/dashboard-scene/scene/DashboardScene';
 import { DashboardInteractions } from 'app/features/dashboard-scene/utils/interactions';
 
