@@ -1,4 +1,5 @@
 import { selectors as e2eSelectors } from '@grafana/e2e-selectors';
+import { t } from '@grafana/i18n';
 import { Alert } from '@grafana/ui';
 
 export const readOnlyMessage =
@@ -6,7 +7,11 @@ export const readOnlyMessage =
 
 export function DataSourceReadOnlyMessage() {
   return (
-    <Alert data-testid={e2eSelectors.pages.DataSource.readOnly} severity="info" title="Provisioned data source">
+    <Alert
+      data-testid={e2eSelectors.pages.DataSource.readOnly}
+      severity="info"
+      title={t('datasources.data-source-read-only-message.title-provisioned-data-source', 'Provisioned data source')}
+    >
       {readOnlyMessage}
     </Alert>
   );
