@@ -12,17 +12,9 @@ import {
   ThresholdsMode,
   ThemeContext,
 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { Button, ColorPicker, colors, IconButton, Input, Label, RadioButtonGroup, stylesFactory } from '@grafana/ui';
 
-const modes: Array<SelectableValue<ThresholdsMode>> = [
-  { value: ThresholdsMode.Absolute, label: 'Absolute', description: 'Pick thresholds based on the absolute values' },
-  {
-    value: ThresholdsMode.Percentage,
-    label: 'Percentage',
-    description: 'Pick threshold based on the percent between min/max',
-  },
-];
-
 export interface Props {
   thresholds: ThresholdsConfig;
   onChange: (thresholds: ThresholdsConfig) => void;
@@ -145,13 +137,16 @@ export class ThresholdsEditor extends PureComponent<Props, State> {
 
   renderInput(threshold: ThresholdWithKey, styles: ThresholdStyles, idx: number) {
     const isPercent = this.props.thresholds.mode === ThresholdsMode.Percentage;
+    const thresholdNumber = idx + 1;
 
-    const ariaLabel = `Threshold ${idx + 1}`;
+    const ariaLabel = t('dimensions.thresholds-editor.aria-label-threshold', 'Threshold {{thresholdNumber}}', {
+      thresholdNumber,
+    });
     if (!isFinite(threshold.value)) {
       return (
         <Input
           type="text"
-          value={'Base'}
+          value={t('dimensions.thresholds-editor.value-base', 'Base')}
           aria-label={ariaLabel}
           disabled
           prefix={
@@ -194,7 +189,9 @@ export class ThresholdsEditor extends PureComponent<Props, State> {
             className={styles.trashIcon}
             name="trash-alt"
             onClick={() => this.onRemoveThreshold(threshold)}
-            tooltip={`Remove ${ariaLabel}`}
+            tooltip={t('dimensions.threshold-editor.tooltip-remove-threshold', 'Remove threshold {{thresholdNumber}}', {
+              thresholdNumber,
+            })}
           />
         }
       />
@@ -205,6 +202,25 @@ export class ThresholdsEditor extends PureComponent<Props, State> {
     const { thresholds } = this.props;
     const { steps } = this.state;
 
+    const modes: Array<SelectableValue<ThresholdsMode>> = [
+      {
+        value: ThresholdsMode.Absolute,
+        label: t('dimensions.thresholds-editor.modes.label.absolute', 'Absolute'),
+        description: t(
+          'dimensions.thresholds-editor.modes.description.thresholds-based-absolute-values',
+          'Pick thresholds based on the absolute values'
+        ),
+      },
+      {
+        value: ThresholdsMode.Percentage,
+        label: t('dimensions.thresholds-editor.modes.label.percentage', 'Percentage'),
+        description: t(
+          'dimensions.thresholds-editor.modes.description.threshold-based-percent-between-minmax',
+          'Pick threshold based on the percent between min/max'
+        ),
+      },
+    ];
+
     return (
       <ThemeContext.Consumer>
         {(theme) => {
@@ -219,7 +235,7 @@ export class ThresholdsEditor extends PureComponent<Props, State> {
                 className={styles.addButton}
                 fullWidth
               >
-                Add threshold
+                <Trans i18nKey="dimensions.thresholds-editor.add-threshold">Add threshold</Trans>
               </Button>
               <div className={styles.thresholds}>
                 {steps
@@ -233,7 +249,14 @@ export class ThresholdsEditor extends PureComponent<Props, State> {
               </div>
 
               <div>
-                <Label description="Percentage means thresholds relative to min & max">Thresholds mode</Label>
+                <Label
+                  description={t(
+                    'dimensions.thresholds-editor.description-percentage-means-thresholds-relative',
+                    'Percentage means thresholds relative to min & max'
+                  )}
+                >
+                  <Trans i18nKey="dimensions.thresholds-editor.thresholds-mode">Thresholds mode</Trans>
+                </Label>
                 <RadioButtonGroup options={modes} onChange={this.onModeChanged} value={thresholds.mode} />
               </div>
             </div>
