@@ -1,5 +1,4 @@
-import { DataFrame, Field } from '@grafana/data';
-import { getMinMaxAndDelta } from '@grafana/data/src/field/scale';
+import { getMinMaxAndDelta, DataFrame, Field } from '@grafana/data';
 import { ScaleDimensionConfig, ScaleDimensionMode } from '@grafana/schema';
 
 import { DimensionSupplier, ScaleDimensionOptions } from './types';
