@@ -1,8 +1,9 @@
 import { css } from '@emotion/css';
 import * as React from 'react';
 
-import { GrafanaTheme2 } from '@grafana/data/src';
-import { Field, Input, useTheme2 } from '@grafana/ui/src';
+import { GrafanaTheme2 } from '@grafana/data';
+import { t } from '@grafana/i18n';
+import { Field, Input, useTheme2 } from '@grafana/ui';
 
 function getStyles(theme: GrafanaTheme2) {
   return {
@@ -14,10 +15,16 @@ function getStyles(theme: GrafanaTheme2) {
 
 export function LogsColumnSearch(props: { onChange: (e: React.FormEvent<HTMLInputElement>) => void; value: string }) {
   const theme = useTheme2();
+
   const styles = getStyles(theme);
   return (
     <Field className={styles.searchWrap}>
-      <Input value={props.value} type={'text'} placeholder={'Search fields by name'} onChange={props.onChange} />
+      <Input
+        value={props.value}
+        type={'text'}
+        placeholder={t('explore.logs-column-search.placeholder-search-fields-by-name', 'Search fields by name')}
+        onChange={props.onChange}
+      />
     </Field>
   );
 }
