@@ -1,34 +1,31 @@
 import { css } from '@emotion/css';
-import React from 'react';
 
 import { GrafanaTheme2, IconName } from '@grafana/data';
 import { Button, useStyles2 } from '@grafana/ui';
 
-export const getStyles = (theme: GrafanaTheme2) => {
-  return {
-    ActionButton: css`
-      label: ActionButton;
-      overflow: hidden;
-      position: relative;
-      &:after {
-        content: '';
-        background: ${theme.colors.primary.main};
-        display: block;
-        position: absolute;
-        right: 0;
-        width: 100%;
-        height: 100%;
-        opacity: 0;
-        transition: all 0.8s;
-      }
-      &:active:after {
-        margin: 0;
-        opacity: 0.3;
-        transition: 0s;
-      }
-    `,
-  };
-};
+export const getStyles = (theme: GrafanaTheme2) => ({
+  ActionButton: css({
+    label: 'ActionButton',
+    overflow: 'hidden',
+    position: 'relative',
+    '&:after': {
+      content: '""',
+      background: theme.colors.primary.main,
+      display: 'block',
+      position: 'absolute',
+      right: 0,
+      width: '100%',
+      height: '100%',
+      opacity: 0,
+      transition: 'all 0.8s',
+    },
+    '&:active:after': {
+      margin: 0,
+      opacity: 0.3,
+      transition: '0s',
+    },
+  }),
+});
 
 export type ActionButtonProps = {
   onClick: () => void;
