@@ -1,6 +1,6 @@
-import React from 'react';
+import * as React from 'react';
 
-import { Field } from '@grafana/data';
+import { Field, LinkTarget } from '@grafana/data';
 
 import { TraceSpan } from './trace';
 
@@ -9,6 +9,8 @@ export enum SpanLinkType {
   Traces = 'trace',
   Metrics = 'metric',
   Profiles = 'profile',
+  ProfilesDrilldown = 'profile-drilldown',
+  Session = 'session',
   Unknown = 'unknown',
 }
 
@@ -19,6 +21,7 @@ export type SpanLinkDef = {
   title?: string;
   field: Field;
   type: SpanLinkType;
+  target?: LinkTarget;
 };
 
 export type SpanLinkFunc = (span: TraceSpan) => SpanLinkDef[] | undefined;
