@@ -12,34 +12,24 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+import { TraceKeyValuePair, TraceLog } from '@grafana/data';
+
 /**
  * All timestamps are in microseconds
  */
 
-// TODO: Everett Tech Debt: Fix KeyValuePair types
-export type TraceKeyValuePair = {
-  key: string;
-  type?: string;
-  value: any;
-};
-
 export type TraceLink = {
   url: string;
   text: string;
 };
 
-export type TraceLog = {
-  timestamp: number;
-  fields: TraceKeyValuePair[];
-};
-
 export type TraceProcess = {
   serviceName: string;
   tags: TraceKeyValuePair[];
 };
 
 export type TraceSpanReference = {
-  refType: 'CHILD_OF' | 'FOLLOWS_FROM';
+  refType: 'CHILD_OF' | 'FOLLOWS_FROM' | 'EXTERNAL';
   // eslint-disable-next-line no-use-before-define
   span?: TraceSpan | null | undefined;
   spanID: string;
@@ -110,3 +100,12 @@ export type CriticalPathSection = {
   section_start: number;
   section_end: number;
 };
+
+// Type for the plugin link context that includes trace data and datasource information
+export type TraceViewPluginExtensionContext = Trace & {
+  datasource: {
+    name: string;
+    uid: string;
+    type: string;
+  };
+};
