@@ -14,13 +14,15 @@
 
 import { SpanStatusCode } from '@opentelemetry/api';
 
-import { SearchProps, Tag } from '../../useSearch';
+import { TraceKeyValuePair, TraceSearchProps, TraceSearchTag } from '@grafana/data';
+
 import { KIND, LIBRARY_NAME, LIBRARY_VERSION, STATUS, STATUS_MESSAGE, TRACE_STATE, ID } from '../constants/span';
-import { TNil, TraceKeyValuePair, TraceSpan } from '../types';
+import TNil from '../types/TNil';
+import { TraceSpan } from '../types/trace';
 
 // filter spans where all filters added need to be true for each individual span that is returned
 // i.e. the more filters added -> the more specific that the returned results are
-export function filterSpans(searchProps: SearchProps, spans: TraceSpan[] | TNil) {
+export function filterSpans(searchProps: TraceSearchProps, spans: TraceSpan[] | TNil) {
   if (!spans) {
     return undefined;
   }
@@ -76,7 +78,7 @@ export function getQueryMatches(query: string, spans: TraceSpan[] | TNil) {
   const isTextInKeyValues = (kvs: TraceKeyValuePair[]) =>
     kvs
       ? kvs.some((kv) => {
-          return isTextInQuery(queryParts, kv.key) || isTextInQuery(queryParts, kv.value.toString());
+          return isTextInQuery(queryParts, kv.key) || isTextInQuery(queryParts, getStringValue(kv.value));
         })
       : false;
 
@@ -90,14 +92,15 @@ export function getQueryMatches(query: string, spans: TraceSpan[] | TNil) {
     (span.instrumentationLibraryName && isTextInQuery(queryParts, span.instrumentationLibraryName)) ||
     (span.instrumentationLibraryVersion && isTextInQuery(queryParts, span.instrumentationLibraryVersion)) ||
     (span.traceState && isTextInQuery(queryParts, span.traceState)) ||
-    (span.logs !== null && span.logs.some((log) => isTextInKeyValues(log.fields))) ||
+    (span.logs !== null &&
+      span.logs.some((log) => (log.name && isTextInQuery(queryParts, log.name)) || isTextInKeyValues(log.fields))) ||
     isTextInKeyValues(span.process.tags) ||
     queryParts.some((queryPart) => queryPart === span.spanID);
 
   return spans.filter(isSpanAMatch);
 }
 
-const getTagMatches = (spans: TraceSpan[], tags: Tag[]) => {
+const getTagMatches = (spans: TraceSpan[], tags: TraceSearchTag[]) => {
   // remove empty/default tags
   tags = tags.filter((tag) => {
     // tag.key === '' when it is cleared via pressing x icon in select field
@@ -107,28 +110,17 @@ const getTagMatches = (spans: TraceSpan[], tags: Tag[]) => {
   if (tags.length > 0) {
     return spans.filter((span: TraceSpan) => {
       // match against every tag filter
-      return tags.every((tag: Tag) => {
+      return tags.every((tag: TraceSearchTag) => {
         if (tag.key && tag.value) {
           if (
-            span.tags.some((kv) => checkKeyAndValueForMatch(tag, kv)) ||
-            span.process.tags.some((kv) => checkKeyAndValueForMatch(tag, kv)) ||
-            (span.logs && span.logs.some((log) => log.fields.some((kv) => checkKeyAndValueForMatch(tag, kv)))) ||
-            (span.kind && tag.key === KIND && tag.value === span.kind) ||
-            (span.statusCode !== undefined &&
-              tag.key === STATUS &&
-              tag.value === SpanStatusCode[span.statusCode].toLowerCase()) ||
-            (span.statusMessage && tag.key === STATUS_MESSAGE && tag.value === span.statusMessage) ||
-            (span.instrumentationLibraryName &&
-              tag.key === LIBRARY_NAME &&
-              tag.value === span.instrumentationLibraryName) ||
-            (span.instrumentationLibraryVersion &&
-              tag.key === LIBRARY_VERSION &&
-              tag.value === span.instrumentationLibraryVersion) ||
-            (span.traceState && tag.key === TRACE_STATE && tag.value === span.traceState) ||
-            (tag.key === ID && tag.value === span.spanID)
+            (tag.operator === '=' && checkKeyValConditionForMatch(tag, span)) ||
+            (tag.operator === '=~' && checkKeyValConditionForRegex(tag, span)) ||
+            (tag.operator === '!=' && !checkKeyValConditionForMatch(tag, span)) ||
+            (tag.operator === '!~' && !checkKeyValConditionForRegex(tag, span))
           ) {
-            return getReturnValue(tag.operator, true);
+            return true;
           }
+          return false;
         } else if (tag.key) {
           if (
             span.tags.some((kv) => checkKeyForMatch(tag.key!, kv.key)) ||
@@ -142,29 +134,74 @@ const getTagMatches = (spans: TraceSpan[], tags: Tag[]) => {
             (span.traceState && tag.key === TRACE_STATE) ||
             tag.key === ID
           ) {
-            return getReturnValue(tag.operator, true);
+            return tag.operator === '=' || tag.operator === '=~' ? true : false;
           }
+          return tag.operator === '=' || tag.operator === '=~' ? false : true;
         }
-        return getReturnValue(tag.operator, false);
+        return false;
       });
     });
   }
   return undefined;
 };
 
+const checkKeyValConditionForRegex = (tag: TraceSearchTag, span: TraceSpan) => {
+  return (
+    span.tags.some((kv) => checkKeyAndValueForRegex(tag, kv)) ||
+    span.process.tags.some((kv) => checkKeyAndValueForRegex(tag, kv)) ||
+    (span.logs && span.logs.some((log) => log.fields.some((kv) => checkKeyAndValueForRegex(tag, kv)))) ||
+    (span.kind && tag.key === KIND && tag.value?.includes(span.kind)) ||
+    (span.statusCode !== undefined &&
+      tag.key === STATUS &&
+      tag.value?.includes(SpanStatusCode[span.statusCode].toLowerCase())) ||
+    (span.statusMessage && tag.key === STATUS_MESSAGE && tag.value?.includes(span.statusMessage)) ||
+    (span.instrumentationLibraryName &&
+      tag.key === LIBRARY_NAME &&
+      tag.value?.includes(span.instrumentationLibraryName)) ||
+    (span.instrumentationLibraryVersion &&
+      tag.key === LIBRARY_VERSION &&
+      tag.value?.includes(span.instrumentationLibraryVersion)) ||
+    (span.traceState && tag.key === TRACE_STATE && tag.value?.includes(span.traceState)) ||
+    (tag.key === ID && tag.value?.includes(span.spanID))
+  );
+};
+
+const checkKeyValConditionForMatch = (tag: TraceSearchTag, span: TraceSpan) => {
+  return (
+    span.tags.some((kv) => checkKeyAndValueForMatch(tag, kv)) ||
+    span.process.tags.some((kv) => checkKeyAndValueForMatch(tag, kv)) ||
+    (span.logs && span.logs.some((log) => log.fields.some((kv) => checkKeyAndValueForMatch(tag, kv)))) ||
+    (span.kind && tag.key === KIND && tag.value === span.kind) ||
+    (span.statusCode !== undefined &&
+      tag.key === STATUS &&
+      tag.value === SpanStatusCode[span.statusCode].toLowerCase()) ||
+    (span.statusMessage && tag.key === STATUS_MESSAGE && tag.value === span.statusMessage) ||
+    (span.instrumentationLibraryName && tag.key === LIBRARY_NAME && tag.value === span.instrumentationLibraryName) ||
+    (span.instrumentationLibraryVersion &&
+      tag.key === LIBRARY_VERSION &&
+      tag.value === span.instrumentationLibraryVersion) ||
+    (span.traceState && tag.key === TRACE_STATE && tag.value === span.traceState) ||
+    (tag.key === ID && tag.value === span.spanID)
+  );
+};
+
 const checkKeyForMatch = (tagKey: string, key: string) => {
-  return tagKey === key.toString() ? true : false;
+  return tagKey === key.toString();
 };
 
-const checkKeyAndValueForMatch = (tag: Tag, kv: TraceKeyValuePair) => {
-  return tag.key === kv.key.toString() && tag.value === kv.value.toString() ? true : false;
+const checkKeyAndValueForMatch = (tag: TraceSearchTag, kv: TraceKeyValuePair) => {
+  return tag.key === kv.key && tag.value === getStringValue(kv.value);
 };
 
-const getReturnValue = (operator: string, found: boolean) => {
-  return operator === '=' ? found : !found;
+const checkKeyAndValueForRegex = (tag: TraceSearchTag, kv: TraceKeyValuePair) => {
+  return kv.key.includes(tag.key || '') && getStringValue(kv.value).includes(tag.value || '');
 };
 
-const getServiceNameMatches = (spans: TraceSpan[], searchProps: SearchProps) => {
+const getStringValue = (value: string | number | boolean | undefined) => {
+  return value ? value.toString() : '';
+};
+
+const getServiceNameMatches = (spans: TraceSpan[], searchProps: TraceSearchProps) => {
   return spans.filter((span: TraceSpan) => {
     return searchProps.serviceNameOperator === '='
       ? span.process.serviceName === searchProps.serviceName
@@ -172,7 +209,7 @@ const getServiceNameMatches = (spans: TraceSpan[], searchProps: SearchProps) =>
   });
 };
 
-const getSpanNameMatches = (spans: TraceSpan[], searchProps: SearchProps) => {
+const getSpanNameMatches = (spans: TraceSpan[], searchProps: TraceSearchProps) => {
   return spans.filter((span: TraceSpan) => {
     return searchProps.spanNameOperator === '='
       ? span.operationName === searchProps.spanName
@@ -180,7 +217,7 @@ const getSpanNameMatches = (spans: TraceSpan[], searchProps: SearchProps) => {
   });
 };
 
-const getDurationMatches = (spans: TraceSpan[], searchProps: SearchProps) => {
+const getDurationMatches = (spans: TraceSpan[], searchProps: TraceSearchProps) => {
   const from = convertTimeFilter(searchProps?.from || '');
   const to = convertTimeFilter(searchProps?.to || '');
   let filteredSpans: TraceSpan[] = [];
