@@ -26,38 +26,42 @@ export const runQuery = async (exploreId = 'left') => {
 };
 
 export const openQueryHistory = async () => {
-  const explore = withinExplore('left');
-  const button = explore.getByRole('button', { name: 'Query history' });
-  await userEvent.click(button);
-  expect(await screen.findByPlaceholderText('Search queries')).toBeInTheDocument();
+  let button = screen.queryByRole('button', { name: 'Query history' });
+  if (button) {
+    await userEvent.click(button);
+    expect(await screen.findByPlaceholderText('Search queries')).toBeInTheDocument();
+  } else {
+    button = screen.getByRole('button', { name: 'Open query library or query history' });
+    await userEvent.click(button);
+    button = await screen.findByRole('menuitem', { name: 'Query history' });
+    await userEvent.click(button);
+    expect(await screen.findByPlaceholderText('Search queries')).toBeInTheDocument();
+  }
 };
 
 export const openQueryLibrary = async () => {
-  const explore = withinExplore('left');
-  const button = explore.getByRole('button', { name: 'Query library' });
+  const button = screen.getByRole('button', { name: 'Add from saved queries' });
   await userEvent.click(button);
   await waitFor(async () => {
-    screen.getByRole('tab', {
-      name: /query library/i,
+    const container = screen.getByRole('dialog', {
+      name: /Drawer title/,
     });
+    within(container).getByText('Saved queries');
   });
 };
 
-export const switchToQueryHistory = async () => {
-  const tab = screen.getByRole('tab', {
-    name: /query history/i,
-  });
-  await userEvent.click(tab);
-};
-
 export const addQueryHistoryToQueryLibrary = async () => {
-  const button = withinQueryHistory().getByRole('button', { name: /add to library/i });
+  const button = withinQueryHistory().getByRole('button', { name: /Save query/i });
   await userEvent.click(button);
 };
 
-export const submitAddToQueryLibrary = async ({ description }: { description: string }) => {
-  const input = within(screen.getByRole('dialog')).getByLabelText('Description');
-  await userEvent.type(input, description);
+export const submitAddToQueryLibrary = async ({ title }: { title: string }) => {
+  const container = screen.getByRole('dialog', {
+    name: /Drawer title/i,
+  });
+
+  const input = within(container).getByRole('textbox', { name: /title/i });
+  await userEvent.type(input, title);
   const saveButton = screen.getByRole('button', {
     name: /^save$/i,
   });
@@ -75,9 +79,9 @@ export const switchToQueryHistoryTab = async (name: 'Settings' | 'Query History'
 };
 
 export const selectStarredTabFirst = async () => {
-  const checkbox = withinQueryHistory().getByRole('checkbox', {
-    name: /Change the default active tab from “Query history” to “Starred”/,
-  });
+  const checkbox = withinQueryHistory().getByLabelText(
+    /Change the default active tab from “Query history” to “Starred”/
+  );
   await userEvent.click(checkbox);
 };
 
