@@ -3,38 +3,12 @@ import { useEffect, useState } from 'react';
 
 import { StandardEditorProps, DataFrame, GrafanaTheme2 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
+import { t } from '@grafana/i18n';
 import { FrameGeometrySource, FrameGeometrySourceMode } from '@grafana/schema';
-import { Alert, HorizontalGroup, Icon, Select, useStyles2 } from '@grafana/ui';
+import { Alert, Icon, Select, useStyles2 } from '@grafana/ui';
 
 import { FrameGeometryField, getGeometryField, getLocationMatchers } from '../utils/location';
 
-const MODE_OPTIONS = [
-  {
-    value: FrameGeometrySourceMode.Auto,
-    label: 'Auto',
-    ariaLabel: selectors.components.Transforms.SpatialOperations.location.autoOption,
-    description: 'Automatically identify location data based on default field names',
-  },
-  {
-    value: FrameGeometrySourceMode.Coords,
-    label: 'Coords',
-    ariaLabel: selectors.components.Transforms.SpatialOperations.location.coords.option,
-    description: 'Specify latitude and longitude fields',
-  },
-  {
-    value: FrameGeometrySourceMode.Geohash,
-    label: 'Geohash',
-    ariaLabel: selectors.components.Transforms.SpatialOperations.location.geohash.option,
-    description: 'Specify geohash field',
-  },
-  {
-    value: FrameGeometrySourceMode.Lookup,
-    label: 'Lookup',
-    ariaLabel: selectors.components.Transforms.SpatialOperations.location.lookup.option,
-    description: 'Specify Gazetteer and lookup field',
-  },
-];
-
 interface ModeEditorSettings {
   data?: DataFrame[];
   source?: FrameGeometrySource;
@@ -47,9 +21,43 @@ export const LocationModeEditor = ({
   onChange,
   context,
   item,
+  id,
 }: StandardEditorProps<string, ModeEditorSettings, unknown, unknown>) => {
   const [info, setInfo] = useState<FrameGeometryField>();
 
+  const MODE_OPTIONS = [
+    {
+      value: FrameGeometrySourceMode.Auto,
+      label: t('geo.location-more-editor.mode-options.label-auto', 'Auto'),
+      ariaLabel: selectors.components.Transforms.SpatialOperations.location.autoOption,
+      description: t(
+        'geo.location-more-editor.mode-options.description-auto',
+        'Automatically identify location data based on default field names'
+      ),
+    },
+    {
+      value: FrameGeometrySourceMode.Coords,
+      label: t('geo.location-more-editor.mode-options.label-coords', 'Coords'),
+      ariaLabel: selectors.components.Transforms.SpatialOperations.location.coords.option,
+      description: t(
+        'geo.location-more-editor.mode-options.description-coords',
+        'Specify latitude and longitude fields'
+      ),
+    },
+    {
+      value: FrameGeometrySourceMode.Geohash,
+      label: t('geo.location-more-editor.mode-options.label-geohash', 'Geohash'),
+      ariaLabel: selectors.components.Transforms.SpatialOperations.location.geohash.option,
+      description: t('geo.location-more-editor.mode-options.description-geohash', 'Specify geohash field'),
+    },
+    {
+      value: FrameGeometrySourceMode.Lookup,
+      label: t('geo.location-more-editor.mode-options.label-lookup', 'Lookup'),
+      ariaLabel: selectors.components.Transforms.SpatialOperations.location.lookup.option,
+      description: t('geo.location-more-editor.mode-options.description-lookup', 'Specify Gazetteer and lookup field'),
+    },
+  ];
+
   useEffect(() => {
     if (item.settings?.source && item.settings?.data?.length && item.settings.data[0]) {
       getLocationMatchers(item.settings.source).then((location) => {
@@ -90,32 +98,27 @@ export const LocationModeEditor = ({
   return (
     <>
       <Select
+        inputId={id}
         options={MODE_OPTIONS}
         value={value}
         onChange={(v) => {
           onChange(v.value);
         }}
       />
-      <HorizontalGroup className={styles.hGroup}>{dataValidation()}</HorizontalGroup>
+      {dataValidation()}
     </>
   );
 };
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    alert: css`
-      & div {
-        padding: 4px;
-      }
-      margin-bottom: 0px;
-      margin-top: 5px;
-      padding: 2px;
-    `,
-    // TODO apply styling to horizontal group (currently not working)
-    hGroup: css`
-      & div {
-        width: 100%;
-      }
-    `,
+    alert: css({
+      '& div': {
+        padding: theme.spacing(0.5),
+      },
+      marginBottom: '0px',
+      marginTop: '5px',
+      padding: theme.spacing(0.25),
+    }),
   };
 };
