@@ -1,7 +1,21 @@
-import React, { FocusEvent, SyntheticEvent, useCallback } from 'react';
+import {
+  memo,
+  FocusEvent,
+  SyntheticEvent,
+  useCallback,
+  ReactNode,
+  useMemo,
+  cloneElement,
+  isValidElement,
+  MouseEvent,
+} from 'react';
 
-import { LogRowModel } from '@grafana/data';
-import { ClipboardButton, IconButton } from '@grafana/ui';
+import { LogRowContextOptions, LogRowModel } from '@grafana/data';
+import { t } from '@grafana/i18n';
+import { DataQuery } from '@grafana/schema';
+import { ClipboardButton, IconButton, PopoverContent } from '@grafana/ui';
+
+import { handleOpenLogsContextClick } from '../utils';
 
 import { LogRowStyles } from './getLogRowStyles';
 
@@ -10,39 +24,54 @@ interface Props {
   row: LogRowModel;
   showContextToggle?: (row: LogRowModel) => boolean;
   onOpenContext: (row: LogRowModel) => void;
+  getRowContextQuery?: (
+    row: LogRowModel,
+    options?: LogRowContextOptions,
+    cacheFilters?: boolean
+  ) => Promise<DataQuery | null>;
   onPermalinkClick?: (row: LogRowModel) => Promise<void>;
   onPinLine?: (row: LogRowModel) => void;
   onUnpinLine?: (row: LogRowModel) => void;
+  pinLineButtonTooltipTitle?: PopoverContent;
   pinned?: boolean;
   styles: LogRowStyles;
   mouseIsOver: boolean;
   onBlur: () => void;
+  addonBefore?: ReactNode[];
+  addonAfter?: ReactNode[];
 }
 
-export const LogRowMenuCell = React.memo(
+export const LogRowMenuCell = memo(
   ({
     logText,
     onOpenContext,
     onPermalinkClick,
     onPinLine,
     onUnpinLine,
+    pinLineButtonTooltipTitle,
     pinned,
     row,
     showContextToggle,
     styles,
     mouseIsOver,
     onBlur,
+    getRowContextQuery,
+    addonBefore,
+    addonAfter,
   }: Props) => {
-    const shouldShowContextToggle = showContextToggle ? showContextToggle(row) : false;
+    const shouldShowContextToggle = useMemo(
+      () => (showContextToggle ? showContextToggle(row) : false),
+      [row, showContextToggle]
+    );
     const onLogRowClick = useCallback((e: SyntheticEvent) => {
       e.stopPropagation();
     }, []);
     const onShowContextClick = useCallback(
-      (e: SyntheticEvent<HTMLElement, Event>) => {
-        e.stopPropagation();
-        onOpenContext(row);
+      async (event: MouseEvent<HTMLElement>) => {
+        event.stopPropagation();
+        handleOpenLogsContextClick(event, row, getRowContextQuery, onOpenContext);
       },
-      [onOpenContext, row]
+      [onOpenContext, getRowContextQuery, row]
     );
     /**
      * For better accessibility support, we listen to the onBlur event here (to hide this component), and
@@ -57,6 +86,21 @@ export const LogRowMenuCell = React.memo(
       [onBlur]
     );
     const getLogText = useCallback(() => logText, [logText]);
+
+    const beforeContent = useMemo(() => {
+      if (!addonBefore) {
+        return null;
+      }
+      return addClickListenersToNode(addonBefore, row);
+    }, [addonBefore, row]);
+
+    const afterContent = useMemo(() => {
+      if (!addonAfter) {
+        return null;
+      }
+      return addClickListenersToNode(addonAfter, row);
+    }, [addonAfter, row]);
+
     return (
       // We keep this click listener here to prevent the row from being selected when clicking on the menu.
       // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions
@@ -67,22 +111,23 @@ export const LogRowMenuCell = React.memo(
             size="md"
             name="gf-pin"
             onClick={() => onUnpinLine && onUnpinLine(row)}
-            tooltip="Unpin line"
+            tooltip={t('logs.log-row-menu-cell.tooltip-unpin-line', 'Unpin line')}
             tooltipPlacement="top"
-            aria-label="Unpin line"
+            aria-label={t('logs.log-row-menu-cell.aria-label-unpin-line', 'Unpin line')}
             tabIndex={0}
           />
         )}
         {mouseIsOver && (
           <>
+            {beforeContent}
             {shouldShowContextToggle && (
               <IconButton
                 size="md"
                 name="gf-show-context"
                 onClick={onShowContextClick}
-                tooltip="Show context"
+                tooltip={t('logs.log-row-menu-cell.tooltip-show-context', 'Show context')}
                 tooltipPlacement="top"
-                aria-label="Show context"
+                aria-label={t('logs.log-row-menu-cell.aria-label-show-context', 'Show context')}
                 tabIndex={0}
               />
             )}
@@ -93,7 +138,7 @@ export const LogRowMenuCell = React.memo(
               fill="text"
               size="md"
               getText={getLogText}
-              tooltip="Copy to clipboard"
+              tooltip={t('logs.log-row-menu-cell.tooltip-copy-to-clipboard', 'Copy to clipboard')}
               tooltipPlacement="top"
               tabIndex={0}
             />
@@ -103,9 +148,9 @@ export const LogRowMenuCell = React.memo(
                 size="md"
                 name="gf-pin"
                 onClick={() => onUnpinLine && onUnpinLine(row)}
-                tooltip="Unpin line"
+                tooltip={t('logs.log-row-menu-cell.tooltip-unpin-line', 'Unpin line')}
                 tooltipPlacement="top"
-                aria-label="Unpin line"
+                aria-label={t('logs.log-row-menu-cell.aria-label-unpin-line', 'Unpin line')}
                 tabIndex={0}
               />
             )}
@@ -115,16 +160,16 @@ export const LogRowMenuCell = React.memo(
                 size="md"
                 name="gf-pin"
                 onClick={() => onPinLine && onPinLine(row)}
-                tooltip="Pin line"
+                tooltip={pinLineButtonTooltipTitle ?? 'Pin line'}
                 tooltipPlacement="top"
-                aria-label="Pin line"
+                aria-label={t('logs.log-row-menu-cell.aria-label-pin-line', 'Pin line')}
                 tabIndex={0}
               />
             )}
             {onPermalinkClick && row.rowId !== undefined && row.uid && (
               <IconButton
-                tooltip="Copy shortlink"
-                aria-label="Copy shortlink"
+                tooltip={t('logs.log-row-menu-cell.tooltip-copy-shortlink', 'Copy shortlink')}
+                aria-label={t('logs.log-row-menu-cell.aria-label-copy-shortlink', 'Copy shortlink')}
                 tooltipPlacement="top"
                 size="md"
                 name="share-alt"
@@ -132,6 +177,7 @@ export const LogRowMenuCell = React.memo(
                 tabIndex={0}
               />
             )}
+            {afterContent}
           </>
         )}
       </span>
@@ -139,4 +185,23 @@ export const LogRowMenuCell = React.memo(
   }
 );
 
+type AddonOnClickListener = (event: MouseEvent, row: LogRowModel) => void | undefined;
+function addClickListenersToNode(nodes: ReactNode[], row: LogRowModel) {
+  return nodes.map((node, index) => {
+    if (isValidElement(node)) {
+      const onClick: AddonOnClickListener = node.props.onClick;
+      if (!onClick) {
+        return node;
+      }
+      return cloneElement(node, {
+        onClick: (event: MouseEvent<HTMLElement>) => {
+          onClick(event, row);
+        },
+        key: index,
+      });
+    }
+    return node;
+  });
+}
+
 LogRowMenuCell.displayName = 'LogRowMenuCell';
