@@ -22,8 +22,8 @@ import {
   toDataFrame,
 } from '@grafana/data';
 import { config } from '@grafana/runtime';
-import { getMockFrames } from 'app/plugins/datasource/loki/__mocks__/frames';
 import { LokiQueryDirection } from 'app/plugins/datasource/loki/dataquery.gen';
+import { getMockFrames } from 'app/plugins/datasource/loki/mocks/frames';
 
 import { MockObservableDataSourceApi } from '../../../test/mocks/datasource_srv';
 
@@ -31,9 +31,9 @@ import {
   COMMON_LABELS,
   dataFrameToLogsModel,
   dedupLogRows,
-  filterLogLevels,
   getSeriesProperties,
   LIMIT_LABEL,
+  TOTAL_LABEL,
   logRowToSingleRowDataFrame,
   logSeriesToLogsModel,
   queryLogsSample,
@@ -168,63 +168,6 @@ describe('dedupLogRows()', () => {
   });
 });
 
-describe('filterLogLevels()', () => {
-  test('should correctly filter out log levels', () => {
-    const rows = [
-      {
-        entry: 'DEBUG 1',
-        logLevel: LogLevel.debug,
-      },
-      {
-        entry: 'ERROR 1',
-        logLevel: LogLevel.error,
-      },
-      {
-        entry: 'TRACE 1',
-        logLevel: LogLevel.trace,
-      },
-    ] as LogRowModel[];
-    const filteredLogs = filterLogLevels(rows, new Set([LogLevel.debug]));
-    expect(filteredLogs.length).toBe(2);
-    expect(filteredLogs).toEqual([
-      { entry: 'ERROR 1', logLevel: 'error' },
-      { entry: 'TRACE 1', logLevel: 'trace' },
-    ]);
-  });
-  test('should correctly filter out log levels and then deduplicate', () => {
-    const rows = [
-      {
-        entry: 'DEBUG 1',
-        logLevel: LogLevel.debug,
-      },
-      {
-        entry: 'DEBUG 2',
-        logLevel: LogLevel.debug,
-      },
-      {
-        entry: 'DEBUG 2',
-        logLevel: LogLevel.debug,
-      },
-      {
-        entry: 'ERROR 1',
-        logLevel: LogLevel.error,
-      },
-      {
-        entry: 'TRACE 1',
-        logLevel: LogLevel.trace,
-      },
-    ] as LogRowModel[];
-    const filteredLogs = filterLogLevels(rows, new Set([LogLevel.error]));
-    const deduplicatedLogs = dedupLogRows(filteredLogs, LogsDedupStrategy.exact);
-    expect(deduplicatedLogs.length).toBe(3);
-    expect(deduplicatedLogs).toEqual([
-      { duplicates: 0, entry: 'DEBUG 1', logLevel: 'debug' },
-      { duplicates: 1, entry: 'DEBUG 2', logLevel: 'debug' },
-      { duplicates: 0, entry: 'TRACE 1', logLevel: 'trace' },
-    ]);
-  });
-});
-
 const emptyLogsModel = {
   hasUniqueLabels: false,
   rows: [],
@@ -348,6 +291,11 @@ describe('dataFrameToLogsModel', () => {
     ]);
     expect(logsModel.meta).toHaveLength(2);
     expect(logsModel.meta![0]).toMatchObject({
+      label: '',
+      value: `2 lines returned`,
+      kind: LogsMetaKind.String,
+    });
+    expect(logsModel.meta![1]).toMatchObject({
       label: COMMON_LABELS,
       value: {
         filename: '/var/log/grafana/grafana.log',
@@ -355,11 +303,6 @@ describe('dataFrameToLogsModel', () => {
       },
       kind: LogsMetaKind.LabelsMap,
     });
-    expect(logsModel.meta![1]).toMatchObject({
-      label: LIMIT_LABEL,
-      value: `1000 (2 returned)`,
-      kind: LogsMetaKind.String,
-    });
   });
 
   it('given one series should return expected logs model with detected_level', () => {
@@ -430,17 +373,17 @@ describe('dataFrameToLogsModel', () => {
     ]);
     expect(logsModel.meta).toHaveLength(2);
     expect(logsModel.meta![0]).toMatchObject({
+      label: '',
+      value: `2 lines returned`,
+      kind: LogsMetaKind.String,
+    });
+    expect(logsModel.meta![1]).toMatchObject({
       label: COMMON_LABELS,
       value: {
         job: 'grafana',
       },
       kind: LogsMetaKind.LabelsMap,
     });
-    expect(logsModel.meta![1]).toMatchObject({
-      label: LIMIT_LABEL,
-      value: `1000 (2 returned)`,
-      kind: LogsMetaKind.String,
-    });
   });
 
   it('with infinite scrolling enabled it should return expected logs model', () => {
@@ -474,8 +417,8 @@ describe('dataFrameToLogsModel', () => {
     ];
     const logsModel = dataFrameToLogsModel(series, 1);
     expect(logsModel.meta![0]).toMatchObject({
-      label: LIMIT_LABEL,
-      value: `1000 (1 displayed)`,
+      label: '',
+      value: `1 line displayed`,
       kind: LogsMetaKind.String,
     });
 
@@ -485,13 +428,59 @@ describe('dataFrameToLogsModel', () => {
   it('given one series with limit as custom meta property should return correct limit', () => {
     const series: DataFrame[] = getTestDataFrame();
     const logsModel = dataFrameToLogsModel(series, 1);
-    expect(logsModel.meta![1]).toMatchObject({
-      label: LIMIT_LABEL,
-      value: `1000 (2 returned)`,
+    expect(logsModel.meta![0]).toMatchObject({
+      label: '',
+      value: `2 lines returned`,
       kind: LogsMetaKind.String,
     });
   });
 
+  it('given one series with total as custom meta property should return correct total', () => {
+    const series: DataFrame[] = [
+      createDataFrame({
+        fields: [],
+        meta: {
+          custom: {
+            total: 9999,
+          },
+        },
+      }),
+    ];
+    const logsModel = dataFrameToLogsModel(series, 1);
+    expect(logsModel.meta![0]).toMatchObject({
+      label: TOTAL_LABEL,
+      value: 9999,
+      kind: LogsMetaKind.Number,
+    });
+  });
+
+  it('given multiple series with total as custom meta property should return correct total', () => {
+    const series: DataFrame[] = [
+      createDataFrame({
+        fields: [],
+        meta: {
+          custom: {
+            total: 4,
+          },
+        },
+      }),
+      createDataFrame({
+        fields: [],
+        meta: {
+          custom: {
+            total: 5,
+          },
+        },
+      }),
+    ];
+    const logsModel = dataFrameToLogsModel(series, 1);
+    expect(logsModel.meta![0]).toMatchObject({
+      label: TOTAL_LABEL,
+      value: 9,
+      kind: LogsMetaKind.Number,
+    });
+  });
+
   it('should return the expected meta when the line limit is reached', () => {
     const series: DataFrame[] = getTestDataFrame();
     series[0].meta = {
@@ -500,8 +489,8 @@ describe('dataFrameToLogsModel', () => {
       },
     };
     const timeRange = {
-      from: 1556270800000,
-      to: 1556270899999,
+      from: 1556270899999,
+      to: 1556357299999,
     };
     const queries = [
       {
@@ -516,16 +505,16 @@ describe('dataFrameToLogsModel', () => {
       queries
     );
     expect(logsModel.meta).toEqual([
+      {
+        label: '',
+        value: '2 lines shown — 21.85% (5h 14min 40sec) of 24h',
+        kind: 1,
+      },
       {
         label: 'Common labels',
         value: { filename: '/var/log/grafana/grafana.log', job: 'grafana' },
         kind: 2,
       },
-      {
-        label: 'Line limit',
-        value: '2 reached, received logs cover 8.65% (9sec) of your selected time range (1min 40sec)',
-        kind: 1,
-      },
     ]);
   });
 
@@ -554,16 +543,16 @@ describe('dataFrameToLogsModel', () => {
       queries
     );
     expect(logsModel.meta).toEqual([
+      {
+        label: '',
+        value: '2 reached',
+        kind: 1,
+      },
       {
         label: 'Common labels',
         value: { filename: '/var/log/grafana/grafana.log', job: 'grafana' },
         kind: 2,
       },
-      {
-        label: 'Line limit',
-        value: '2 reached',
-        kind: 1,
-      },
     ]);
   });
 
@@ -649,15 +638,15 @@ describe('dataFrameToLogsModel', () => {
     ]);
     expect(logsModel.meta).toHaveLength(2);
     expect(logsModel.meta![0]).toMatchObject({
+      label: '',
+      value: `2 lines returned`,
+      kind: LogsMetaKind.String,
+    });
+    expect(logsModel.meta![1]).toMatchObject({
       label: COMMON_LABELS,
       value: { filename: '/var/log/grafana/grafana.log', job: 'grafana' },
       kind: LogsMetaKind.LabelsMap,
     });
-    expect(logsModel.meta![1]).toMatchObject({
-      label: LIMIT_LABEL,
-      value: `1000 (2 returned)`,
-      kind: LogsMetaKind.String,
-    });
   });
 
   it('given one series with labels-field it should work regardless the label-fields position', () => {
@@ -768,20 +757,20 @@ describe('dataFrameToLogsModel', () => {
     expect(logsModel.series).toHaveLength(2);
     expect(logsModel.meta).toHaveLength(3);
     expect(logsModel.meta![0]).toMatchObject({
-      label: COMMON_LABELS,
-      value: series[0].fields[1].labels,
-      kind: LogsMetaKind.LabelsMap,
-    });
-    expect(logsModel.meta![1]).toMatchObject({
-      label: LIMIT_LABEL,
-      value: `1000 (2 returned)`,
+      label: '',
+      value: `2 lines returned`,
       kind: LogsMetaKind.String,
     });
-    expect(logsModel.meta![2]).toMatchObject({
+    expect(logsModel.meta![1]).toMatchObject({
       label: '',
       value: 'Error when parsing some of the logs',
       kind: LogsMetaKind.Error,
     });
+    expect(logsModel.meta![2]).toMatchObject({
+      label: COMMON_LABELS,
+      value: series[0].fields[1].labels,
+      kind: LogsMetaKind.LabelsMap,
+    });
   });
 
   it('given one series without labels should return expected logs model', () => {
@@ -1110,15 +1099,15 @@ describe('dataFrameToLogsModel', () => {
     const logsModel = dataFrameToLogsModel(series, 1, { from: 1556270591353, to: 1556289770991 });
     expect(logsModel.meta).toHaveLength(2);
     expect(logsModel.meta![0]).toMatchObject({
+      label: '',
+      value: `2 lines shown — 98.44% (5h 14min 40sec) of 5h 19min 40sec`,
+      kind: LogsMetaKind.String,
+    });
+    expect(logsModel.meta![1]).toMatchObject({
       label: COMMON_LABELS,
       value: series[0].fields[1].labels,
       kind: LogsMetaKind.LabelsMap,
     });
-    expect(logsModel.meta![1]).toMatchObject({
-      label: LIMIT_LABEL,
-      value: `2 reached, received logs cover 98.44% (5h 14min 40sec) of your selected time range (5h 19min 40sec)`,
-      kind: LogsMetaKind.String,
-    });
   });
 
   it('should fallback to row index if no id', () => {
@@ -1271,9 +1260,9 @@ describe('logSeriesToLogsModel', () => {
 
     const logsModel = dataFrameToLogsModel(logSeries, 0);
     expect(logsModel.meta).toMatchObject([
-      { kind: 2, label: COMMON_LABELS, value: { foo: 'bar', level: 'dbug' } },
       { kind: 0, label: LIMIT_LABEL, value: 2000 },
       { kind: 1, label: 'Total bytes processed', value: '194  kB' },
+      { kind: 2, label: COMMON_LABELS, value: { foo: 'bar', level: 'dbug' } },
     ]);
     expect(logsModel.rows).toHaveLength(3);
     expect(logsModel.rows).toMatchObject([
