@@ -39,7 +39,8 @@ import {
   toDataFrame,
   toUtc,
 } from '@grafana/data';
-import { SIPrefix } from '@grafana/data/src/valueFormats/symbolFormatters';
+import { SIPrefix } from '@grafana/data/internal';
+import { t } from '@grafana/i18n';
 import { config } from '@grafana/runtime';
 import { BarAlignment, GraphDrawStyle, StackingMode } from '@grafana/schema';
 import { colors } from '@grafana/ui';
@@ -51,6 +52,7 @@ import { createLogRowsMap, getLogLevel, getLogLevelFromKey, sortInAscendingOrder
 
 export const LIMIT_LABEL = 'Line limit';
 export const COMMON_LABELS = 'Common labels';
+export const TOTAL_LABEL = 'Total lines';
 
 export const LogLevelColor = {
   [LogLevel.critical]: colors[7],
@@ -102,16 +104,6 @@ export function dedupLogRows(rows: LogRowModel[], strategy?: LogsDedupStrategy):
   }, []);
 }
 
-export function filterLogLevels(logRows: LogRowModel[], hiddenLogLevels: Set<LogLevel>): LogRowModel[] {
-  if (hiddenLogLevels.size === 0) {
-    return logRows;
-  }
-
-  return logRows.filter((row: LogRowModel) => {
-    return !hiddenLogLevels.has(row.logLevel);
-  });
-}
-
 interface Series {
   lastTs: number | null;
   datapoints: Array<[number, number]>;
@@ -259,6 +251,7 @@ export function dataFrameToLogsModel(
  * @param intervalMs Dynamic data interval based on available pixel width
  * @param absoluteRange Requested time range
  * @param pxPerBar Default: 20, buckets will be rendered as bars, assuming 10px per histogram bar plus some free space around it
+ * @param minimumBucketSize
  */
 export function getSeriesProperties(
   sortedRows: LogRowModel[],
@@ -274,18 +267,21 @@ export function getSeriesProperties(
   let requestedRangeMs;
   // Clamp time range to visible logs otherwise big parts of the graph might look empty
   if (absoluteRange) {
-    const earliestTsLogs = sortedRows[0].timeEpochMs;
+    const firstTimeStamp = sortedRows[0].timeEpochMs;
+    const lastTimeStamp = sortedRows[sortedRows.length - 1].timeEpochMs;
+    const earliestTsLogs = firstTimeStamp < lastTimeStamp ? firstTimeStamp : lastTimeStamp;
+    const earliestLogToTimeRangeEnd = absoluteRange.to - earliestTsLogs;
 
     requestedRangeMs = absoluteRange.to - absoluteRange.from;
-    visibleRangeMs = absoluteRange.to - earliestTsLogs;
+    visibleRangeMs = Math.abs(firstTimeStamp - lastTimeStamp);
 
     if (visibleRangeMs > 0) {
       // Adjust interval bucket size for potentially shorter visible range
-      const clampingFactor = visibleRangeMs / requestedRangeMs;
+      const clampingFactor = earliestLogToTimeRangeEnd / requestedRangeMs;
       resolutionIntervalMs *= clampingFactor;
       // Minimum bucketsize of 1s for nicer graphing
       bucketSize = Math.max(Math.ceil(resolutionIntervalMs * pxPerBar), minimumBucketSize);
-      // makeSeriesForLogs() aligns dataspoints with time buckets, so we do the same here to not cut off data
+      // makeSeriesForLogs() aligns data points with time buckets, so we do the same here to not cut off data
       const adjustedEarliest = Math.floor(earliestTsLogs / bucketSize) * bucketSize;
       visibleRange = { from: adjustedEarliest, to: absoluteRange.to };
     } else {
@@ -431,7 +427,9 @@ export function logSeriesToLogsModel(
         logLevel = getLogLevel(entry);
       }
 
-      const datasourceType = queries.find((query) => query.refId === series.refId)?.datasource?.type;
+      const datasource = queries.find((query) => query.refId === series.refId)?.datasource;
+      const datasourceType = datasource?.type;
+      const datasourceUid = datasource?.uid;
 
       const row: LogRowModel = {
         entryFieldIndex: stringField.index,
@@ -453,6 +451,7 @@ export function logSeriesToLogsModel(
         // prepend refId to uid to make it unique across all series in a case when series contain duplicates
         uid: `${series.refId}_${idField ? idField.values[j] : j.toString()}`,
         datasourceType,
+        datasourceUid,
       };
 
       if (idField !== null) {
@@ -469,13 +468,6 @@ export function logSeriesToLogsModel(
 
   // Meta data to display in status
   const meta: LogsMetaItem[] = [];
-  if (size(commonLabels) > 0) {
-    meta.push({
-      label: COMMON_LABELS,
-      value: commonLabels,
-      kind: LogsMetaKind.LabelsMap,
-    });
-  }
   // Data sources that set up searchWords on backend use meta.custom.limit.
   // Data sources that set up searchWords through frontend can use meta.limit.
   const limits = logSeries.filter((series) => series?.meta?.custom?.limit ?? series?.meta?.limit);
@@ -495,6 +487,15 @@ export function logSeriesToLogsModel(
     });
   }
 
+  const totalValue = logSeries.reduce((acc, series) => (acc += series.meta?.custom?.total), 0);
+  if (totalValue > 0) {
+    meta.push({
+      label: TOTAL_LABEL,
+      value: totalValue,
+      kind: LogsMetaKind.Number,
+    });
+  }
+
   let totalBytes = 0;
   const queriesVisited: { [refId: string]: boolean } = {};
   // To add just 1 error message
@@ -528,12 +529,20 @@ export function logSeriesToLogsModel(
   if (totalBytes > 0) {
     const { text, suffix } = SIPrefix('B')(totalBytes);
     meta.push({
-      label: 'Total bytes processed',
+      label: t('logs.log-series-to-logs-model.label.total-bytes-processed', 'Total bytes processed'),
       value: `${text} ${suffix}`,
       kind: LogsMetaKind.String,
     });
   }
 
+  if (size(commonLabels) > 0) {
+    meta.push({
+      label: COMMON_LABELS,
+      value: commonLabels,
+      kind: LogsMetaKind.LabelsMap,
+    });
+  }
+
   return {
     hasUniqueLabels,
     meta,
@@ -564,17 +573,15 @@ function adjustMetaInfo(logsModel: LogsModel, visibleRangeMs?: number, requested
 
       if (canShowCoverage) {
         const coverage = ((visibleRangeMs / requestedRangeMs) * 100).toFixed(2);
-        metaLimitValue += `, received logs cover ${coverage}% (${rangeUtil.msRangeToTimeString(
-          visibleRangeMs
-        )}) of your selected time range (${rangeUtil.msRangeToTimeString(requestedRangeMs)})`;
+        metaLimitValue = `${limit} lines shown — ${coverage}% (${rangeUtil.msRangeToTimeString(visibleRangeMs)}) of ${rangeUtil.msRangeToTimeString(requestedRangeMs)}`;
       }
     } else {
       const description = config.featureToggles.logsInfiniteScrolling ? 'displayed' : 'returned';
-      metaLimitValue = `${limit} (${logsModel.rows.length} ${description})`;
+      metaLimitValue = `${logsModel.rows.length} ${logsModel.rows.length > 1 ? 'lines' : 'line'} ${description}`;
     }
 
     logsModelMeta[limitIndex] = {
-      label: LIMIT_LABEL,
+      label: '',
       value: metaLimitValue,
       kind: LogsMetaKind.String,
     };
