@@ -1,7 +1,6 @@
-import { PluginSignatureStatus, PluginSignatureType, PluginType } from '@grafana/data';
+import { PluginErrorCode, PluginSignatureStatus, PluginSignatureType, PluginType } from '@grafana/data';
 import { config } from '@grafana/runtime';
 
-import { getLocalPluginMock, getRemotePluginMock, getCatalogPluginMock } from './__mocks__';
 import {
   mapToCatalogPlugin,
   mapRemoteToCatalog,
@@ -12,8 +11,11 @@ import {
   Sorters,
   isLocalPluginVisibleByConfig,
   isRemotePluginVisibleByConfig,
+  isNonAngularVersion,
+  isDisabledAngularPlugin,
 } from './helpers';
-import { RemotePlugin, LocalPlugin, RemotePluginStatus } from './types';
+import { getLocalPluginMock, getRemotePluginMock, getCatalogPluginMock } from './mocks/mockHelpers';
+import { RemotePlugin, LocalPlugin, RemotePluginStatus, Version, CatalogPlugin } from './types';
 
 describe('Plugins/Helpers', () => {
   let remotePlugin: RemotePlugin;
@@ -92,10 +94,8 @@ describe('Plugins/Helpers', () => {
     test('core plugins should be fullyInstalled in cloud', () => {
       const corePluginId = 'plugin-core';
 
-      const oldFeatureTogglesManagedPluginsInstall = config.featureToggles.managedPluginsInstall;
       const oldPluginAdminExternalManageEnabled = config.pluginAdminExternalManageEnabled;
 
-      config.featureToggles.managedPluginsInstall = true;
       config.pluginAdminExternalManageEnabled = true;
 
       const merged = mergeLocalsAndRemotes({
@@ -109,17 +109,14 @@ describe('Plugins/Helpers', () => {
       expect(findMerged(corePluginId)?.isCore).toBe(true);
       expect(findMerged(corePluginId)?.isFullyInstalled).toBe(true);
 
-      config.featureToggles.managedPluginsInstall = oldFeatureTogglesManagedPluginsInstall;
       config.pluginAdminExternalManageEnabled = oldPluginAdminExternalManageEnabled;
     });
 
     test('plugins should be fully installed if they are installed and it is provisioned', () => {
       const pluginId = 'plugin-1';
 
-      const oldFeatureTogglesManagedPluginsInstall = config.featureToggles.managedPluginsInstall;
       const oldPluginAdminExternalManageEnabled = config.pluginAdminExternalManageEnabled;
 
-      config.featureToggles.managedPluginsInstall = true;
       config.pluginAdminExternalManageEnabled = true;
 
       const merged = mergeLocalsAndRemotes({
@@ -133,15 +130,12 @@ describe('Plugins/Helpers', () => {
       expect(findMerged(pluginId)).not.toBeUndefined();
       expect(findMerged(pluginId)?.isFullyInstalled).toBe(true);
 
-      config.featureToggles.managedPluginsInstall = oldFeatureTogglesManagedPluginsInstall;
       config.pluginAdminExternalManageEnabled = oldPluginAdminExternalManageEnabled;
     });
 
     test('plugins should have update when instance version is different from remote version', () => {
-      const oldFeatureTogglesManagedPluginsInstall = config.featureToggles.managedPluginsInstall;
       const oldPluginAdminExternalManageEnabled = config.pluginAdminExternalManageEnabled;
 
-      config.featureToggles.managedPluginsInstall = true;
       config.pluginAdminExternalManageEnabled = true;
 
       const pluginId = 'plugin-1';
@@ -162,7 +156,6 @@ describe('Plugins/Helpers', () => {
       expect(findMerged(pluginId)).not.toBeUndefined();
       expect(findMerged(pluginId)?.hasUpdate).toBe(true);
 
-      config.featureToggles.managedPluginsInstall = oldFeatureTogglesManagedPluginsInstall;
       config.pluginAdminExternalManageEnabled = oldPluginAdminExternalManageEnabled;
     });
   });
@@ -217,6 +210,7 @@ describe('Plugins/Helpers', () => {
         updatedAt: '2021-05-18T14:53:01.000Z',
         isFullyInstalled: false,
         angularDetected: false,
+        url: 'https://github.com/alexanderzobnin/grafana-zabbix',
       });
     });
 
@@ -354,6 +348,7 @@ describe('Plugins/Helpers', () => {
         installedVersion: '4.2.2',
         isFullyInstalled: true,
         angularDetected: false,
+        url: 'https://github.com/alexanderzobnin/grafana-zabbix',
       });
     });
 
@@ -883,4 +878,35 @@ describe('Plugins/Helpers', () => {
       expect(isRemotePluginVisibleByConfig(plugin)).toBe(false);
     });
   });
+
+  describe('isNonAngularVersion()', () => {
+    test('should return TRUE if the version is not using angular', () => {
+      expect(isNonAngularVersion({ angularDetected: false } as Version)).toBe(true);
+    });
+
+    test('should return FALSE if the version is using angular', () => {
+      expect(isNonAngularVersion({ angularDetected: true } as Version)).toBe(false);
+    });
+
+    test('should return FALSE if the version is not set', () => {
+      expect(isNonAngularVersion(undefined)).toBe(false);
+    });
+  });
+
+  describe('isDisabledAngularPlugin', () => {
+    it('should return true for disabled angular plugins', () => {
+      const plugin = { isDisabled: true, error: PluginErrorCode.angular } as CatalogPlugin;
+      expect(isDisabledAngularPlugin(plugin)).toBe(true);
+    });
+
+    it('should return false for non-angular plugins', () => {
+      const plugin = { isDisabled: true, error: undefined } as CatalogPlugin;
+      expect(isDisabledAngularPlugin(plugin)).toBe(false);
+    });
+
+    it('should return false for plugins that are not disabled', () => {
+      const plugin = { isDisabled: false, error: undefined } as CatalogPlugin;
+      expect(isDisabledAngularPlugin(plugin)).toBe(false);
+    });
+  });
 });
