@@ -9,13 +9,14 @@ import {
   dateTimeFormatTimeAgo,
   WithAccessControlMetadata,
 } from '@grafana/data';
+import { GrafanaEdition } from '@grafana/data/internal';
 import { selectors } from '@grafana/e2e-selectors';
-import { config } from '@grafana/runtime';
+import { config, getBackendSrv, setBackendSrv } from '@grafana/runtime';
 import { configureStore } from 'app/store/configureStore';
 
-import { mockPluginApis, getCatalogPluginMock, getPluginsStateMock, mockUserPermissions } from '../__mocks__';
 import * as api from '../api';
 import { usePluginConfig } from '../hooks/usePluginConfig';
+import { mockPluginApis, getCatalogPluginMock, getPluginsStateMock, mockUserPermissions } from '../mocks/mockHelpers';
 import { fetchRemotePlugins } from '../state/actions';
 import {
   CatalogPlugin,
@@ -29,27 +30,17 @@ import {
 import PluginDetailsPage from './PluginDetails';
 
 jest.mock('@grafana/runtime', () => {
-  const original = jest.requireActual('@grafana/runtime');
-  const mockedRuntime = { ...original };
-  mockedRuntime.config.buildInfo.version = 'v8.1.0';
-  return mockedRuntime;
+  const runtime = jest.requireActual('@grafana/runtime');
+  runtime.config.buildInfo.version = 'v8.1.0';
+
+  return runtime;
 });
 
-jest.mock('../hooks/usePluginConfig.tsx', () => ({
-  usePluginConfig: jest.fn(() => ({
-    value: {
-      meta: {},
-    },
-  })),
-}));
-
-jest.mock('../helpers.ts', () => ({
-  ...jest.requireActual('../helpers.ts'),
-  updatePanels: jest.fn(),
-}));
+jest.mock('../hooks/usePluginConfig.tsx', () => ({ usePluginConfig: jest.fn(() => ({ value: { meta: {} } })) }));
 
 jest.mock('app/core/core', () => ({
   contextSrv: {
+    ...jest.requireActual('app/core/core').contextSrv,
     hasPermission: (action: string) => true,
     hasPermissionInMetadata: (action: string, object: WithAccessControlMetadata) => true,
   },
@@ -57,19 +48,11 @@ jest.mock('app/core/core', () => ({
 
 const renderPluginDetails = (
   pluginOverride: Partial<CatalogPlugin>,
-  {
-    pageId,
-    pluginsStateOverride,
-  }: {
-    pageId?: PluginTabIds;
-    pluginsStateOverride?: ReducerState;
-  } = {}
+  { pageId, pluginsStateOverride }: { pageId?: PluginTabIds; pluginsStateOverride?: ReducerState } = {}
 ) => {
   const plugin = getCatalogPluginMock(pluginOverride);
   const { id } = plugin;
-  const store = configureStore({
-    plugins: pluginsStateOverride || getPluginsStateMock([plugin]),
-  });
+  const store = configureStore({ plugins: pluginsStateOverride || getPluginsStateMock([plugin]) });
 
   return render(
     <Routes>
@@ -84,21 +67,20 @@ describe('Plugin details page', () => {
   const id = 'my-plugin';
   const originalWindowLocation = window.location;
   let dateNow: jest.SpyInstance<number, []>;
+  const originalBackendSrv = getBackendSrv();
 
   beforeAll(() => {
     dateNow = jest.spyOn(Date, 'now').mockImplementation(() => 1609470000000); // 2021-01-01 04:00:00
 
     // Enabling / disabling the plugin is currently reloading the page to propagate the changes
-    Object.defineProperty(window, 'location', {
-      configurable: true,
-      value: { reload: jest.fn() },
-    });
+    Object.defineProperty(window, 'location', { configurable: true, value: { reload: jest.fn() } });
   });
 
   afterEach(() => {
     jest.clearAllMocks();
     config.pluginAdminExternalManageEnabled = false;
     config.licenseInfo.enabledFeatures = {};
+    setBackendSrv(originalBackendSrv);
   });
 
   afterAll(() => {
@@ -108,21 +90,14 @@ describe('Plugin details page', () => {
 
   describe('viewed as user with grafana admin permissions', () => {
     beforeAll(() => {
-      mockUserPermissions({
-        isAdmin: true,
-        isDataSourceEditor: true,
-        isOrgAdmin: true,
-      });
+      mockUserPermissions({ isAdmin: true, isDataSourceEditor: true, isOrgAdmin: true });
     });
 
     // We are doing this very basic test to see if the API fetching and data-munging is working correctly from a high-level.
     it('(SMOKE TEST) - should fetch and merge the remote and local plugin API responses correctly ', async () => {
       const id = 'smoke-test-plugin';
 
-      mockPluginApis({
-        remote: { slug: id },
-        local: { id },
-      });
+      mockPluginApis({ remote: { slug: id }, local: { id } });
 
       const { queryByText } = renderPluginDetails({ id });
 
@@ -141,12 +116,7 @@ describe('Plugin details page', () => {
       // @ts-ignore
       usePluginConfig.mockReturnValue({
         value: {
-          meta: {
-            type: PluginType.app,
-            enabled: false,
-            pinned: false,
-            jsonData: {},
-          },
+          meta: { type: PluginType.app, enabled: false, pinned: false, jsonData: {} },
           configPages: [
             {
               title: 'Config',
@@ -160,11 +130,7 @@ describe('Plugin details page', () => {
         },
       });
 
-      const { queryByText } = renderPluginDetails({
-        name,
-        isInstalled: true,
-        type: PluginType.app,
-      });
+      const { queryByText } = renderPluginDetails({ name, isInstalled: true, type: PluginType.app });
 
       expect(await queryByText(/custom config page/i)).toBeInTheDocument();
     });
@@ -238,34 +204,13 @@ describe('Plugin details page', () => {
 
     it('should display version history if the plugin is published', async () => {
       const versions = [
-        {
-          version: '1.2.0',
-          createdAt: '2018-04-06T20:23:41.000Z',
-          isCompatible: false,
-          grafanaDependency: '>=8.3.0',
-        },
-        {
-          version: '1.1.0',
-          createdAt: '2017-04-06T20:23:41.000Z',
-          isCompatible: true,
-          grafanaDependency: '>=8.0.0',
-        },
-        {
-          version: '1.0.0',
-          createdAt: '2016-04-06T20:23:41.000Z',
-          isCompatible: true,
-          grafanaDependency: '>=7.0.0',
-        },
+        { version: '1.2.0', createdAt: '2018-04-06T20:23:41.000Z', isCompatible: false, grafanaDependency: '>=8.3.0' },
+        { version: '1.1.0', createdAt: '2017-04-06T20:23:41.000Z', isCompatible: true, grafanaDependency: '>=8.0.0' },
+        { version: '1.0.0', createdAt: '2016-04-06T20:23:41.000Z', isCompatible: true, grafanaDependency: '>=7.0.0' },
       ];
 
       const { findByRole, queryByText, getByRole } = renderPluginDetails(
-        {
-          id,
-          details: {
-            links: [],
-            versions,
-          },
-        },
+        { id, details: { links: [], versions } },
         { pageId: PluginTabIds.VERSIONS }
       );
 
@@ -274,7 +219,7 @@ describe('Plugin details page', () => {
 
       // Check the column headers
       expect(getByRole('columnheader', { name: /version/i })).toBeInTheDocument();
-      expect(getByRole('columnheader', { name: /last updated/i })).toBeInTheDocument();
+      expect(getByRole('columnheader', { name: /latest release date/i })).toBeInTheDocument();
 
       // Check the data
       for (const version of versions) {
@@ -354,6 +299,7 @@ describe('Plugin details page', () => {
 
     it('should not display install button for enterprise plugins if license is invalid (but allow uninstall)', async () => {
       config.licenseInfo.enabledFeatures = {};
+      config.buildInfo.edition = GrafanaEdition.Enterprise;
 
       const { queryByRole, queryByText } = renderPluginDetails({ id, isInstalled: true, isEnterprise: true });
 
@@ -391,31 +337,6 @@ describe('Plugin details page', () => {
       expect(await queryByRole('button', { name: /(un)?install/i })).not.toBeInTheDocument();
     });
 
-    it('should display install link with `config.pluginAdminExternalManageEnabled` set to true', async () => {
-      config.pluginAdminExternalManageEnabled = true;
-
-      const { queryByRole } = renderPluginDetails({ id, isInstalled: false });
-
-      expect(await queryByRole('link', { name: /install via grafana.com/i })).toBeInTheDocument();
-    });
-
-    it('should display uninstall link for an installed plugin with `config.pluginAdminExternalManageEnabled` set to true', async () => {
-      config.pluginAdminExternalManageEnabled = true;
-
-      const { queryByRole } = renderPluginDetails({ id, isInstalled: true });
-
-      expect(await queryByRole('link', { name: /uninstall via grafana.com/i })).toBeInTheDocument();
-    });
-
-    it('should display update and uninstall links for a plugin with an available update and `config.pluginAdminExternalManageEnabled` set to true', async () => {
-      config.pluginAdminExternalManageEnabled = true;
-
-      const { queryByRole } = renderPluginDetails({ id, isInstalled: true, hasUpdate: true });
-
-      expect(await queryByRole('link', { name: /update via grafana.com/i })).toBeInTheDocument();
-      expect(queryByRole('link', { name: /uninstall via grafana.com/i })).toBeInTheDocument();
-    });
-
     it('should display alert with information about why the plugin is disabled', async () => {
       const { queryByTestId } = renderPluginDetails({
         id,
@@ -430,11 +351,7 @@ describe('Plugin details page', () => {
     it('should display grafana dependencies for a plugin if they are available', async () => {
       const { queryByText } = renderPluginDetails({
         id,
-        details: {
-          pluginDependencies: [],
-          grafanaDependency: '>=8.0.0',
-          links: [],
-        },
+        details: { pluginDependencies: [], grafanaDependency: '>=8.0.0', links: [] },
       });
 
       // Wait for the dependencies part to be loaded
@@ -445,6 +362,8 @@ describe('Plugin details page', () => {
       // @ts-ignore
       api.uninstallPlugin = jest.fn();
 
+      setBackendSrv({ ...originalBackendSrv, get: jest.fn().mockResolvedValue({ panels: [] }) });
+
       const { queryByText, getByRole, findByRole, user } = renderPluginDetails({
         id,
         name: 'Akumuli',
@@ -453,14 +372,7 @@ describe('Plugin details page', () => {
           pluginDependencies: [],
           grafanaDependency: '>=8.0.0',
           links: [],
-          versions: [
-            {
-              version: '1.0.0',
-              createdAt: '',
-              isCompatible: true,
-              grafanaDependency: '>=8.0.0',
-            },
-          ],
+          versions: [{ version: '1.0.0', createdAt: '', isCompatible: true, grafanaDependency: '>=8.0.0' }],
         },
       });
 
@@ -491,12 +403,7 @@ describe('Plugin details page', () => {
       // Mock the store like if the remote plugins request was rejected
       const pluginsStateOverride = {
         ...state,
-        requests: {
-          ...state.requests,
-          [fetchRemotePlugins.typePrefix]: {
-            status: RequestStatus.Rejected,
-          },
-        },
+        requests: { ...state.requests, [fetchRemotePlugins.typePrefix]: { status: RequestStatus.Rejected } },
       };
 
       // Does not show an Install button
@@ -542,11 +449,7 @@ describe('Plugin details page', () => {
 
     it('should display a "Create" button as a post installation step for installed data source plugins', async () => {
       const name = 'Akumuli';
-      const { queryByText } = renderPluginDetails({
-        name,
-        isInstalled: true,
-        type: PluginType.datasource,
-      });
+      const { queryByText } = renderPluginDetails({ name, isInstalled: true, type: PluginType.datasource });
 
       await waitFor(() => queryByText('Uninstall'));
       expect(queryByText('Add new data source')).toBeInTheDocument();
@@ -567,11 +470,7 @@ describe('Plugin details page', () => {
 
     it('should not display post installation step for panel plugins', async () => {
       const name = 'Akumuli';
-      const { queryByText } = renderPluginDetails({
-        name,
-        isInstalled: true,
-        type: PluginType.panel,
-      });
+      const { queryByText } = renderPluginDetails({ name, isInstalled: true, type: PluginType.panel });
 
       await waitFor(() => queryByText('Uninstall'));
       expect(queryByText('Add new data source')).toBeNull();
@@ -581,21 +480,9 @@ describe('Plugin details page', () => {
       const name = 'Akumuli';
 
       // @ts-ignore
-      usePluginConfig.mockReturnValue({
-        value: {
-          meta: {
-            enabled: false,
-            pinned: false,
-            jsonData: {},
-          },
-        },
-      });
+      usePluginConfig.mockReturnValue({ value: { meta: { enabled: false, pinned: false, jsonData: {} } } });
 
-      const { queryByText, queryByRole } = renderPluginDetails({
-        name,
-        isInstalled: true,
-        type: PluginType.app,
-      });
+      const { queryByText, queryByRole } = renderPluginDetails({ name, isInstalled: true, type: PluginType.app });
 
       await waitFor(() => queryByText('Uninstall'));
 
@@ -607,21 +494,9 @@ describe('Plugin details page', () => {
       const name = 'Akumuli';
 
       // @ts-ignore
-      usePluginConfig.mockReturnValue({
-        value: {
-          meta: {
-            enabled: true,
-            pinned: false,
-            jsonData: {},
-          },
-        },
-      });
+      usePluginConfig.mockReturnValue({ value: { meta: { enabled: true, pinned: false, jsonData: {} } } });
 
-      const { queryByText, queryByRole } = renderPluginDetails({
-        name,
-        isInstalled: true,
-        type: PluginType.app,
-      });
+      const { queryByText, queryByRole } = renderPluginDetails({ name, isInstalled: true, type: PluginType.app });
 
       await waitFor(() => queryByText('Uninstall'));
 
@@ -637,15 +512,7 @@ describe('Plugin details page', () => {
       api.updatePluginSettings = jest.fn();
 
       // @ts-ignore
-      usePluginConfig.mockReturnValue({
-        value: {
-          meta: {
-            enabled: false,
-            pinned: false,
-            jsonData: {},
-          },
-        },
-      });
+      usePluginConfig.mockReturnValue({ value: { meta: { enabled: false, pinned: false, jsonData: {} } } });
 
       const { queryByText, getByRole, user } = renderPluginDetails({
         id,
@@ -662,11 +529,7 @@ describe('Plugin details page', () => {
 
       // Check if the API request was initiated
       expect(api.updatePluginSettings).toHaveBeenCalledTimes(1);
-      expect(api.updatePluginSettings).toHaveBeenCalledWith(id, {
-        enabled: true,
-        pinned: true,
-        jsonData: {},
-      });
+      expect(api.updatePluginSettings).toHaveBeenCalledWith(id, { enabled: true, pinned: true, jsonData: {} });
     });
 
     it('should be possible to disable an app plugin', async () => {
@@ -677,15 +540,7 @@ describe('Plugin details page', () => {
       api.updatePluginSettings = jest.fn();
 
       // @ts-ignore
-      usePluginConfig.mockReturnValue({
-        value: {
-          meta: {
-            enabled: true,
-            pinned: true,
-            jsonData: {},
-          },
-        },
-      });
+      usePluginConfig.mockReturnValue({ value: { meta: { enabled: true, pinned: true, jsonData: {} } } });
 
       const { queryByText, getByRole, user } = renderPluginDetails({
         id,
@@ -702,11 +557,7 @@ describe('Plugin details page', () => {
 
       // Check if the API request was initiated
       expect(api.updatePluginSettings).toHaveBeenCalledTimes(1);
-      expect(api.updatePluginSettings).toHaveBeenCalledWith(id, {
-        enabled: false,
-        pinned: false,
-        jsonData: {},
-      });
+      expect(api.updatePluginSettings).toHaveBeenCalledWith(id, { enabled: false, pinned: false, jsonData: {} });
     });
 
     it('should not display versions tab for plugins not published to gcom', async () => {
@@ -763,37 +614,25 @@ describe('Plugin details page', () => {
     });
 
     it('shows a "angular warning" if the plugin uses Angular', async () => {
-      const { queryByText } = renderPluginDetails({
-        angularDetected: true,
-      });
+      const { queryByText } = renderPluginDetails({ angularDetected: true });
 
       await waitFor(() => expect(queryByText(/angular plugin/i)).toBeInTheDocument);
     });
 
     it('does not show an "angular warning" if the plugin is not using Angular', async () => {
-      const { queryByText } = renderPluginDetails({
-        angularDetected: false,
-      });
+      const { queryByText } = renderPluginDetails({ angularDetected: false });
 
       await waitFor(() => expect(queryByText(/angular plugin/i)).not.toBeInTheDocument);
     });
 
     it('should display a deprecation warning if the plugin is deprecated', async () => {
-      const { findByRole } = renderPluginDetails({
-        id,
-        isInstalled: true,
-        isDeprecated: true,
-      });
+      const { findByRole } = renderPluginDetails({ id, isInstalled: true, isDeprecated: true });
 
       expect(await findByRole('link', { name: 'deprecated' })).toBeInTheDocument();
     });
 
     it('should not display a deprecation warning in the plugin is not deprecated', async () => {
-      const { queryByRole } = renderPluginDetails({
-        id,
-        isInstalled: true,
-        isDeprecated: false,
-      });
+      const { queryByRole } = renderPluginDetails({ id, isInstalled: true, isDeprecated: false });
 
       await waitFor(() => expect(queryByRole('link', { name: 'deprecated' })).not.toBeInTheDocument());
     });
@@ -804,10 +643,7 @@ describe('Plugin details page', () => {
         id,
         isInstalled: true,
         isDeprecated: true,
-        details: {
-          statusContext,
-          links: [],
-        },
+        details: { statusContext, links: [] },
       });
 
       expect(await findByRole('link', { name: 'deprecated' })).toBeInTheDocument();
@@ -821,10 +657,7 @@ describe('Plugin details page', () => {
         id,
         isInstalled: true,
         isDeprecated: true,
-        details: {
-          statusContext,
-          links: [],
-        },
+        details: { statusContext, links: [] },
       });
 
       expect(await findByRole('link', { name: 'deprecated' })).toBeInTheDocument();
@@ -837,11 +670,7 @@ describe('Plugin details page', () => {
 
   describe('viewed as user without grafana admin permissions', () => {
     beforeAll(() => {
-      mockUserPermissions({
-        isAdmin: false,
-        isDataSourceEditor: false,
-        isOrgAdmin: false,
-      });
+      mockUserPermissions({ isAdmin: false, isDataSourceEditor: false, isOrgAdmin: false });
     });
 
     it("should not display an install button for a plugin that isn't installed", async () => {
@@ -879,20 +708,12 @@ describe('Plugin details page', () => {
 
   describe('viewed as user without data source edit permissions', () => {
     beforeAll(() => {
-      mockUserPermissions({
-        isAdmin: true,
-        isDataSourceEditor: false,
-        isOrgAdmin: true,
-      });
+      mockUserPermissions({ isAdmin: true, isDataSourceEditor: false, isOrgAdmin: true });
     });
 
     it('should not display the data source post installation step', async () => {
       const name = 'Akumuli';
-      const { queryByText } = renderPluginDetails({
-        name,
-        isInstalled: true,
-        type: PluginType.app,
-      });
+      const { queryByText } = renderPluginDetails({ name, isInstalled: true, type: PluginType.app });
 
       await waitFor(() => queryByText('Uninstall'));
       expect(queryByText('Add new data source')).toBeNull();
@@ -901,23 +722,14 @@ describe('Plugin details page', () => {
 
   describe('Display plugin details right panel', () => {
     beforeAll(() => {
-      mockUserPermissions({
-        isAdmin: true,
-        isDataSourceEditor: false,
-        isOrgAdmin: true,
-      });
-      config.featureToggles.pluginsDetailsRightPanel = true;
+      mockUserPermissions({ isAdmin: true, isDataSourceEditor: false, isOrgAdmin: true });
     });
 
-    afterAll(() => {
-      config.featureToggles.pluginsDetailsRightPanel = false;
-    });
-
-    it('should display Last updated and report a concern information', async () => {
+    it('should display Latest release date and report a concern information', async () => {
       const id = 'right-panel-test-plugin';
       const updatedAt = '2023-10-26T16:54:55.000Z';
       const { queryByText } = renderPluginDetails({ id, updatedAt });
-      expect(queryByText('Last updated:')).toBeVisible();
+      expect(queryByText('Latest release date:')).toBeVisible();
       expect(queryByText('Oct 26, 2023')).toBeVisible();
       expect(queryByText('Report a concern')).toBeVisible();
     });
@@ -929,21 +741,6 @@ describe('Plugin details page', () => {
       expect(queryByText('Last updated:')).toBeNull();
     });
 
-    it('should display last commit date information', async () => {
-      const id = 'right-panel-test-plugin';
-      const lastCommitDate = '2023-10-26T16:54:55.000Z';
-      const { queryByText } = renderPluginDetails({ id, details: { lastCommitDate, links: [] } });
-      expect(queryByText('Last commit date:')).toBeVisible();
-      expect(queryByText('Oct 26, 2023')).toBeVisible();
-    });
-
-    it('should not display last commit date if there is no lastCommit data', async () => {
-      const id = 'right-panel-test-plugin';
-      const lastCommitDate = undefined;
-      const { queryByText } = renderPluginDetails({ id, details: { lastCommitDate, links: [] } });
-      expect(queryByText('Last commit date:')).toBeNull();
-    });
-
     it('should not display Report Abuse if the plugin is Core', async () => {
       const id = 'right-panel-test-plugin';
       const isCore = true;
