@@ -1,20 +1,22 @@
 import { css } from '@emotion/css';
-import React, { PureComponent, useEffect, useState } from 'react';
+import { PureComponent, useEffect, useState } from 'react';
+import * as React from 'react';
 import { Unsubscribable } from 'rxjs';
 
 import {
   CoreApp,
   DataSourceApi,
   DataSourceInstanceSettings,
+  getDataSourceRef,
   getDefaultTimeRange,
   LoadingState,
   PanelData,
-  PluginType,
 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
+import { Trans, t } from '@grafana/i18n';
 import { getDataSourceSrv, locationService } from '@grafana/runtime';
 import { DataQuery } from '@grafana/schema';
-import { Button, CustomScrollbar, HorizontalGroup, InlineFormLabel, Modal, stylesFactory } from '@grafana/ui';
+import { Button, InlineFormLabel, Modal, ScrollContainer, Stack, stylesFactory } from '@grafana/ui';
 import { PluginHelp } from 'app/core/components/PluginHelp/PluginHelp';
 import config from 'app/core/config';
 import { backendSrv } from 'app/core/services/backend_srv';
@@ -22,12 +24,10 @@ import { addQuery, queryIsEmpty } from 'app/core/utils/query';
 import { DataSourceModal } from 'app/features/datasources/components/picker/DataSourceModal';
 import { DataSourcePicker } from 'app/features/datasources/components/picker/DataSourcePicker';
 import { dataSource as expressionDatasource } from 'app/features/expressions/ExpressionDatasource';
-import { AngularDeprecationPluginNotice } from 'app/features/plugins/angularDeprecation/AngularDeprecationPluginNotice';
-import { isSharedDashboardQuery } from 'app/plugins/datasource/dashboard';
+import { isSharedDashboardQuery } from 'app/plugins/datasource/dashboard/runSharedRequest';
 import { GrafanaQuery } from 'app/plugins/datasource/grafana/types';
-import { QueryGroupOptions } from 'app/types';
+import { QueryGroupOptions } from 'app/types/query';
 
-import { isAngularDatasourcePluginAndNotHidden } from '../../plugins/angularDeprecation/utils';
 import { PanelQueryRunner } from '../state/PanelQueryRunner';
 import { updateQueries } from '../state/updateQueries';
 
@@ -148,8 +148,7 @@ export class QueryGroup extends PureComponent<Props, State> {
       dataSource: {
         name: newSettings.name,
         uid: newSettings.uid,
-        type: newSettings.meta.id,
-        default: newSettings.isDefault,
+        ...getDataSourceRef(newSettings),
       },
     });
 
@@ -173,11 +172,16 @@ export class QueryGroup extends PureComponent<Props, State> {
   newQuery(): Partial<DataQuery> {
     const { dsSettings, defaultDataSource } = this.state;
 
-    const ds = !dsSettings?.meta.mixed ? dsSettings : defaultDataSource;
+    const ds =
+      dsSettings && !dsSettings.meta.mixed
+        ? getDataSourceRef(dsSettings)
+        : defaultDataSource
+          ? defaultDataSource.getRef()
+          : { type: undefined, uid: undefined };
 
     return {
       ...this.state.dataSource?.getDefaultQuery?.(CoreApp.PanelEditor),
-      datasource: { uid: ds?.uid, type: ds?.type },
+      datasource: ds,
     };
   }
 
@@ -240,7 +244,9 @@ export class QueryGroup extends PureComponent<Props, State> {
 
   onAddQuery = (query: Partial<DataQuery>) => {
     const { dsSettings, queries } = this.state;
-    this.onQueriesChange(addQuery(queries, query, { type: dsSettings?.type, uid: dsSettings?.uid }));
+    this.onQueriesChange(
+      addQuery(queries, query, dsSettings ? getDataSourceRef(dsSettings) : { type: undefined, uid: undefined })
+    );
     this.onScrollBottom();
   };
 
@@ -268,7 +274,7 @@ export class QueryGroup extends PureComponent<Props, State> {
   }
 
   isExpressionsSupported(dsSettings: DataSourceInstanceSettings): boolean {
-    return (dsSettings.meta.alerting || dsSettings.meta.mixed) === true;
+    return (dsSettings.meta.backend || dsSettings.meta.alerting || dsSettings.meta.mixed) === true;
   }
 
   renderExtraActions() {
@@ -287,7 +293,7 @@ export class QueryGroup extends PureComponent<Props, State> {
     const showAddButton = !isSharedDashboardQuery(dsSettings.name);
 
     return (
-      <HorizontalGroup spacing="md" align="flex-start">
+      <Stack gap={2} alignItems="flex-start">
         {showAddButton && (
           <Button
             icon="plus"
@@ -295,7 +301,7 @@ export class QueryGroup extends PureComponent<Props, State> {
             variant="secondary"
             data-testid={selectors.components.QueryTab.addQuery}
           >
-            Add query
+            <Trans i18nKey="query.query-group.add-query">Add query</Trans>
           </Button>
         )}
         {config.expressionsEnabled && this.isExpressionsSupported(dsSettings) && (
@@ -306,11 +312,13 @@ export class QueryGroup extends PureComponent<Props, State> {
             className={styles.expressionButton}
             data-testid="query-tab-add-expression"
           >
-            <span>Expression&nbsp;</span>
+            <span>
+              <Trans i18nKey="query.query-group.expression">Expression</Trans>
+            </span>
           </Button>
         )}
         {this.renderExtraActions()}
-      </HorizontalGroup>
+      </Stack>
     );
   }
 
@@ -323,7 +331,7 @@ export class QueryGroup extends PureComponent<Props, State> {
     const styles = getStyles();
 
     return (
-      <CustomScrollbar autoHeightMin="100%" scrollRefCallback={this.setScrollRef}>
+      <ScrollContainer minHeight="100%" ref={this.setScrollRef}>
         <div className={styles.innerWrapper}>
           {this.renderTopSection(styles)}
           {dsSettings && (
@@ -331,14 +339,18 @@ export class QueryGroup extends PureComponent<Props, State> {
               <div className={styles.queriesWrapper}>{this.renderQueries(dsSettings)}</div>
               {this.renderAddQueryRow(dsSettings, styles)}
               {isHelpOpen && (
-                <Modal title="Data source help" isOpen={true} onDismiss={this.onCloseHelp}>
+                <Modal
+                  title={t('query.query-group.title-data-source-help', 'Data source help')}
+                  isOpen={true}
+                  onDismiss={this.onCloseHelp}
+                >
                   <PluginHelp pluginId={dsSettings.meta.id} />
                 </Modal>
               )}
             </>
           )}
         </div>
-      </CustomScrollbar>
+      </ScrollContainer>
     );
   }
 }
@@ -347,29 +359,29 @@ const getStyles = stylesFactory(() => {
   const { theme } = config;
 
   return {
-    innerWrapper: css`
-      display: flex;
-      flex-direction: column;
-      padding: ${theme.spacing.md};
-    `,
-    dataSourceRow: css`
-      display: flex;
-      margin-bottom: ${theme.spacing.md};
-    `,
-    dataSourceRowItem: css`
-      margin-right: ${theme.spacing.inlineFormMargin};
-    `,
-    dataSourceRowItemOptions: css`
-      flex-grow: 1;
-      margin-right: ${theme.spacing.inlineFormMargin};
-    `,
-    queriesWrapper: css`
-      padding-bottom: 16px;
-    `,
-    expressionWrapper: css``,
-    expressionButton: css`
-      margin-right: ${theme.spacing.sm};
-    `,
+    innerWrapper: css({
+      display: 'flex',
+      flexDirection: 'column',
+      padding: theme.spacing.md,
+    }),
+    dataSourceRow: css({
+      display: 'flex',
+      marginBottom: theme.spacing.md,
+    }),
+    dataSourceRowItem: css({
+      marginRight: theme.spacing.inlineFormMargin,
+    }),
+    dataSourceRowItemOptions: css({
+      flexGrow: 1,
+      marginRight: theme.spacing.inlineFormMargin,
+    }),
+    queriesWrapper: css({
+      paddingBottom: '16px',
+    }),
+    expressionWrapper: css({}),
+    expressionButton: css({
+      marginRight: theme.spacing.sm,
+    }),
   };
 });
 
@@ -396,12 +408,13 @@ export function QueryGroupTopSection({
 }: QueryGroupTopSectionProps) {
   const styles = getStyles();
   const [isHelpOpen, setIsHelpOpen] = useState(false);
+
   return (
     <>
-      <div>
+      <div data-testid={selectors.components.QueryTab.queryGroupTopSection}>
         <div className={styles.dataSourceRow}>
           <InlineFormLabel htmlFor="data-source-picker" width={'auto'}>
-            Data source
+            <Trans i18nKey="query.query-group-top-section.data-source">Data source</Trans>
           </InlineFormLabel>
           <div className={styles.dataSourceRowItem}>
             <DataSourcePickerWithPrompt
@@ -418,7 +431,10 @@ export function QueryGroupTopSection({
                 <Button
                   variant="secondary"
                   icon="question-circle"
-                  title="Open data source help"
+                  tooltip={t(
+                    'query.query-group-top-section.query-tab-help-button-title-open-data-source-help',
+                    'Open data source help'
+                  )}
                   onClick={() => setIsHelpOpen(true)}
                   data-testid="query-tab-help-button"
                 />
@@ -440,25 +456,20 @@ export function QueryGroupTopSection({
                     onClick={onOpenQueryInspector}
                     aria-label={selectors.components.QueryTab.queryInspectorButton}
                   >
-                    Query inspector
+                    <Trans i18nKey="query.query-group-top-section.query-inspector">Query inspector</Trans>
                   </Button>
                 </div>
               )}
             </>
           )}
         </div>
-        {dataSource && isAngularDatasourcePluginAndNotHidden(dataSource.uid) && (
-          <AngularDeprecationPluginNotice
-            pluginId={dataSource.type}
-            pluginType={PluginType.datasource}
-            angularSupportEnabled={config?.angularSupportEnabled}
-            showPluginDetailsLink={true}
-            interactionElementId="datasource-query"
-          />
-        )}
       </div>
       {isHelpOpen && (
-        <Modal title="Data source help" isOpen={true} onDismiss={() => setIsHelpOpen(false)}>
+        <Modal
+          title={t('query.query-group-top-section.title-data-source-help', 'Data source help')}
+          isOpen={true}
+          onDismiss={() => setIsHelpOpen(false)}
+        >
           <PluginHelp pluginId={dsSettings.meta.id} />
         </Modal>
       )}
