@@ -14,7 +14,7 @@ export function getGrafanaSearcher(): GrafanaSearcher {
 
     const useBluge = config.featureToggles.panelTitleSearch;
     searcher = useBluge ? new BlugeSearcher(sqlSearcher) : sqlSearcher;
-    if (useBluge && location.search.includes('do-frontend-query')) {
+    if (useBluge && window.location.search.includes('do-frontend-query')) {
       return new FrontendSearcher(searcher);
     }
 
