@@ -1,6 +1,18 @@
 import { DataFrameView, SelectableValue } from '@grafana/data';
 import { TermCount } from 'app/core/components/TagFilter/TagFilter';
-import { PermissionLevelString } from 'app/types';
+import { PermissionLevelString } from 'app/types/acl';
+
+import { ManagerKind } from '../../apiserver/types';
+
+export interface SortOption {
+  description: string;
+  displayName: string;
+  meta: string;
+  name: string;
+}
+export interface SortOptions {
+  sortOptions: SortOption[];
+}
 
 export interface FacetField {
   field: string;
@@ -29,6 +41,7 @@ export interface SearchQuery {
   starred?: boolean;
   permission?: PermissionLevelString;
   deleted?: boolean;
+  offset?: number;
 }
 
 export interface DashboardQueryResult {
@@ -46,6 +59,7 @@ export interface DashboardQueryResult {
   // debugging fields
   score: number;
   explain: {};
+  managedBy?: ManagerKind;
 
   // enterprise sends extra properties through for sorting (views, errors, etc)
   [key: string]: unknown;
@@ -91,4 +105,5 @@ export interface GrafanaSearcher {
 export interface NestedFolderDTO {
   uid: string;
   title: string;
+  managedBy?: ManagerKind;
 }
