@@ -12,12 +12,11 @@ import {
   Field,
   getValueFormat,
   formattedValueToString,
-  durationToMilliseconds,
-  parseDuration,
   TransformationApplicabilityLevels,
+  TimeRange,
 } from '@grafana/data';
-import { isLikelyAscendingVector } from '@grafana/data/src/transformations/transformers/joinDataFrames';
-import { config } from '@grafana/runtime';
+import { isLikelyAscendingVector } from '@grafana/data/internal';
+import { t } from '@grafana/i18n';
 import {
   ScaleDistribution,
   HeatmapCellLayout,
@@ -25,17 +24,20 @@ import {
   HeatmapCalculationOptions,
 } from '@grafana/schema';
 
-import { niceLinearIncrs, niceTimeIncrs } from './utils';
+import { convertDurationToMilliseconds, niceLinearIncrs, niceTimeIncrs } from './utils';
 
 export interface HeatmapTransformerOptions extends HeatmapCalculationOptions {
   /** the raw values will still exist in results after transformation */
   keepOriginalData?: boolean;
 }
 
-export const heatmapTransformer: SynchronousDataTransformerInfo<HeatmapTransformerOptions> = {
+export const getHeatmapTransformer: () => SynchronousDataTransformerInfo<HeatmapTransformerOptions> = () => ({
   id: DataTransformerID.heatmap,
-  name: 'Create heatmap',
-  description: 'Generate heatmap data from source data.',
+  name: t('transformers.get-heatmap-transformer.name.create-heatmap', 'Create heatmap'),
+  description: t(
+    'transformers.get-heatmap-transformer.description.generate-heatmap-data-from-source',
+    'Generate heatmap data from source data.'
+  ),
   defaultOptions: {},
   isApplicable: (data) => {
     const { xField, yField, xs, ys } = findHeatmapFields(data);
@@ -53,29 +55,7 @@ export const heatmapTransformer: SynchronousDataTransformerInfo<HeatmapTransform
   isApplicableDescription:
     'The Heatmap transformation requires fields with Heatmap compatible data. No fields with Heatmap data could be found.',
   operator: (options, ctx) => (source) =>
-    source.pipe(
-      map((data) => {
-        if (config.featureToggles.transformationsVariableSupport) {
-          const optionsCopy = {
-            ...options,
-            xBuckets: { ...options.xBuckets } ?? undefined,
-            yBuckets: { ...options.yBuckets } ?? undefined,
-          };
-
-          if (optionsCopy.xBuckets?.value) {
-            optionsCopy.xBuckets.value = ctx.interpolate(optionsCopy.xBuckets.value);
-          }
-
-          if (optionsCopy.yBuckets?.value) {
-            optionsCopy.yBuckets.value = ctx.interpolate(optionsCopy.yBuckets.value);
-          }
-
-          return heatmapTransformer.transformer(optionsCopy, ctx)(data);
-        } else {
-          return heatmapTransformer.transformer(options, ctx)(data);
-        }
-      })
-    ),
+    source.pipe(map((data) => getHeatmapTransformer().transformer(options, ctx)(data))),
 
   transformer: (options: HeatmapTransformerOptions) => {
     return (data: DataFrame[]) => {
@@ -86,7 +66,7 @@ export const heatmapTransformer: SynchronousDataTransformerInfo<HeatmapTransform
       return [v];
     };
   },
-};
+});
 
 function parseNumeric(v?: string | null) {
   return v === '+Inf' ? Infinity : v === '-Inf' ? -Infinity : +(v ?? 0);
@@ -292,7 +272,14 @@ export function prepBucketFrames(frames: DataFrame[]): DataFrame[] {
   }));
 }
 
-export function calculateHeatmapFromData(frames: DataFrame[], options: HeatmapCalculationOptions): DataFrame {
+interface HeatmapCalculationOptionsWithTimeRange extends HeatmapCalculationOptions {
+  timeRange?: TimeRange;
+}
+
+export function calculateHeatmapFromData(
+  frames: DataFrame[],
+  options: HeatmapCalculationOptionsWithTimeRange
+): DataFrame {
   // Find fields in the heatmap
   const { xField, yField, xs, ys } = findHeatmapFields(frames);
 
@@ -321,7 +308,7 @@ export function calculateHeatmapFromData(frames: DataFrame[], options: HeatmapCa
     xMode: xBucketsCfg.mode,
     xSize:
       xBucketsCfg.mode === HeatmapCalculationMode.Size
-        ? durationToMilliseconds(parseDuration(xBucketsCfg.value ?? ''))
+        ? convertDurationToMilliseconds(xBucketsCfg.value ?? '')
         : xBucketsCfg.value
           ? +xBucketsCfg.value
           : undefined,
@@ -329,6 +316,9 @@ export function calculateHeatmapFromData(frames: DataFrame[], options: HeatmapCa
     ySize: yBucketsCfg.value ? +yBucketsCfg.value : undefined,
     yLog:
       scaleDistribution?.type === ScaleDistribution.Log ? (scaleDistribution?.log as 2 | 10 | undefined) : undefined,
+
+    xMin: options.timeRange?.from.valueOf(),
+    xMax: options.timeRange?.to.valueOf(),
   });
 
   const frame = {
@@ -460,20 +450,23 @@ function heatmap(xs: number[], ys: number[], opts?: HeatmapOpts) {
   let ySorted = opts?.ySorted ?? false;
 
   // find x and y limits to pre-compute buckets struct
-  let minX = xSorted ? xs[0] : Infinity;
+  let minX = opts?.xMin ?? (xSorted ? xs[0] : Infinity);
   let minY = ySorted ? ys[0] : Infinity;
-  let maxX = xSorted ? xs[len - 1] : -Infinity;
+  let maxX = opts?.xMax ?? (xSorted ? xs[len - 1] : -Infinity);
   let maxY = ySorted ? ys[len - 1] : -Infinity;
 
   let yExp = opts?.yLog;
 
+  let withPredefX = opts?.xMin != null && opts?.xMax != null;
+  let withPredefY = opts?.yMin != null && opts?.yMax != null;
+
   for (let i = 0; i < len; i++) {
-    if (!xSorted) {
+    if (!xSorted && !withPredefX) {
       minX = Math.min(minX, xs[i]);
       maxX = Math.max(maxX, xs[i]);
     }
 
-    if (!ySorted) {
+    if (!ySorted && !withPredefY) {
       if (!yExp || ys[i] > 0) {
         minY = Math.min(minY, ys[i]);
         maxY = Math.max(maxY, ys[i]);
@@ -500,7 +493,6 @@ function heatmap(xs: number[], ys: number[], opts?: HeatmapOpts) {
   }
 
   if (xMode === HeatmapCalculationMode.Count) {
-    // TODO: optionally use view range min/max instead of data range for bucket sizing
     let approx = (maxX - minX) / Math.max(xBinIncr - 1, 1);
     // nice-ify
     let xIncrs = opts?.xTime ? niceTimeIncrs : niceLinearIncrs;
@@ -509,7 +501,6 @@ function heatmap(xs: number[], ys: number[], opts?: HeatmapOpts) {
   }
 
   if (yMode === HeatmapCalculationMode.Count) {
-    // TODO: optionally use view range min/max instead of data range for bucket sizing
     let approx = (maxY - minY) / Math.max(yBinIncr - 1, 1);
     // nice-ify
     let yIncrs = opts?.yTime ? niceTimeIncrs : niceLinearIncrs;
