@@ -3,7 +3,8 @@ import { Draggable } from '@hello-pangea/dnd';
 import { FormEvent, useState, KeyboardEvent, useRef, useEffect } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { Icon, Input, IconButton, HorizontalGroup, FieldValidationMessage, useStyles2 } from '@grafana/ui';
+import { t } from '@grafana/i18n';
+import { Icon, Input, IconButton, FieldValidationMessage, useStyles2, Stack } from '@grafana/ui';
 
 type EnumMappingRowProps = {
   transformIndex: number;
@@ -107,19 +108,22 @@ const EnumMappingRow = ({
             // TODO fix accessibility issue here
             // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-noninteractive-element-interactions
             <td onClick={onEnumValueClick} className={styles.clickableTableCell}>
-              {value && value !== '' ? value : 'Click to edit'}
+              {value && value !== '' ? value : t('transformers.enum-mapping-row.click-to-edit', 'Click to edit')}
             </td>
           )}
           <td className={styles.textAlignCenter}>
-            <HorizontalGroup spacing="sm">
+            <Stack gap={1}>
               <IconButton
                 name="trash-alt"
                 onClick={onRemoveButtonClick}
                 data-testid="remove-enum-row"
-                aria-label="Delete enum row"
-                tooltip="Delete"
+                aria-label={t(
+                  'transformers.enum-mapping-row.remove-enum-row-aria-label-delete-enum-row',
+                  'Delete enum row'
+                )}
+                tooltip={t('transformers.enum-mapping-row.remove-enum-row-tooltip-delete', 'Delete')}
               />
-            </HorizontalGroup>
+            </Stack>
           </td>
         </tr>
       )}
