@@ -9,31 +9,37 @@ import {
   StandardEditorsRegistryItem,
   TransformerCategory,
 } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { InlineField, InlineFieldRow, Select, InlineSwitch, Input, Combobox, ComboboxOption } from '@grafana/ui';
-import { FieldNamePicker } from '@grafana/ui/src/components/MatchersUI/FieldNamePicker';
+import { FieldNamePicker } from '@grafana/ui/internal';
 
 import { getTransformationContent } from '../docs/getTransformationContent';
+import darkImage from '../images/dark/extractFields.svg';
+import lightImage from '../images/light/extractFields.svg';
 
 import { JSONPathEditor } from './components/JSONPathEditor';
 import { extractFieldsTransformer } from './extractFields';
 import { fieldExtractors } from './fieldExtractors';
 import { ExtractFieldsOptions, FieldExtractorID, JSONPath } from './types';
 
-const fieldNamePickerSettings: StandardEditorsRegistryItem<string, FieldNamePickerConfigSettings> = {
-  settings: {
-    width: 30,
-    placeholderText: 'Select field',
-  },
-  name: '',
-  id: '',
-  editor: () => null,
-};
-
 export const extractFieldsTransformerEditor = ({
   input,
   options = { delimiter: ',' },
   onChange,
 }: TransformerUIProps<ExtractFieldsOptions>) => {
+  const fieldNamePickerSettings: StandardEditorsRegistryItem<string, FieldNamePickerConfigSettings> = {
+    settings: {
+      width: 30,
+      placeholderText: t(
+        'transformers.extract-fields-transformer-editor.field-name-picker-settings.placeholderText.select-field',
+        'Select field'
+      ),
+    },
+    name: '',
+    id: '',
+    editor: () => null,
+  };
+
   const onPickSourceField = (source?: string) => {
     onChange({
       ...options,
@@ -92,7 +98,7 @@ export const extractFieldsTransformerEditor = ({
   return (
     <div>
       <InlineFieldRow>
-        <InlineField label={'Source'} labelWidth={16}>
+        <InlineField label={t('transformers.extract-fields-transformer-editor.label-source', 'Source')} labelWidth={16}>
           <FieldNamePicker
             context={{ data: input }}
             value={options.source ?? ''}
@@ -102,20 +108,34 @@ export const extractFieldsTransformerEditor = ({
         </InlineField>
       </InlineFieldRow>
       <InlineFieldRow>
-        <InlineField label={'Format'} labelWidth={16}>
+        <InlineField label={t('transformers.extract-fields-transformer-editor.label-format', 'Format')} labelWidth={16}>
           <Select
             value={format.current[0] as any}
             options={format.options as any}
             onChange={onFormatChange}
             width={24}
-            placeholder={'Auto'}
+            placeholder={t('transformers.extract-fields-transformer-editor.placeholder-auto', 'Auto')}
           />
         </InlineField>
       </InlineFieldRow>
       {options.format === FieldExtractorID.RegExp && (
         <InlineFieldRow>
-          <InlineField label="RegExp" labelWidth={16} interactive={true} tooltip="Example: /(?<NewField>.*)/">
-            <Input placeholder="/(?<NewField>.*)/" value={options.regExp} onChange={onRegexpChange} />
+          <InlineField
+            // eslint-disable-next-line @grafana/i18n/no-untranslated-strings
+            label="RegExp"
+            labelWidth={16}
+            interactive={true}
+            tooltip={t('transformers.extract-fields-transformer-editor.tooltip-regexp', 'Example: {{regexExample}}', {
+              regexExample: '/(?<NewField>.*)/',
+              interpolation: { escapeValue: false },
+            })}
+          >
+            <Input
+              // eslint-disable-next-line @grafana/i18n/no-untranslated-strings
+              placeholder="/(?<NewField>.*)/"
+              value={options.regExp}
+              onChange={onRegexpChange}
+            />
           </InlineField>
         </InlineFieldRow>
       )}
@@ -124,25 +144,37 @@ export const extractFieldsTransformerEditor = ({
       )}
       {options.format === FieldExtractorID.Delimiter && (
         <InlineFieldRow>
-          <InlineField label="Delimiter" labelWidth={16}>
+          <InlineField
+            label={t('transformers.extract-fields-transformer-editor.label-delimiter', 'Delimiter')}
+            labelWidth={16}
+          >
             <Combobox
               value={options.delimiter}
               options={[{ value: ',' }, { value: ';' }, { value: '|' }]}
               onChange={onDelimiterChange}
-              placeholder="Select delimiter..."
+              placeholder={t(
+                'transformers.extract-fields-transformer-editor.placeholder-select-delimiter',
+                'Select delimiter...'
+              )}
               width={24}
             />
           </InlineField>
         </InlineFieldRow>
       )}
       <InlineFieldRow>
-        <InlineField label={'Replace all fields'} labelWidth={16}>
+        <InlineField
+          label={t('transformers.extract-fields-transformer-editor.label-replace-all-fields', 'Replace all fields')}
+          labelWidth={16}
+        >
           <InlineSwitch value={options.replace ?? false} onChange={onToggleReplace} />
         </InlineField>
       </InlineFieldRow>
       {options.replace && (
         <InlineFieldRow>
-          <InlineField label={'Keep time'} labelWidth={16}>
+          <InlineField
+            label={t('transformers.extract-fields-transformer-editor.label-keep-time', 'Keep time')}
+            labelWidth={16}
+          >
             <InlineSwitch value={options.keepTime ?? false} onChange={onToggleKeepTime} />
           </InlineField>
         </InlineFieldRow>
@@ -151,12 +183,17 @@ export const extractFieldsTransformerEditor = ({
   );
 };
 
-export const extractFieldsTransformRegistryItem: TransformerRegistryItem<ExtractFieldsOptions> = {
+export const getExtractFieldsTransformRegistryItem: () => TransformerRegistryItem<ExtractFieldsOptions> = () => ({
   id: DataTransformerID.extractFields,
   editor: extractFieldsTransformerEditor,
   transformation: extractFieldsTransformer,
-  name: extractFieldsTransformer.name,
-  description: `Parse fields from content (JSON, labels, etc).`,
+  name: t('transformers.extract-fields-transformer-editor.name.extract-fields', 'Extract fields'),
+  description: t(
+    'transformers.extract-fields-transformer-editor.description.parse-fields-from-content',
+    'Parse fields from content (JSON, labels, etc).'
+  ),
   categories: new Set([TransformerCategory.Reformat]),
   help: getTransformationContent(DataTransformerID.extractFields).helperDocs,
-};
+  imageDark: darkImage,
+  imageLight: lightImage,
+});
