@@ -4,7 +4,7 @@ import { MapDispatchToProps, MapStateToProps } from 'react-redux';
 import { CustomVariableModel, VariableWithMultiSupport } from '@grafana/data';
 import { connectWithStore } from 'app/core/utils/connectWithReduxStore';
 import { CustomVariableForm } from 'app/features/dashboard-scene/settings/variables/components/CustomVariableForm';
-import { StoreState } from 'app/types';
+import { StoreState } from 'app/types/store';
 
 import { OnPropChangeArguments, VariableEditorProps } from '../editor/types';
 import { changeVariableMultiValue } from '../state/actions';
