@@ -1,12 +1,19 @@
 import { createSlice, PayloadAction } from '@reduxjs/toolkit';
 import { isNumber, sortBy, toLower, uniqBy } from 'lodash';
 
-import { MetricFindValue, stringToJsRegex } from '@grafana/data';
+import {
+  MetricFindValue,
+  QueryVariableModel,
+  stringToJsRegex,
+  VariableOption,
+  VariableRefresh,
+  VariableSort,
+} from '@grafana/data';
 
 import { ALL_VARIABLE_TEXT, ALL_VARIABLE_VALUE, NONE_VARIABLE_TEXT, NONE_VARIABLE_VALUE } from '../constants';
 import { getInstanceState } from '../state/selectors';
 import { initialVariablesState, VariablePayload, VariablesState } from '../state/types';
-import { initialVariableModelState, QueryVariableModel, VariableOption, VariableRefresh, VariableSort } from '../types';
+import { initialVariableModelState } from '../types';
 
 interface VariableOptionsUpdate {
   templatedRegex: string;
