@@ -1,4 +1,4 @@
-import { DataSourceVariableModel, QueryVariableModel, VariableRefresh } from 'app/features/variables/types';
+import { DataSourceVariableModel, QueryVariableModel, VariableRefresh } from '@grafana/data';
 
 import { MultiVariableBuilder } from './multiVariableBuilder';
 
