@@ -1,5 +1,4 @@
-import { Namespace } from 'i18next';
-import { find, startsWith } from 'lodash';
+import { find } from 'lodash';
 
 import { AzureCredentials } from '@grafana/azure-sdk';
 import { ScopedVars } from '@grafana/data';
@@ -7,27 +6,27 @@ import { DataSourceWithBackend, getTemplateSrv, TemplateSrv } from '@grafana/run
 
 import { getCredentials } from '../credentials';
 import TimegrainConverter from '../time_grain_converter';
+import { AzureMetricQuery, AzureMonitorQuery, AzureQueryType } from '../types/query';
 import {
+  AzureAPIResponse,
   AzureMonitorDataSourceInstanceSettings,
   AzureMonitorDataSourceJsonData,
+  AzureMonitorLocations,
   AzureMonitorMetricsMetadataResponse,
-  AzureMonitorQuery,
-  AzureQueryType,
+  AzureMonitorProvidersResponse,
   DatasourceValidationResult,
+  GetLogAnalyticsTableResponse,
+  GetMetricMetadataQuery,
   GetMetricNamespacesQuery,
   GetMetricNamesQuery,
-  GetMetricMetadataQuery,
-  AzureMetricQuery,
-  AzureMonitorLocations,
-  AzureMonitorProvidersResponse,
-  AzureAPIResponse,
-  AzureGetResourceNamesQuery,
-  Subscription,
+  instanceOfLogAnalyticsTableError,
   Location,
-  ResourceGroup,
   Metric,
-} from '../types';
-import { routeNames } from '../utils/common';
+  MetricNamespace,
+  Subscription,
+  TablePlan,
+} from '../types/types';
+import { replaceTemplateVariables, routeNames } from '../utils/common';
 import migrateQuery from '../utils/migrateQuery';
 
 import ResponseParser from './response_parser';
@@ -123,7 +122,9 @@ export default class AzureMonitorDatasource extends DataSourceWithBackend<
       migratedTarget.subscription || this.defaultSubscriptionId,
       scopedVars
     );
-    const resources = migratedQuery.resources?.map((r) => this.replaceTemplateVariables(r, scopedVars)).flat();
+    const resources = migratedQuery.resources
+      ?.map((r) => replaceTemplateVariables(this.templateSrv, r, scopedVars))
+      .flat();
     const metricNamespace = this.templateSrv.replace(migratedQuery.metricNamespace, scopedVars);
     const customNamespace = this.templateSrv.replace(migratedQuery.customNamespace, scopedVars);
     const timeGrain = this.templateSrv.replace((migratedQuery.timeGrain || '').toString(), scopedVars);
@@ -176,69 +177,8 @@ export default class AzureMonitorDatasource extends DataSourceWithBackend<
     });
   }
 
-  getResourceGroups(subscriptionId: string) {
-    return this.getResource(
-      `${this.resourcePath}/subscriptions/${subscriptionId}/resourceGroups?api-version=${this.listByResourceGroupApiVersion}`
-    ).then((result: AzureAPIResponse<ResourceGroup>) => {
-      return ResponseParser.parseResponseValues<ResourceGroup>(result, 'name', 'name');
-    });
-  }
-
-  async getResourceNames(query: AzureGetResourceNamesQuery, skipToken?: string) {
-    const promises = this.replaceTemplateVariables(query).map(
-      ({ metricNamespace, subscriptionId, resourceGroup, region }) => {
-        const validMetricNamespace = startsWith(metricNamespace?.toLowerCase(), 'microsoft.storage/storageaccounts/')
-          ? 'microsoft.storage/storageaccounts'
-          : metricNamespace;
-        let url = `${this.resourcePath}/subscriptions/${subscriptionId}`;
-        if (resourceGroup) {
-          url += `/resourceGroups/${resourceGroup}`;
-        }
-        url += `/resources?api-version=${this.listByResourceGroupApiVersion}`;
-        const filters: string[] = [];
-        if (validMetricNamespace) {
-          filters.push(`resourceType eq '${validMetricNamespace}'`);
-        }
-        if (region) {
-          filters.push(`location eq '${region}'`);
-        }
-        if (filters.length > 0) {
-          url += `&$filter=${filters.join(' and ')}`;
-        }
-        if (skipToken) {
-          url += `&$skiptoken=${skipToken}`;
-        }
-        return this.getResource(url).then(async (result) => {
-          let list: Array<{ text: string; value: string }> = [];
-          if (startsWith(metricNamespace?.toLowerCase(), 'microsoft.storage/storageaccounts/')) {
-            list = ResponseParser.parseResourceNames(result, 'microsoft.storage/storageaccounts');
-            for (let i = 0; i < list.length; i++) {
-              list[i].text += '/default';
-              list[i].value += '/default';
-            }
-          } else {
-            list = ResponseParser.parseResourceNames(result, metricNamespace);
-          }
-
-          if (result.nextLink) {
-            // If there is a nextLink, we should request more pages
-            const nextURL = new URL(result.nextLink);
-            const nextToken = nextURL.searchParams.get('$skiptoken');
-            if (!nextToken) {
-              throw Error('unable to request the next page of resources');
-            }
-            const nextPage = await this.getResourceNames({ metricNamespace, subscriptionId, resourceGroup }, nextToken);
-            list = list.concat(nextPage);
-          }
-
-          return list;
-        });
-      }
-    );
-    return (await Promise.all(promises)).flat();
-  }
-
-  getMetricNamespaces(query: GetMetricNamespacesQuery, globalRegion: boolean, region?: string) {
+  // Note globalRegion should be false when querying custom metric namespaces
+  getMetricNamespaces(query: GetMetricNamespacesQuery, globalRegion: boolean, region?: string, custom?: boolean) {
     const url = UrlBuilder.buildAzureMonitorGetMetricNamespacesUrl(
       this.resourcePath,
       this.apiPreviewVersion,
@@ -249,7 +189,10 @@ export default class AzureMonitorDatasource extends DataSourceWithBackend<
       region
     );
     return this.getResource(url)
-      .then((result: AzureAPIResponse<Namespace>) => {
+      .then((result: AzureAPIResponse<MetricNamespace>) => {
+        if (custom) {
+          result.value = result.value.filter((namespace) => namespace.classification === 'Custom');
+        }
         return ResponseParser.parseResponseValues(
           result,
           'properties.metricNamespaceName',
@@ -332,6 +275,36 @@ export default class AzureMonitorDatasource extends DataSourceWithBackend<
     return undefined;
   }
 
+  async getWorkspaceTablePlan(resources: string[], tableName: string): Promise<TablePlan> {
+    let workspaceUri = '';
+
+    if (resources) {
+      workspaceUri = resources[0];
+    }
+
+    if (!workspaceUri) {
+      return TablePlan.Analytics;
+    }
+
+    if (workspaceUri && !workspaceUri.toLowerCase().includes('microsoft.operationalinsights/workspaces')) {
+      // Not a Log Analytics workspace so default to Analytics
+      return TablePlan.Analytics;
+    }
+
+    const url = UrlBuilder.buildAzureMonitorGetLogsTableUrl(
+      this.resourcePath,
+      this.templateSrv.replace(workspaceUri),
+      this.templateSrv.replace(tableName)
+    );
+    const tableResult = await this.getResource<GetLogAnalyticsTableResponse>(url);
+
+    if (!tableResult || instanceOfLogAnalyticsTableError(tableResult)) {
+      return TablePlan.Analytics;
+    }
+
+    return tableResult.properties.plan || TablePlan.Analytics;
+  }
+
   private isValidConfigField(field?: string): boolean {
     return typeof field === 'string' && field.length > 0;
   }
@@ -344,34 +317,7 @@ export default class AzureMonitorDatasource extends DataSourceWithBackend<
     // { resourceGroup: 'rg1', resourceName: 'res1' } which is valid but
     // { resourceGroup: ['rg1', 'rg2'], resourceName: ['res2'] } would result in
     // { resourceGroup: 'rg1', resourceName: 'res2' } which is not.
-    return this.replaceTemplateVariables(query, scopedVars)[0];
-  }
-
-  private replaceTemplateVariables<T extends { [K in keyof T]: string }>(query: T, scopedVars?: ScopedVars) {
-    const workingQueries: Array<{ [K in keyof T]: string }> = [{ ...query }];
-    const keys = Object.keys(query) as Array<keyof T>;
-    keys.forEach((key) => {
-      const replaced = this.templateSrv.replace(workingQueries[0][key], scopedVars, 'raw');
-      if (replaced.includes(',')) {
-        const multiple = replaced.split(',');
-        const currentQueries = [...workingQueries];
-        multiple.forEach((value, i) => {
-          currentQueries.forEach((q) => {
-            if (i === 0) {
-              q[key] = value;
-            } else {
-              workingQueries.push({ ...q, [key]: value });
-            }
-          });
-        });
-      } else {
-        workingQueries.forEach((q) => {
-          q[key] = replaced;
-        });
-      }
-    });
-
-    return workingQueries;
+    return replaceTemplateVariables(this.templateSrv, query, scopedVars)[0];
   }
 
   async getProvider(providerName: string) {
