@@ -1,8 +1,8 @@
 import { render, screen } from '@testing-library/react';
 
-import createMockDatasource from '../../__mocks__/datasource';
-import createMockQuery from '../../__mocks__/query';
-import { AzureMonitorOption } from '../../types';
+import createMockDatasource from '../../mocks/datasource';
+import createMockQuery from '../../mocks/query';
+import { AzureMonitorOption } from '../../types/types';
 
 import MetricNameField from './MetricNameField';
 
