@@ -1,6 +1,7 @@
 import { debounce } from 'lodash';
-import React, { useEffect, useMemo, useState } from 'react';
+import { useEffect, useMemo, useState } from 'react';
 
+import { t } from '@grafana/i18n';
 import { Icon, Input } from '@grafana/ui';
 
 import { selectors } from '../../e2e/selectors';
@@ -18,7 +19,7 @@ const Search = ({ searchFn }: { searchFn: (searchPhrase: string) => void }) => {
 
   return (
     <Input
-      aria-label="resource search"
+      aria-label={t('components.search.aria-label-resource-search', 'Resource search')}
       prefix={<Icon name="search" />}
       value={searchFilter}
       onChange={(event) => {
@@ -26,8 +27,9 @@ const Search = ({ searchFn }: { searchFn: (searchPhrase: string) => void }) => {
         setSearchFilter(searchPhrase);
         debouncedSearch(searchPhrase);
       }}
-      placeholder="search for a resource"
+      placeholder={t('components.search.placeholder-resource-search', 'Search for a resource')}
       data-testid={selectors.components.queryEditor.resourcePicker.search.input}
+      style={{ marginBottom: '10px' }}
     />
   );
 };
