@@ -1,7 +1,5 @@
-import React from 'react';
-
 import { SelectableValue } from '@grafana/data';
-import { EditorField } from '@grafana/experimental';
+import { EditorField } from '@grafana/plugin-ui';
 import { Select } from '@grafana/ui';
 
 import { LOOKBACK_PERIODS } from '../constants';
