@@ -1,6 +1,6 @@
 import { SelectableValue } from '@grafana/data';
-import { EditorField } from '@grafana/experimental';
-import { Alert, Select } from '@grafana/ui';
+import { EditorField } from '@grafana/plugin-ui';
+import { Alert, PopoverContent, Select } from '@grafana/ui';
 
 import { VariableQueryType } from '../../types';
 import { removeMarginBottom } from '../styles';
@@ -13,6 +13,8 @@ interface VariableQueryFieldProps<T> {
   inputId?: string;
   allowCustomValue?: boolean;
   isLoading?: boolean;
+  tooltip?: PopoverContent;
+  interactive?: boolean;
   error?: string;
 }
 
@@ -24,11 +26,19 @@ export const VariableQueryField = <T extends string | VariableQueryType>({
   allowCustomValue = false,
   isLoading = false,
   inputId = label,
+  tooltip,
+  interactive,
   error,
 }: VariableQueryFieldProps<T>) => {
   return (
     <>
-      <EditorField label={label} htmlFor={inputId} className={removeMarginBottom}>
+      <EditorField
+        label={label}
+        tooltip={tooltip}
+        tooltipInteractive={interactive}
+        htmlFor={inputId}
+        className={removeMarginBottom}
+      >
         <Select
           aria-label={label}
           allowCustomValue={allowCustomValue}
