@@ -32,7 +32,8 @@ import {
   Stack,
 } from '@grafana/ui';
 import { hasAlphaPanels } from 'app/core/config';
-import * as DFImport from 'app/features/dataframe-import';
+import { acceptedFiles, maxFileSize } from 'app/features/dataframe-import/constants';
+import { filesToDataframes } from 'app/features/dataframe-import/utils';
 import { getManagedChannelInfo } from 'app/features/live/info';
 import { SearchQuery } from 'app/features/search/service/types';
 
@@ -82,7 +83,7 @@ export class UnthemedQueryEditor extends PureComponent<Props, State> {
         description: 'Search for grafana resources',
       });
     }
-    if (config.featureToggles.unifiedStorageSearch) {
+    if (config.featureToggles.unifiedStorageSearchUI) {
       this.queryTypes.push({
         label: 'Search (experimental)',
         value: GrafanaQueryType.SearchNext,
@@ -107,7 +108,7 @@ export class UnthemedQueryEditor extends PureComponent<Props, State> {
   loadFolderInfo() {
     const query: DataQueryRequest<GrafanaQuery> = {
       targets: [{ queryType: GrafanaQueryType.List, refId: 'A' }],
-    } as any;
+    } as DataQueryRequest<GrafanaQuery>;
 
     getDataSourceSrv()
       .get('-- Grafana --')
@@ -360,7 +361,7 @@ export class UnthemedQueryEditor extends PureComponent<Props, State> {
   };
 
   onFileDrop = (acceptedFiles: File[], fileRejections: FileRejection[], event: DropEvent) => {
-    DFImport.filesToDataframes(acceptedFiles).subscribe((next) => {
+    filesToDataframes(acceptedFiles).subscribe((next) => {
       const snapshot: DataFrameJSON[] = [];
       next.dataFrames.forEach((df) => {
         const dataframeJson = dataFrameToJSON(df);
@@ -406,9 +407,9 @@ export class UnthemedQueryEditor extends PureComponent<Props, State> {
               fileListRenderer={this.fileListRenderer}
               options={{
                 onDrop: this.onFileDrop,
-                maxSize: DFImport.maxFileSize,
+                maxSize: maxFileSize,
                 multiple: false,
-                accept: DFImport.acceptedFiles,
+                accept: acceptedFiles,
               }}
             >
               <FileDropzoneDefaultChildren
