@@ -1,8 +1,7 @@
 import { render, waitFor } from '@testing-library/react';
-import React from 'react';
 
 import InfluxDatasource from '../../../../../datasource';
-import { getMockInfluxDS, getMockDSInstanceSettings } from '../../../../../mocks';
+import { getMockInfluxDS, getMockDSInstanceSettings } from '../../../../../mocks/datasource';
 import { DEFAULT_POLICY, InfluxQuery } from '../../../../../types';
 
 import { VisualInfluxQLEditor } from './VisualInfluxQLEditor';
