@@ -6,11 +6,11 @@ import config from 'app/core/config';
 
 import { queryBuilder } from '../../../features/variables/shared/testing/builders';
 
-import { getMockDSInstanceSettings, getMockInfluxDS, mockBackendService, replaceMock } from './__mocks__/datasource';
-import { mockInfluxQueryRequest } from './__mocks__/request';
-import { mockInfluxFetchResponse, mockMetricFindQueryResponse } from './__mocks__/response';
 import { BROWSER_MODE_DISABLED_MESSAGE } from './constants';
 import InfluxDatasource from './datasource';
+import { getMockDSInstanceSettings, getMockInfluxDS, mockBackendService, replaceMock } from './mocks/datasource';
+import { mockInfluxQueryRequest } from './mocks/request';
+import { mockInfluxFetchResponse, mockMetricFindQueryResponse } from './mocks/response';
 import { InfluxQuery, InfluxVersion } from './types';
 
 const fetchMock = mockBackendService(mockInfluxFetchResponse());
@@ -284,7 +284,11 @@ describe('interpolateQueryExpr', () => {
   it('should return the escaped value if the value wrapped in regex', () => {
     const value = '/special/path';
     const variableMock = queryBuilder().withId('tempVar').withName('tempVar').withMulti(false).build();
-    const result = ds.interpolateQueryExpr(value, variableMock, 'select that where path = /$tempVar/');
+    const result = ds.interpolateQueryExpr(
+      value,
+      variableMock,
+      'select atan(z/sqrt(3.14)), that where path =~ /$tempVar/'
+    );
     const expectation = `\\/special\\/path`;
     expect(result).toBe(expectation);
   });
@@ -292,7 +296,11 @@ describe('interpolateQueryExpr', () => {
   it('should return the escaped value if the value wrapped in regex 2', () => {
     const value = '/special/path';
     const variableMock = queryBuilder().withId('tempVar').withName('tempVar').withMulti(false).build();
-    const result = ds.interpolateQueryExpr(value, variableMock, 'select that where path = /^$tempVar$/');
+    const result = ds.interpolateQueryExpr(
+      value,
+      variableMock,
+      'select atan(z/sqrt(3.14)), that where path !~ /^$tempVar$/'
+    );
     const expectation = `\\/special\\/path`;
     expect(result).toBe(expectation);
   });
@@ -305,7 +313,11 @@ describe('interpolateQueryExpr', () => {
       .withMulti(false)
       .withIncludeAll(true)
       .build();
-    const result = ds.interpolateQueryExpr(value, variableMock, 'select from /^($tempVar)$/');
+    const result = ds.interpolateQueryExpr(
+      value,
+      variableMock,
+      'select atan(z/sqrt(3.14)), thing from path =~ /^($tempVar)$/'
+    );
     const expectation = `(env|env2|env3)`;
     expect(result).toBe(expectation);
   });
@@ -358,11 +370,23 @@ describe('interpolateQueryExpr', () => {
       )
       .build();
     const value = [`/special/path`, `/some/other/path`];
-    const result = ds.interpolateQueryExpr(value, variableMock, `select that where path = /$tempVar/`);
+    const result = ds.interpolateQueryExpr(value, variableMock, `select that where path =~ /$tempVar/`);
     const expectation = `(\\/special\\/path|\\/some\\/other\\/path)`;
     expect(result).toBe(expectation);
   });
 
+  it('should **not** return the escaped value if the value **is not** wrapped in regex and the query is more complex (e.g. text is contained between two / but not a regex', () => {
+    const value = 'testmatch';
+    const variableMock = queryBuilder().withId('tempVar').withName('tempVar').withMulti(false).build();
+    const result = ds.interpolateQueryExpr(
+      value,
+      variableMock,
+      `select value where ("tag"::tag =~ /value/) AND where other = $tempVar $timeFilter GROUP BY time($__interval) tz('Europe/London')`
+    );
+    const expectation = `testmatch`;
+    expect(result).toBe(expectation);
+  });
+
   it('should return floating point number as it is', () => {
     const variableMock = queryBuilder()
       .withId('tempVar')
@@ -392,5 +416,160 @@ describe('interpolateQueryExpr', () => {
     const adhocFilter: AdHocVariableFilter[] = [{ key: 'bar', value: templateVarName, operator: '=' }];
     const result = ds.applyTemplateVariables(mockInfluxQueryRequest() as unknown as InfluxQuery, {}, adhocFilter);
     expect(result.tags![0].value).toBe(templateVarValue);
+    expect(result.adhocFilters![0].value).toBe(templateVarValue);
+  });
+});
+
+describe('interpolateVariablesInQueries', () => {
+  const templateSrvStub = {
+    replace: jest.fn().mockImplementation((target: string) => {
+      if (target === '$database') {
+        return 'test_db';
+      }
+      if (target === '$measurement') {
+        return 'cpu_usage';
+      }
+      if (target === 'SELECT * FROM $measurement WHERE database = "$database"') {
+        return 'SELECT * FROM cpu_usage WHERE database = "test_db"';
+      }
+      if (target === 'SELECT * FROM $measurement') {
+        return 'SELECT * FROM cpu_usage';
+      }
+      if (target === '$server') {
+        return 'prod-server';
+      }
+      return target;
+    }),
+  } as unknown as TemplateSrv;
+  let dsInfluxQL = getMockInfluxDS(getMockDSInstanceSettings(), templateSrvStub);
+  let dsFlux = getMockInfluxDS(getMockDSInstanceSettings({ version: InfluxVersion.Flux }), templateSrvStub);
+  let dsSQL = getMockInfluxDS(getMockDSInstanceSettings({ version: InfluxVersion.SQL }), templateSrvStub);
+
+  beforeEach(() => {
+    jest.clearAllMocks();
+  });
+
+  it('should return an empty array if there are no queries', () => {
+    const result = dsInfluxQL.interpolateVariablesInQueries([], {}, []);
+    expect(result).toEqual([]);
+  });
+
+  it('should interpolate template variables in query rawQuery (Flux)', () => {
+    const queries: InfluxQuery[] = [
+      {
+        refId: 'A',
+        rawQuery: true,
+        query: 'SELECT * FROM $measurement WHERE database = "$database"',
+      } as InfluxQuery,
+    ];
+
+    const result = dsFlux.interpolateVariablesInQueries(queries, {}, []);
+
+    expect(result).toHaveLength(1);
+    expect(result[0].query).toBe('SELECT * FROM cpu_usage WHERE database = "test_db"');
+  });
+
+  it('should apply adhoc filters to queries (InfluxQL)', () => {
+    const queries: InfluxQuery[] = [
+      {
+        refId: 'A',
+        rawQuery: false,
+        measurement: 'cpu',
+        tags: [],
+      } as InfluxQuery,
+    ];
+
+    const adhocFilters: AdHocVariableFilter[] = [
+      { key: 'host', value: 'server1', operator: '=' },
+      { key: 'region', value: 'us-east', operator: '=' },
+    ];
+
+    const result = dsInfluxQL.interpolateVariablesInQueries(queries, {}, adhocFilters);
+
+    expect(result).toHaveLength(1);
+    expect(result[0].adhocFilters).toEqual(adhocFilters);
+  });
+
+  it('should apply adhoc filters to queries (SQL)', () => {
+    const queries: InfluxQuery[] = [
+      {
+        refId: 'A',
+        rawQuery: false,
+        measurement: 'cpu',
+        tags: [],
+      } as InfluxQuery,
+    ];
+
+    const adhocFilters: AdHocVariableFilter[] = [
+      { key: 'host', value: 'server1', operator: '=' },
+      { key: 'region', value: 'us-east', operator: '=' },
+    ];
+
+    const result = dsSQL.interpolateVariablesInQueries(queries, {}, adhocFilters);
+
+    expect(result).toHaveLength(1);
+    expect(result[0].adhocFilters).toEqual(adhocFilters);
+  });
+
+  it('should interpolate template variables in adhoc filter values (InfluxQL)', () => {
+    const templateSrvWithAdhoc = {
+      replace: jest.fn().mockImplementation((target: string) => {
+        if (target === '$server') {
+          return 'prod-server';
+        }
+        return target;
+      }),
+    } as unknown as TemplateSrv;
+
+    const ds = getMockInfluxDS(getMockDSInstanceSettings({ version: InfluxVersion.InfluxQL }), templateSrvWithAdhoc);
+    const queries: InfluxQuery[] = [
+      {
+        refId: 'A',
+        rawQuery: false,
+        measurement: 'cpu',
+        tags: [],
+      } as InfluxQuery,
+    ];
+
+    const adhocFilters: AdHocVariableFilter[] = [{ key: 'host', value: '$server', operator: '=' }];
+
+    const result = ds.interpolateVariablesInQueries(queries, {}, adhocFilters);
+
+    expect(result[0].adhocFilters![0].value).toBe('prod-server');
+  });
+
+  it('should preserve existing tags when applying adhoc filters', () => {
+    const queries: InfluxQuery[] = [
+      {
+        refId: 'A',
+        rawQuery: false,
+        measurement: 'cpu',
+        tags: [{ key: 'datacenter', value: 'dc1', operator: '=' }],
+      } as InfluxQuery,
+    ];
+
+    const adhocFilters: AdHocVariableFilter[] = [{ key: 'host', value: 'server1', operator: '=' }];
+
+    const result = dsInfluxQL.interpolateVariablesInQueries(queries, {}, adhocFilters);
+
+    expect(result[0].tags?.length).toEqual(2);
+    expect(result[0].tags![0]).toEqual({ key: 'datacenter', value: 'dc1', operator: '=' });
+    expect(result[0].tags![1]).toEqual({ key: 'host', value: 'server1', operator: '=' });
+    expect(result[0].adhocFilters).toEqual(adhocFilters);
+  });
+
+  it('should handle empty adhoc filters array', () => {
+    const queries: InfluxQuery[] = [
+      {
+        refId: 'A',
+        rawQuery: true,
+        query: 'SELECT * FROM cpu',
+      } as InfluxQuery,
+    ];
+
+    const result = dsInfluxQL.interpolateVariablesInQueries(queries, {}, []);
+
+    expect(result).toHaveLength(1);
+    expect(result[0].adhocFilters).toEqual([]);
   });
 });
