@@ -8,6 +8,7 @@ import {
   createDataFrame,
   dateTime,
 } from '@grafana/data';
+import { setTemplateSrv, TemplateSrv } from '@grafana/runtime';
 
 import LokiLanguageProvider from './LanguageProvider';
 import {
@@ -15,20 +16,37 @@ import {
   LOKI_LOG_CONTEXT_PRESERVED_LABELS,
   SHOULD_INCLUDE_PIPELINE_OPERATIONS,
 } from './LogContextProvider';
-import { createLokiDatasource } from './__mocks__/datasource';
+import { createLokiDatasource } from './mocks/datasource';
 import { LokiQuery } from './types';
 
 const defaultLanguageProviderMock = {
   start: jest.fn(),
-  fetchSeriesLabels: jest.fn(() => ({ bar: ['baz'], xyz: ['abc'] })),
+  fetchLabels: jest.fn(() => ['bar', 'xyz']),
   getLabelKeys: jest.fn(() => ['bar', 'xyz']),
 } as unknown as LokiLanguageProvider;
 
-const defaultDatasourceMock = createLokiDatasource();
-defaultDatasourceMock.query = jest.fn(() => of({ data: [] } as DataQueryResponse));
-defaultDatasourceMock.languageProvider = defaultLanguageProviderMock;
-
 const defaultLogRow = {
+  rowIndex: 0,
+  dataFrame: createDataFrame({
+    fields: [
+      {
+        name: 'ts',
+        type: FieldType.time,
+        values: [0],
+      },
+      {
+        name: 'labelTypes',
+        type: FieldType.other,
+        values: [{ bar: 'I', foo: 'S', xyz: 'I' }],
+      },
+    ],
+  }),
+  labels: { bar: 'baz', foo: 'uniqueParsedLabel', xyz: 'abc' },
+  uid: '1',
+  timeEpochMs: new Date().getTime(),
+} as unknown as LogRowModel;
+
+const frameWithoutTypes = {
   rowIndex: 0,
   dataFrame: createDataFrame({
     fields: [
@@ -47,6 +65,13 @@ const defaultLogRow = {
 describe('LogContextProvider', () => {
   let logContextProvider: LogContextProvider;
   beforeEach(() => {
+    const templateSrv = {
+      replace: jest.fn((str: string) => str?.replace('$test', 'baz')),
+    };
+    setTemplateSrv(templateSrv as unknown as TemplateSrv);
+    const defaultDatasourceMock = createLokiDatasource(templateSrv);
+    defaultDatasourceMock.query = jest.fn(() => of({ data: [] } as DataQueryResponse));
+    defaultDatasourceMock.languageProvider = defaultLanguageProviderMock;
     logContextProvider = new LogContextProvider(defaultDatasourceMock);
   });
 
@@ -75,7 +100,7 @@ describe('LogContextProvider', () => {
       );
       expect(logContextProvider.getInitContextFilters).toBeCalled();
       expect(logContextProvider.getInitContextFilters).toHaveBeenCalledWith(
-        { bar: 'baz', foo: 'uniqueParsedLabel', xyz: 'abc' },
+        expect.objectContaining({ labels: { bar: 'baz', foo: 'uniqueParsedLabel', xyz: 'abc' } }),
         { expr: '{bar="baz"}', refId: 'A' },
         {
           from: dateTime(defaultLogRow.timeEpochMs),
@@ -86,6 +111,32 @@ describe('LogContextProvider', () => {
       expect(logContextProvider.cachedContextFilters).toHaveLength(1);
     });
 
+    it('should replace variables before getInitContextFilters', async () => {
+      logContextProvider.getInitContextFilters = jest.fn().mockResolvedValue({
+        contextFilters: [{ value: 'baz', enabled: true, nonIndexed: false, label: 'bar' }],
+        preservedFiltersApplied: false,
+      });
+
+      expect(logContextProvider.cachedContextFilters).toHaveLength(0);
+      await logContextProvider.getLogRowContext(
+        defaultLogRow,
+        {
+          limit: 10,
+          direction: LogRowContextQueryDirection.Backward,
+          scopedVars: { test: { value: 'baz', text: 'baz' } },
+        },
+        {
+          expr: '{bar="$test"}',
+          refId: 'A',
+        }
+      );
+      expect(logContextProvider.getInitContextFilters).toHaveBeenCalledWith(
+        expect.anything(),
+        expect.objectContaining({ expr: '{bar="baz"}', refId: 'A' }),
+        expect.anything()
+      );
+    });
+
     it('should not call getInitContextFilters if cachedContextFilters', async () => {
       logContextProvider.getInitContextFilters = jest
         .fn()
@@ -119,6 +170,26 @@ describe('LogContextProvider', () => {
       expect(logContextProvider.getInitContextFilters).toHaveBeenCalled();
     });
 
+    it('should replace variables before getInitContextFilters', async () => {
+      logContextProvider.getInitContextFilters = jest.fn().mockResolvedValue({
+        contextFilters: [{ value: 'baz', enabled: true, nonIndexed: false, label: 'bar' }],
+        preservedFiltersApplied: false,
+      });
+
+      const query = await logContextProvider.getLogRowContextQuery(
+        defaultLogRow,
+        {
+          limit: 10,
+          direction: LogRowContextQueryDirection.Backward,
+        },
+        {
+          expr: '{bar="$test"}',
+          refId: 'A',
+        }
+      );
+      expect(query.expr).toBe('{bar="baz"}');
+    });
+
     it('should also call getInitContextFilters if cacheFilters is not set', async () => {
       logContextProvider.getInitContextFilters = jest.fn().mockResolvedValue({
         contextFilters: [{ value: 'baz', enabled: true, nonIndexed: false, label: 'bar' }],
@@ -399,7 +470,7 @@ describe('LogContextProvider', () => {
       };
 
       it('should correctly create contextFilters', async () => {
-        const result = await logContextProvider.getInitContextFilters(defaultLogRow.labels, queryWithoutParser);
+        const result = await logContextProvider.getInitContextFilters(defaultLogRow, queryWithoutParser);
         expect(result.contextFilters).toEqual([
           { enabled: true, nonIndexed: false, label: 'bar', value: 'baz' },
           { enabled: false, nonIndexed: true, label: 'foo', value: 'uniqueParsedLabel' },
@@ -409,28 +480,29 @@ describe('LogContextProvider', () => {
       });
 
       it('should return empty contextFilters if no query', async () => {
-        const filters = (await logContextProvider.getInitContextFilters(defaultLogRow.labels, undefined))
-          .contextFilters;
+        const filters = (await logContextProvider.getInitContextFilters(defaultLogRow, undefined)).contextFilters;
         expect(filters).toEqual([]);
       });
 
       it('should return empty contextFilters if no labels', async () => {
-        const filters = (await logContextProvider.getInitContextFilters({}, queryWithoutParser)).contextFilters;
+        const filters = (
+          await logContextProvider.getInitContextFilters({ labels: [] } as unknown as LogRowModel, queryWithoutParser)
+        ).contextFilters;
         expect(filters).toEqual([]);
       });
 
-      it('should call fetchSeriesLabels if parser', async () => {
-        await logContextProvider.getInitContextFilters(defaultLogRow.labels, queryWithParser);
-        expect(defaultLanguageProviderMock.fetchSeriesLabels).toBeCalled();
+      it('should call fetchLabels with stream selector if parser', async () => {
+        await logContextProvider.getInitContextFilters(defaultLogRow, queryWithParser);
+        expect(defaultLanguageProviderMock.fetchLabels).toBeCalledWith({ streamSelector: `{bar="baz"}` });
       });
 
-      it('should call fetchSeriesLabels with given time range', async () => {
-        await logContextProvider.getInitContextFilters(defaultLogRow.labels, queryWithParser, timeRange);
-        expect(defaultLanguageProviderMock.fetchSeriesLabels).toBeCalledWith(`{bar="baz"}`, { timeRange });
+      it('should call fetchLabels with given time range', async () => {
+        await logContextProvider.getInitContextFilters(defaultLogRow, queryWithParser, timeRange);
+        expect(defaultLanguageProviderMock.fetchLabels).toBeCalledWith({ streamSelector: `{bar="baz"}`, timeRange });
       });
 
       it('should call `languageProvider.start` if no parser with given time range', async () => {
-        await logContextProvider.getInitContextFilters(defaultLogRow.labels, queryWithoutParser, timeRange);
+        await logContextProvider.getInitContextFilters(defaultLogRow, queryWithoutParser, timeRange);
         expect(defaultLanguageProviderMock.start).toBeCalledWith(timeRange);
       });
     });
@@ -442,7 +514,7 @@ describe('LogContextProvider', () => {
       };
 
       it('should correctly create contextFilters', async () => {
-        const result = await logContextProvider.getInitContextFilters(defaultLogRow.labels, queryWithParser);
+        const result = await logContextProvider.getInitContextFilters(defaultLogRow, queryWithParser);
         expect(result.contextFilters).toEqual([
           { enabled: true, nonIndexed: false, label: 'bar', value: 'baz' },
           { enabled: false, nonIndexed: true, label: 'foo', value: 'uniqueParsedLabel' },
@@ -452,13 +524,14 @@ describe('LogContextProvider', () => {
       });
 
       it('should return empty contextFilters if no query', async () => {
-        const filters = (await logContextProvider.getInitContextFilters(defaultLogRow.labels, undefined))
-          .contextFilters;
+        const filters = (await logContextProvider.getInitContextFilters(defaultLogRow, undefined)).contextFilters;
         expect(filters).toEqual([]);
       });
 
       it('should return empty contextFilters if no labels', async () => {
-        const filters = (await logContextProvider.getInitContextFilters({}, queryWithParser)).contextFilters;
+        const filters = (
+          await logContextProvider.getInitContextFilters({ labels: [] } as unknown as LogRowModel, queryWithParser)
+        ).contextFilters;
         expect(filters).toEqual([]);
       });
     });
@@ -477,7 +550,7 @@ describe('LogContextProvider', () => {
             selectedExtractedLabels: ['foo'],
           })
         );
-        const result = await logContextProvider.getInitContextFilters(defaultLogRow.labels, queryWithParser);
+        const result = await logContextProvider.getInitContextFilters(defaultLogRow, queryWithParser);
         expect(result.contextFilters).toEqual([
           { enabled: false, nonIndexed: false, label: 'bar', value: 'baz' }, // disabled real label
           { enabled: true, nonIndexed: true, label: 'foo', value: 'uniqueParsedLabel' }, // enabled parsed label
@@ -486,6 +559,23 @@ describe('LogContextProvider', () => {
         expect(result.preservedFiltersApplied).toBe(true);
       });
 
+      it('should correctly apply preserved labels with no types', async () => {
+        window.localStorage.setItem(
+          LOKI_LOG_CONTEXT_PRESERVED_LABELS,
+          JSON.stringify({
+            removedLabels: ['bar'],
+            selectedExtractedLabels: ['foo'],
+          })
+        );
+        const result = await logContextProvider.getInitContextFilters(frameWithoutTypes, queryWithParser);
+        expect(result.contextFilters).toEqual([
+          { enabled: false, nonIndexed: false, label: 'bar', value: 'baz' }, // disabled real label
+          { enabled: true, nonIndexed: false, label: 'foo', value: 'uniqueParsedLabel' }, // enabled parsed label
+          { enabled: true, nonIndexed: false, label: 'xyz', value: 'abc' },
+        ]);
+        expect(result.preservedFiltersApplied).toBe(true);
+      });
+
       it('should use contextFilters from row labels if all real labels are disabled', async () => {
         window.localStorage.setItem(
           LOKI_LOG_CONTEXT_PRESERVED_LABELS,
@@ -494,7 +584,7 @@ describe('LogContextProvider', () => {
             selectedExtractedLabels: ['foo'],
           })
         );
-        const result = await logContextProvider.getInitContextFilters(defaultLogRow.labels, queryWithParser);
+        const result = await logContextProvider.getInitContextFilters(defaultLogRow, queryWithParser);
         expect(result.contextFilters).toEqual([
           { enabled: true, nonIndexed: false, label: 'bar', value: 'baz' }, // enabled real label
           { enabled: false, nonIndexed: true, label: 'foo', value: 'uniqueParsedLabel' },
@@ -503,6 +593,23 @@ describe('LogContextProvider', () => {
         expect(result.preservedFiltersApplied).toBe(false);
       });
 
+      it('should use contextFilters from row labels if all real labels are disabled with no types', async () => {
+        window.localStorage.setItem(
+          LOKI_LOG_CONTEXT_PRESERVED_LABELS,
+          JSON.stringify({
+            removedLabels: ['bar', 'xyz'],
+            selectedExtractedLabels: ['foo'],
+          })
+        );
+        const result = await logContextProvider.getInitContextFilters(frameWithoutTypes, queryWithParser);
+        expect(result.contextFilters).toEqual([
+          { enabled: false, nonIndexed: false, label: 'bar', value: 'baz' }, // enabled real label
+          { enabled: true, nonIndexed: false, label: 'foo', value: 'uniqueParsedLabel' },
+          { enabled: false, nonIndexed: false, label: 'xyz', value: 'abc' }, // enabled real label
+        ]);
+        expect(result.preservedFiltersApplied).toBe(true);
+      });
+
       it('should not introduce new labels as context filters', async () => {
         window.localStorage.setItem(
           LOKI_LOG_CONTEXT_PRESERVED_LABELS,
@@ -511,7 +618,7 @@ describe('LogContextProvider', () => {
             selectedExtractedLabels: ['foo', 'new'],
           })
         );
-        const result = await logContextProvider.getInitContextFilters(defaultLogRow.labels, queryWithParser);
+        const result = await logContextProvider.getInitContextFilters(defaultLogRow, queryWithParser);
         expect(result.contextFilters).toEqual([
           { enabled: false, nonIndexed: false, label: 'bar', value: 'baz' },
           { enabled: true, nonIndexed: true, label: 'foo', value: 'uniqueParsedLabel' },
@@ -519,6 +626,23 @@ describe('LogContextProvider', () => {
         ]);
         expect(result.preservedFiltersApplied).toBe(true);
       });
+
+      it('should not introduce new labels as context filters with no label types', async () => {
+        window.localStorage.setItem(
+          LOKI_LOG_CONTEXT_PRESERVED_LABELS,
+          JSON.stringify({
+            removedLabels: ['bar'],
+            selectedExtractedLabels: ['foo', 'new'],
+          })
+        );
+        const result = await logContextProvider.getInitContextFilters(frameWithoutTypes, queryWithParser);
+        expect(result.contextFilters).toEqual([
+          { enabled: false, nonIndexed: false, label: 'bar', value: 'baz' },
+          { enabled: true, nonIndexed: false, label: 'foo', value: 'uniqueParsedLabel' },
+          { enabled: true, nonIndexed: false, label: 'xyz', value: 'abc' },
+        ]);
+        expect(result.preservedFiltersApplied).toBe(true);
+      });
     });
   });
 
