@@ -1,13 +1,10 @@
-// Libraries
-import React, { memo } from 'react';
+import { memo } from 'react';
 
 import { AnnotationQuery } from '@grafana/data';
-import { EditorField, EditorRow } from '@grafana/experimental';
-import { Input } from '@grafana/ui';
+import { EditorField, EditorRow } from '@grafana/plugin-ui';
+import { Input, Stack } from '@grafana/ui';
 
-// Types
-import { getNormalizedLokiQuery } from '../queryUtils';
-import { LokiQuery, LokiQueryType } from '../types';
+import { LokiQuery } from '../types';
 
 import { LokiOptionFields } from './LokiOptionFields';
 import { LokiQueryField } from './LokiQueryField';
@@ -27,17 +24,11 @@ export const LokiAnnotationsQueryEditor = memo(function LokiAnnotationQueryEdito
   }
 
   const onChangeQuery = (query: LokiQuery) => {
-    // the current version of annotations only stores an optional boolean
-    // field `instant` to handle the instant/range switch.
-    // we need to maintain compatibility for now, so we do the same.
-    // we explicitly call `getNormalizedLokiQuery` to make sure `queryType`
-    // is set up correctly.
-    const instant = getNormalizedLokiQuery(query).queryType === LokiQueryType.Instant;
     onAnnotationChange({
       ...annotation,
       expr: query.expr,
       maxLines: query.maxLines,
-      instant,
+      queryType: 'range',
     });
   };
 
@@ -49,8 +40,8 @@ export const LokiAnnotationsQueryEditor = memo(function LokiAnnotationQueryEdito
     queryType: annotation.queryType,
   };
   return (
-    <>
-      <div className="gf-form-group">
+    <Stack gap={5} direction="column">
+      <Stack gap={0} direction="column">
         <LokiQueryField
           datasource={props.datasource}
           query={queryWithRefId}
@@ -60,15 +51,13 @@ export const LokiAnnotationsQueryEditor = memo(function LokiAnnotationQueryEdito
           ExtraFieldElement={
             <LokiOptionFields
               lineLimitValue={queryWithRefId?.maxLines?.toString() || ''}
-              resolution={queryWithRefId.resolution || 1}
               query={queryWithRefId}
               onRunQuery={() => {}}
               onChange={onChangeQuery}
             />
           }
         />
-      </div>
-
+      </Stack>
       <EditorRow>
         <EditorField
           label="Title"
@@ -120,6 +109,6 @@ export const LokiAnnotationsQueryEditor = memo(function LokiAnnotationQueryEdito
           />
         </EditorField>
       </EditorRow>
-    </>
+    </Stack>
   );
 });
