@@ -1,9 +1,18 @@
 import debounce from 'debounce-promise';
 import { has, size } from 'lodash';
-import React, { useState } from 'react';
+import { useState } from 'react';
 
 import { SelectableValue, toOption } from '@grafana/data';
-import { Select, InlineFormLabel, Icon, clearButtonStyles, useStyles2, AsyncSelect } from '@grafana/ui';
+import {
+  Select,
+  InlineFormLabel,
+  Icon,
+  clearButtonStyles,
+  useStyles2,
+  AsyncSelect,
+  Stack,
+  InlineLabel,
+} from '@grafana/ui';
 
 import { OpenTsdbQuery } from '../types';
 
@@ -97,47 +106,47 @@ export function TagSection({
   const tagValueSearch = debounce((query: string) => suggestTagValues(query), 350);
 
   return (
-    <div className="gf-form-inline" data-testid={testIds.section}>
-      <div className="gf-form">
-        <InlineFormLabel
-          className="query-keyword"
-          width={8}
-          tooltip={tsdbVersion >= 2 ? <div>Please use filters, tags are deprecated in opentsdb 2.2</div> : undefined}
-        >
-          Tags
-        </InlineFormLabel>
-        {query.tags &&
-          Object.keys(query.tags).map((tagKey: string | number, idx: number) => {
-            const tagValue = query.tags[tagKey];
-            return (
-              <InlineFormLabel key={idx} width="auto" data-testid={testIds.list + idx}>
-                {tagKey}={tagValue}
-                <button type="button" className={buttonStyles} onClick={() => editTag(tagKey, tagValue)}>
-                  <Icon name={'pen'} />
-                </button>
-                <button
-                  type="button"
-                  className={buttonStyles}
-                  onClick={() => removeTag(tagKey)}
-                  data-testid={testIds.remove}
-                >
-                  <Icon name={'times'} />
-                </button>
-              </InlineFormLabel>
-            );
-          })}
-        {!addTagMode && (
-          <button className="gf-form-label" type="button" onClick={changeAddTagMode} aria-label="Add tag">
+    <Stack gap={0} data-testid={testIds.section}>
+      <InlineFormLabel
+        className="query-keyword"
+        width={8}
+        tooltip={tsdbVersion >= 2 ? <div>Please use filters, tags are deprecated in opentsdb 2.2</div> : undefined}
+      >
+        Tags
+      </InlineFormLabel>
+      {query.tags &&
+        Object.keys(query.tags).map((tagKey: string | number, idx: number) => {
+          const tagValue = query.tags[tagKey];
+          return (
+            <InlineFormLabel key={idx} width="auto" data-testid={testIds.list + idx}>
+              {tagKey}={tagValue}
+              <button type="button" className={buttonStyles} onClick={() => editTag(tagKey, tagValue)}>
+                <Icon name={'pen'} />
+              </button>
+              <button
+                type="button"
+                className={buttonStyles}
+                onClick={() => removeTag(tagKey)}
+                data-testid={testIds.remove}
+              >
+                <Icon name={'times'} />
+              </button>
+            </InlineFormLabel>
+          );
+        })}
+      {!addTagMode && (
+        <InlineFormLabel width={2}>
+          <button type="button" className={buttonStyles} onClick={changeAddTagMode} aria-label="Add tag">
             <Icon name={'plus'} />
           </button>
-        )}
-      </div>
+        </InlineFormLabel>
+      )}
+
       {addTagMode && (
-        <div className="gf-form-inline">
-          <div className="gf-form">
+        <Stack gap={0.5} alignItems="center">
+          <Stack gap={0}>
             <Select
               inputId="opentsdb-suggested-tagk-select"
-              className="gf-form-input"
               value={curTagKey ? toOption('' + curTagKey) : undefined}
               placeholder="key"
               allowCustomValue
@@ -156,12 +165,11 @@ export function TagSection({
                 }
               }}
             />
-          </div>
+          </Stack>
 
-          <div className="gf-form">
+          <Stack gap={0}>
             <AsyncSelect
               inputId="opentsdb-suggested-tagv-select"
-              className="gf-form-input"
               value={curTagValue ? toOption(curTagValue) : undefined}
               placeholder="value"
               allowCustomValue
@@ -173,30 +181,30 @@ export function TagSection({
                 }
               }}
             />
-          </div>
+          </Stack>
 
-          <div className="gf-form">
+          <Stack gap={0}>
             {errors && (
-              <div className="gf-form-label" title={errors} data-testid={testIds.error}>
+              <InlineLabel title={errors} data-testid={testIds.error}>
                 <Icon name={'exclamation-triangle'} color={'rgb(229, 189, 28)'} />
-              </div>
+              </InlineLabel>
             )}
 
-            <div className="gf-form-label">
+            <InlineFormLabel width={5.5}>
               <button type="button" className={buttonStyles} onClick={addTag}>
                 add tag
               </button>
               <button type="button" className={buttonStyles} onClick={changeAddTagMode}>
                 <Icon name={'times'} />
               </button>
-            </div>
-          </div>
-        </div>
+            </InlineFormLabel>
+          </Stack>
+        </Stack>
       )}
-      <div className="gf-form gf-form--grow">
-        <div className="gf-form-label gf-form-label--grow"></div>
-      </div>
-    </div>
+      <Stack gap={0} grow={1}>
+        <InlineLabel> </InlineLabel>
+      </Stack>
+    </Stack>
   );
 }
 
