@@ -1,5 +1,4 @@
 import { lastValueFrom, of } from 'rxjs';
-import { createFetchResponse } from 'test/helpers/createFetchResponse';
 
 import {
   DataFrameView,
@@ -8,52 +7,49 @@ import {
   DataSourcePluginMeta,
   FieldType,
 } from '@grafana/data';
-import { BackendSrv, TemplateSrv } from '@grafana/runtime';
+import { BackendSrv, getBackendSrv, setBackendSrv, TemplateSrv } from '@grafana/runtime';
 
 import { addNodeGraphFramesToResponse, ZipkinDatasource } from './datasource';
 import mockJson from './mocks/mockJsonResponse.json';
 import { mockTraceDataFrame } from './mocks/mockTraceDataFrame';
-import { ZipkinQuery, ZipkinSpan } from './types';
-import { traceFrameFields, zipkinResponse } from './utils/testData';
+import { ZipkinQuery } from './types';
 
-export const backendSrv = { fetch: jest.fn() } as unknown as BackendSrv;
-
-jest.mock('@grafana/runtime', () => ({
-  ...jest.requireActual('@grafana/runtime'),
-  getBackendSrv: () => backendSrv,
-}));
+const templateSrv: TemplateSrv = {
+  replace: jest.fn().mockImplementation((value) => value),
+  getVariables: jest.fn(),
+  containsTemplate: jest.fn(),
+  updateTimeRange: jest.fn(),
+};
 
 describe('ZipkinDatasource', () => {
+  let origBackendSrv: BackendSrv;
+  let ds: ZipkinDatasource;
+  beforeEach(() => {
+    origBackendSrv = getBackendSrv();
+    setBackendSrv({ ...origBackendSrv, fetch: jest.fn().mockReturnValue(of({ data: {} })) });
+    ds = new ZipkinDatasource(defaultSettings, templateSrv);
+  });
+
+  afterEach(() => {
+    setBackendSrv(origBackendSrv);
+    jest.clearAllMocks();
+  });
   describe('query', () => {
-    const templateSrv: TemplateSrv = {
-      replace: jest.fn(),
-      getVariables: jest.fn(),
-      containsTemplate: jest.fn(),
-      updateTimeRange: jest.fn(),
-    };
-
     it('runs query', async () => {
-      setupBackendSrv(zipkinResponse);
-      const ds = new ZipkinDatasource(defaultSettings, templateSrv);
-      await expect(ds.query({ targets: [{ query: '12345' }] } as DataQueryRequest<ZipkinQuery>)).toEmitValuesWith(
-        (val) => {
-          expect(val[0].data[0].fields).toMatchObject(traceFrameFields);
-        }
-      );
-    });
+      const origBackendSrv = getBackendSrv();
+      setBackendSrv({
+        ...origBackendSrv,
+        fetch: jest.fn().mockReturnValue(of({ data: [] })),
+      });
 
-    it('runs query with traceId that includes special characters', async () => {
-      setupBackendSrv(zipkinResponse);
-      const ds = new ZipkinDatasource(defaultSettings, templateSrv);
-      await expect(ds.query({ targets: [{ query: 'a/b' }] } as DataQueryRequest<ZipkinQuery>)).toEmitValuesWith(
-        (val) => {
-          expect(val[0].data[0].fields).toMatchObject(traceFrameFields);
-        }
-      );
+      const response = await lastValueFrom(ds.query({ targets: [{ query: 'test' }] } as DataQueryRequest<ZipkinQuery>));
+      expect(response).toEqual({
+        state: 'Done',
+        data: [],
+      });
     });
 
     it('should handle json file upload', async () => {
-      const ds = new ZipkinDatasource(defaultSettings);
       ds.uploadedJson = JSON.stringify(mockJson);
       const response = await lastValueFrom(
         ds.query({
@@ -67,7 +63,6 @@ describe('ZipkinDatasource', () => {
     });
 
     it('should fail on invalid json file upload', async () => {
-      const ds = new ZipkinDatasource(defaultSettings);
       ds.uploadedJson = JSON.stringify({ key: 'value', arr: [] });
       const response = await lastValueFrom(
         ds.query({
@@ -81,7 +76,10 @@ describe('ZipkinDatasource', () => {
 
   describe('metadataRequest', () => {
     it('runs query', async () => {
-      setupBackendSrv(['service 1', 'service 2'] as unknown as ZipkinSpan[]);
+      setBackendSrv({
+        ...origBackendSrv,
+        fetch: jest.fn().mockReturnValue(of({ data: ['service 1', 'service 2'] })),
+      });
       const ds = new ZipkinDatasource(defaultSettings);
       const response = await ds.metadataRequest('services');
       expect(response).toEqual(['service 1', 'service 2']);
@@ -118,13 +116,6 @@ describe('addNodeGraphFramesToResponse', () => {
   });
 });
 
-function setupBackendSrv(response: ZipkinSpan[]) {
-  const defaultMock = () => of(createFetchResponse(response));
-
-  const fetchMock = jest.spyOn(backendSrv, 'fetch');
-  fetchMock.mockImplementation(defaultMock);
-}
-
 const defaultSettings: DataSourceInstanceSettings = {
   id: 1,
   uid: '1',
