@@ -2,6 +2,7 @@ import { isEmpty, uniq } from 'lodash';
 import { useEffect, useMemo } from 'react';
 
 import { SelectableValue } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { Icon, MultiSelect } from '@grafana/ui';
 import { useUnifiedAlertingSelector } from 'app/features/alerting/unified/hooks/useUnifiedAlertingSelector';
 import { fetchAllPromRulesAction } from 'app/features/alerting/unified/state/actions';
@@ -9,7 +10,7 @@ import {
   isAsyncRequestMapSlicePending,
   isAsyncRequestMapSliceSettled,
 } from 'app/features/alerting/unified/utils/redux';
-import { useDispatch } from 'app/types';
+import { useDispatch } from 'app/types/store';
 import { AlertingRule } from 'app/types/unified-alerting';
 import { PromRuleType } from 'app/types/unified-alerting-dto';
 
@@ -65,8 +66,8 @@ export const GroupBy = (props: Props) => {
       id={id}
       isLoading={loading}
       defaultValue={defaultValue}
-      aria-label={'group by label keys'}
-      placeholder="Group by"
+      aria-label={t('alertlist.group-by.aria-label-group-by-label-keys', 'group by label keys')}
+      placeholder={t('alertlist.group-by.placeholder-group-by', 'Group by')}
       prefix={<Icon name={'tag-alt'} />}
       onChange={(items) => {
         onChange(items.map((item) => item.value ?? ''));
