@@ -1,6 +1,6 @@
 import { useDialog } from '@react-aria/dialog';
 import { useOverlay } from '@react-aria/overlays';
-import React, { createRef } from 'react';
+import { createRef } from 'react';
 
 import { Portal, VizTooltipContainer } from '@grafana/ui';
 import { ComplexDataHoverView } from 'app/features/visualization/data-hover/ComplexDataHoverView';
