@@ -1,4 +1,5 @@
-import React, { Component } from 'react';
+import { Component } from 'react';
+import * as React from 'react';
 import { Observable, Unsubscribable } from 'rxjs';
 
 interface Props<T> {
