@@ -10,6 +10,7 @@ import {
   StyleConfigFields,
   StyleConfigState,
   SymbolAlign,
+  ColorValue,
 } from './types';
 
 /** Indicate if the style wants to show text values */
@@ -91,3 +92,60 @@ export function getDisplacement(symbolAlign: SymbolAlign, radius: number) {
   }
   return displacement;
 }
+
+export function getRGBValues(colorString: string): ColorValue | null {
+  // Check if it's a hex color
+  if (colorString.startsWith('#')) {
+    return getRGBFromHex(colorString);
+  }
+
+  // Check if it's an RGB color
+  else if (colorString.startsWith('rgb')) {
+    return getRGBFromRGBString(colorString);
+  }
+
+  // Handle other color formats if needed
+  else {
+    console.warn(`Unsupported color format: ${colorString}`);
+  }
+  return null;
+}
+
+function getRGBFromHex(hexColor: string): ColorValue {
+  // Remove the '#' character
+  hexColor = hexColor.slice(1);
+
+  // Convert hex to decimal values
+  const r = parseInt(hexColor.slice(0, 2), 16);
+  const g = parseInt(hexColor.slice(2, 4), 16);
+  const b = parseInt(hexColor.slice(4, 6), 16);
+
+  return { r, g, b };
+}
+
+function getRGBFromRGBString(rgbString: string): ColorValue | null {
+  // Use regex to extract the numbers, supporting both rgb(r,g,b) and rgba(r,g,b,a) formats
+  const matches = rgbString.match(/\d+\.?\d*/g);
+
+  if (matches) {
+    if (matches.length === 3) {
+      return {
+        r: parseInt(matches[0], 10),
+        g: parseInt(matches[1], 10),
+        b: parseInt(matches[2], 10),
+      };
+    } else if (matches.length === 4) {
+      return {
+        r: parseInt(matches[0], 10),
+        g: parseInt(matches[1], 10),
+        b: parseInt(matches[2], 10),
+        a: parseFloat(matches[3]), // Using parseFloat for alpha as it can be decimal (0-1)
+      };
+    } else {
+      console.warn(`Unsupported color format: ${rgbString}`);
+    }
+  } else {
+    console.warn(`Unsupported color format: ${rgbString}`);
+  }
+  return null;
+}
