@@ -2,7 +2,7 @@ import { SimulationNodeDatum, SimulationLinkDatum } from 'd3-force';
 
 import { DataFrame, Field, IconName } from '@grafana/data';
 
-export { Options as NodeGraphOptions, ArcOption } from './panelcfg.gen';
+export type { Options as NodeGraphOptions, ArcOption, ZoomMode } from './panelcfg.gen';
 
 export type NodeDatum = SimulationNodeDatum & {
   id: string;
@@ -17,6 +17,7 @@ export type NodeDatum = SimulationNodeDatum & {
   icon?: IconName;
   nodeRadius?: Field;
   highlighted: boolean;
+  isInstrumented?: boolean;
 };
 
 export type NodeDatumFromEdge = NodeDatum & { mainStatNumeric?: number; secondaryStatNumeric?: number };
@@ -35,12 +36,17 @@ export type EdgeDatum = LinkDatum & {
   dataFrameRowIndex: number;
   sourceNodeRadius: number;
   targetNodeRadius: number;
+  /**
+   * @deprecated -- for edges use color instead
+   */
   highlighted: boolean;
   thickness: number;
+  color?: string;
+  strokeDasharray?: string;
 };
 
 // After layout is run D3 will change the string IDs for actual references to the nodes.
-export type EdgeDatumLayout = EdgeDatum & {
+export type EdgeDatumLayout = Omit<EdgeDatum, 'source' | 'target'> & {
   source: NodeDatum;
   target: NodeDatum;
 };
