@@ -1,4 +1,5 @@
 import { css } from '@emotion/css';
+import { useCallback, useMemo } from 'react';
 
 import {
   ActionModel,
@@ -10,10 +11,13 @@ import {
   PanelProps,
   SelectableValue,
   Field,
+  cacheFieldDisplayNames,
 } from '@grafana/data';
 import { config, PanelDataErrorView } from '@grafana/runtime';
-import { Select, Table, usePanelContext, useTheme2 } from '@grafana/ui';
-import { TableSortByFieldState } from '@grafana/ui/src/components/Table/types';
+import { Select, usePanelContext, useTheme2 } from '@grafana/ui';
+import { TableSortByFieldState } from '@grafana/ui/internal';
+import { TableNG } from '@grafana/ui/unstable';
+import { getConfig } from 'app/core/config';
 
 import { getActions } from '../../../features/actions/utils';
 
@@ -23,10 +27,20 @@ import { Options } from './panelcfg.gen';
 interface Props extends PanelProps<Options> {}
 
 export function TablePanel(props: Props) {
-  const { data, height, width, options, fieldConfig, id, timeRange, replaceVariables } = props;
+  const { data, height, width, options, fieldConfig, id, timeRange, replaceVariables, transparent } = props;
+
+  useMemo(() => {
+    cacheFieldDisplayNames(data.series);
+  }, [data.series]);
 
   const theme = useTheme2();
   const panelContext = usePanelContext();
+  const userCanExecuteActions = useMemo(() => panelContext.canExecuteActions?.() ?? false, [panelContext]);
+  const _getActions = useCallback(
+    (frame: DataFrame, field: Field, rowIndex: number) =>
+      userCanExecuteActions ? getCellActions(frame, field, rowIndex, replaceVariables) : [],
+    [replaceVariables, userCanExecuteActions]
+  );
   const frames = hasDeprecatedParentRowIndex(data.series)
     ? migrateFromParentRowIndexToNestedFrames(data.series)
     : data.series;
@@ -50,8 +64,10 @@ export function TablePanel(props: Props) {
 
   const enableSharedCrosshair = panelContext.sync && panelContext.sync() !== DashboardCursorSync.Off;
 
+  const disableSanitizeHtml = getConfig().disableSanitizeHtml;
+
   const tableElement = (
-    <Table
+    <TableNG
       height={tableHeight}
       width={width}
       data={main}
@@ -62,14 +78,17 @@ export function TablePanel(props: Props) {
       onSortByChange={(sortBy) => onSortByChange(sortBy, props)}
       onColumnResize={(displayName, resizedWidth) => onColumnResize(displayName, resizedWidth, props)}
       onCellFilterAdded={panelContext.onAddAdHocFilter}
-      footerOptions={options.footer}
-      enablePagination={options.footer?.enablePagination}
+      frozenColumns={options.frozenColumns?.left}
+      enablePagination={options.enablePagination}
       cellHeight={options.cellHeight}
+      maxRowHeight={options.maxRowHeight}
       timeRange={timeRange}
       enableSharedCrosshair={config.featureToggles.tableSharedCrosshair && enableSharedCrosshair}
       fieldConfig={fieldConfig}
-      getActions={getCellActions}
-      replaceVariables={replaceVariables}
+      getActions={_getActions}
+      structureRev={data.structureRev}
+      transparent={transparent}
+      disableSanitizeHtml={disableSanitizeHtml}
     />
   );
 
@@ -151,28 +170,39 @@ const getCellActions = (
   field: Field,
   rowIndex: number,
   replaceVariables: InterpolateFunction | undefined
-) => {
-  const actions: Array<ActionModel<Field>> = [];
-  const actionLookup = new Set<string>();
+): Array<ActionModel<Field>> => {
+  const numActions = field.config.actions?.length ?? 0;
 
-  const actionsModel = getActions(
-    dataFrame,
-    field,
-    field.state!.scopedVars!,
-    replaceVariables ?? replaceVars,
-    field.config.actions ?? [],
-    { valueRowIndex: rowIndex }
-  );
+  if (numActions > 0) {
+    const actions = getActions(
+      dataFrame,
+      field,
+      field.state!.scopedVars!,
+      replaceVariables ?? replaceVars,
+      field.config.actions ?? [],
+      { valueRowIndex: rowIndex }
+    );
 
-  actionsModel.forEach((action) => {
-    const key = `${action.title}`;
-    if (!actionLookup.has(key)) {
-      actions.push(action);
-      actionLookup.add(key);
+    if (actions.length === 1) {
+      return actions;
+    } else {
+      const actionsOut: Array<ActionModel<Field>> = [];
+      const actionLookup = new Set<string>();
+
+      actions.forEach((action) => {
+        const key = action.title;
+
+        if (!actionLookup.has(key)) {
+          actionsOut.push(action);
+          actionLookup.add(key);
+        }
+      });
+
+      return actionsOut;
     }
-  });
+  }
 
-  return actions;
+  return [];
 };
 
 const tableStyles = {
