@@ -2,7 +2,8 @@ import { css } from '@emotion/css';
 import * as React from 'react';
 
 import { GrafanaTheme2, dateTimeFormat, systemDateFormats, textUtil } from '@grafana/data';
-import { HorizontalGroup, IconButton, Tag, usePanelContext, useStyles2 } from '@grafana/ui';
+import { t } from '@grafana/i18n';
+import { Stack, IconButton, Tag, usePanelContext, useStyles2 } from '@grafana/ui';
 import alertDef from 'app/features/alerting/state/alertDef';
 
 interface Props {
@@ -64,7 +65,7 @@ export const AnnotationTooltip2 = ({ annoVals, annoIdx, timeZone, onEdit }: Prop
   return (
     <div className={styles.wrapper}>
       <div className={styles.header}>
-        <HorizontalGroup justify={'space-between'} align={'center'} spacing={'md'}>
+        <Stack gap={2} basis="100%" justifyContent="space-between" alignItems="center">
           <div className={styles.meta}>
             <span>
               {avatar}
@@ -74,27 +75,36 @@ export const AnnotationTooltip2 = ({ annoVals, annoIdx, timeZone, onEdit }: Prop
           </div>
           {(canEdit || canDelete) && (
             <div className={styles.editControls}>
-              {canEdit && <IconButton name={'pen'} size={'sm'} onClick={onEdit} tooltip="Edit" />}
+              {canEdit && (
+                <IconButton
+                  name={'pen'}
+                  size={'sm'}
+                  onClick={onEdit}
+                  tooltip={t('timeseries.annotation-tooltip2.tooltip-edit', 'Edit')}
+                />
+              )}
               {canDelete && (
                 <IconButton
                   name={'trash-alt'}
                   size={'sm'}
                   onClick={() => onAnnotationDelete(annoId)}
-                  tooltip="Delete"
+                  tooltip={t('timeseries.annotation-tooltip2.tooltip-delete', 'Delete')}
                 />
               )}
             </div>
           )}
-        </HorizontalGroup>
+        </Stack>
       </div>
 
       <div className={styles.body}>
         {text && <div className={styles.text} dangerouslySetInnerHTML={{ __html: textUtil.sanitize(text) }} />}
         {alertText}
         <div>
-          <HorizontalGroup spacing="xs" wrap>
-            {annoVals.tags?.[annoIdx]?.map((t: string, i: number) => <Tag name={t} key={`${t}-${i}`} />)}
-          </HorizontalGroup>
+          <Stack gap={0.5} wrap={true}>
+            {annoVals.tags?.[annoIdx]?.map((t: string, i: number) => (
+              <Tag name={t} key={`${t}-${i}`} />
+            ))}
+          </Stack>
         </div>
       </div>
     </div>
@@ -106,9 +116,9 @@ const getStyles = (theme: GrafanaTheme2) => ({
     zIndex: theme.zIndex.tooltip,
     whiteSpace: 'initial',
     borderRadius: theme.shape.radius.default,
-    background: theme.colors.background.primary,
+    background: theme.colors.background.elevated,
     border: `1px solid ${theme.colors.border.weak}`,
-    boxShadow: theme.shadows.z2,
+    boxShadow: theme.shadows.z3,
     userSelect: 'text',
   }),
   header: css({
@@ -121,13 +131,11 @@ const getStyles = (theme: GrafanaTheme2) => ({
   }),
   meta: css({
     display: 'flex',
-    justifyContent: 'space-between',
     color: theme.colors.text.primary,
     fontWeight: 400,
   }),
   editControls: css({
     display: 'flex',
-    alignItems: 'center',
     '> :last-child': {
       marginLeft: 0,
     },
