@@ -2,6 +2,7 @@ import { DataQuery } from '@grafana/data';
 import { Dashboard, DataSourceRef } from '@grafana/schema';
 import { ObjectMeta } from 'app/features/apiserver/types';
 import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
+import { ProvisioningPreview } from 'app/features/provisioning/types';
 
 export interface HomeDashboardRedirectDTO {
   redirectUri: string;
@@ -78,6 +79,9 @@ export interface DashboardMeta {
   // until we use the resource as the main container
   k8s?: Partial<ObjectMeta>;
 
+  // If the dashboard was loaded from a remote repository
+  provisioning?: ProvisioningPreview;
+
   // This is a property added specifically for edge cases where dashboards should be reloaded on scopes, time range or variables changes
   // This property is not persisted in the DB but its existence is controlled by the API
   reloadOnParamsChange?: boolean;
@@ -105,6 +109,7 @@ export enum DashboardRoutes {
   Home = 'home-dashboard',
   New = 'new-dashboard',
   Normal = 'normal-dashboard',
+  Provisioning = 'provisioning-dashboard',
   Scripted = 'scripted-dashboard',
   Public = 'public-dashboard',
   Embedded = 'embedded-dashboard',
